<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_About extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-about';
    }

    public function get_title()
    { 
        return esc_html__('About', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['about', 'doob'];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'tp_layout',
            [
                'label' => esc_html__('Design Layout', 'tp-core'),
            ] 
        );
        $this->add_control(
            'tp_design_style',
            [
                'label' => esc_html__('Select Layout', 'tp-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout-1', 'tp-core'),
                    'layout-2' => esc_html__('Layout-2', 'tp-core'),
                    'layout-3' => esc_html__('Layout-3', 'tp-core'),
                    'layout-4' => esc_html__('Layout-4', 'tp-core'),
                ],
                'default' => 'layout-1',
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            '_about_thumbnail',
            [
                'label' => esc_html__('Thumbnail', 'doob'),
            ]
        );
        $this->add_control(
            'about_thumbnail',
            [
                'label' => esc_html__( 'Choose Image', 'doob' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'about_thumbnail_size',
                'default' => 'full',
                'exclude' => [
                    'custom'
                ]
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            '_about_list',
            [
                'label' => esc_html__('About List', 'doob'),
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'about_title', [
                'label' => esc_html__( 'About Tirle', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'This is About item title' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'about_description',
            [
                'label' => esc_html__('Description', 'doob'),
                'description' => rbt_get_allowed_html_desc( 'intermediate' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => 'Facilis fugiat hic ipsam iusto laudantium libero maiores minima molestiae mollitia repellat rerum sunt ullam voluptates? Perferendis, suscipit.',
                'label_block' => true,
            ]
        );


        $repeater->add_control(
            'counterup_icon_type',
            [
                'label' => esc_html__('Select Icon Type', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'icon',
                'options' => [
                    'image' => esc_html__('Image', 'doob'),
                    'icon' => esc_html__('Icon', 'doob'),
                ],
            ]
        );

        $repeater->add_control(
            'counterup_image',
            [
                'label' => esc_html__('Upload Image', 'doob'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'counterup_icon_type' => 'image'
                ]

            ]
        );
        if (rbt_is_elementor_version('<', '2.6.0')) {
            $repeater->add_control(
                'counterup_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'fa fa-star',
                    'condition' => [
                        'counterup_icon_type' => 'icon'
                    ]
                ]
            );
        } else {
            $repeater->add_control(
                'counterup_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-star',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'counterup_icon_type' => 'icon'
                    ]
                ]
            );
        }
        $this->add_control(
            'abouts',
            [
                'label' => esc_html__( 'Repeater about', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'about_title' => esc_html__( 'A good traveler has no fixed plans #1', 'doob' ),
                    ],
                    [
                        'about_title' => esc_html__( 'A good traveler has no fixed plans #2', 'doob' ),
                    ],
                ],
                'title_field' => '{{{ about_title }}}',
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            '_tp_hero_video',
            [
                'label' => esc_html__('Video Url', 'tp-core'),
                'condition' => [
                    'tp_design_style' => ['layout-2']
                ]
            ]
         
        );
        $this->add_control(
            'video_title',
            [
                'label' => esc_html__('Hero Video', 'doob'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('#.', 'doob'),
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
         '_section_alignment',
             [
               'label' => esc_html__( 'Alignment', 'doob' ),
               'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
               'condition' => [
                'tp_design_style' => ['layout-4']
               ]
             ]
        );
        $this->add_control(
         'align',
         [
           'label'   => esc_html__( 'Alignment', 'textdomain' ),
           'type' => \Elementor\Controls_Manager::SELECT,
           'options' => [
             'text-center'  => esc_html__( 'Center', 'textdomain' ),
             'text-start'  => esc_html__( 'Left', 'textdomain' ),
             'text-end'  => esc_html__( 'Right', 'textdomain' ),
           ],
           'default' => 'text-start',
           'condition' => [
            'tp_design_style' => ['layout-4']
           ]
         ]
        );
        $this->end_controls_section();
        // Section Title
        $this->rbt_section_title('about', 'Title and Content', '', 'Refreshingly Company', 'h2', 'Far far away, behind the word mountains, far from the countries Vokalia and Consonantia, there live the blind texts. Separated they live in Bookmarksgrove right at the coast of the Semantics, a large language ocean. <br><br> A small river named Duden flows by their place and supplies it with the necessary regelialia. It is a paradisematic country, in which roasted parts of sentences', 'text-left', 'yes', 'yes', true, 'yes');
        
        $this->rbt_link_controls('rbt_button', 'Button', 'Button Text');



        // Style Component
        $this->rbt_basic_style_controls('about_section_title_before_title', 'Section - Before Title', '.section-title .subtitle, .section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('about_section_title_title', 'Section - Title', '.section-title .title');
        $this->rbt_basic_style_controls('about_section_clip_text', 'Clip Text', '.section-title .cd-headline, .section-title .cd-headline .theme-gradient');
        $this->rbt_basic_style_controls('about_section_title_description', 'Section - Description', '.section-title p');

        // Link Style
        $this->rbt_link_controls_style('rbt_button_style', 'Button', '.rbt-button');

        // Area Style
        $this->rbt_section_style_controls('about_area', 'Section Style', '.rainbow-about-area');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        ?>
<?php if ( $settings['tp_design_style']  == 'layout-2' ):?>
<!-- Srart About Area  -->
<div class="about-area about-style-4 rainbow-section-gapBottom">
    <div class="container">
        <div class="row row--40 align-items-center">
            <div class="col-lg-6">
                <div class="video-btn">
                    <div class="video-popup icon-center">
                        <div class="overlay-content">
                            <?php if ($settings['about_thumbnail']['url'] || $settings['about_thumbnail']['id']) : ?>
                            <div class="thumbnail">
                                <?php
                                $this->add_render_attribute('about_thumbnail', 'src', $settings['about_thumbnail']['url']);
                                $this->add_render_attribute('about_thumbnail', 'alt', Control_Media::get_image_alt($settings['about_thumbnail']));
                                $this->add_render_attribute('about_thumbnail', 'title', Control_Media::get_image_title($settings['about_thumbnail']));
                                $this->add_render_attribute('about_thumbnail', 'class', 'w-100');
                                ?>
                                <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'about_thumbnail_size', 'about_thumbnail'); ?>
                            </div>
                            <?php endif; ?>
                            <div class="video-icon">
                                <a class="btn-default rounded-player popup-video"
                                    href="<?php echo esc_url($settings['video_title']);?>">
                                    <span><i class="feather-play"></i></span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <div class="video-lightbox-wrapper"></div>
                </div>
            </div>
            <div class="col-lg-6 mt_md--40 mt_sm--40">
                <div class="content">
                    <div class="inner">
                        <?php $this->rbt_section_title_render('about', $this->get_settings()); ?>
                        <ul class="feature-list">
                            <?php foreach ( $settings['abouts'] as $index => $item){
                            ?>
                            <li>
                                <div class="icon">
                                    <?php if($item['counterup_icon_type'] !== 'image'){ ?>
                                    <?php if (!empty($item['counterup_icon']) || !empty($item['counterup_selected_icon']['value'])) : ?>
                                    <div class="icon">
                                        <?php rbt_render_icon($item, 'counterup_icon', 'counterup_selected_icon'); ?>
                                    </div>
                                    <?php endif; ?>
                                    <?php } else {
                                    if (!empty($item['counterup_image'])){ ?>
                                    <div class="icon">
                                        <?php echo Group_Control_Image_Size::get_attachment_image_html($item, 'full', 'counterup_image'); ?>
                                    </div>
                                    <?php } ?>
                                    <?php } ?>

                                </div>
                                <div class="title-wrapper">
                                    <?php if(!empty($item['about_title']) ) : ?>
                                    <h4 class="title"> <?php echo esc_html($item['about_title']); ?></h4>
                                    <?php endif; ?>
                                    <?php if(!empty($item['about_description']) ) : ?>
                                    <p class="text"> <?php echo esc_html($item['about_description']); ?></p>
                                    <?php endif; ?>
                                </div>
                            </li>
                            <?php } ?>
                        </ul>
                        <?php if($settings['rbt_rbt_button_button_show'] === 'yes'){ ?>
                            <div class="mt--40  <?php echo esc_attr($settings['align']); ?>">
                                <?php $this->rbt_link_control_render('rbt_button', $this->get_settings()); ?>
                            </div>
                        <?php } ?>


                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!-- End About Area  -->

<?php elseif ( $settings['tp_design_style']  == 'layout-3' ):?>

<div class="row align-items-center">
    <div class="col-lg-4 col-md-6 col-12">
        <?php if ($settings['about_thumbnail']['url'] || $settings['about_thumbnail']['id']) : ?>
        <div class="thumbnail text-left text-lg-center">
            <?php
            $this->add_render_attribute('about_thumbnail', 'src', $settings['about_thumbnail']['url']);
            $this->add_render_attribute('about_thumbnail', 'alt', Control_Media::get_image_alt($settings['about_thumbnail']));
            $this->add_render_attribute('about_thumbnail', 'title', Control_Media::get_image_title($settings['about_thumbnail']));
            $this->add_render_attribute('about_thumbnail', 'class', 'w-100');
            ?>
            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'about_thumbnail_size', 'about_thumbnail'); ?>
        </div>
        <?php endif; ?>
    </div>
    <div class="col-lg-8 col-md-6 col-12 mt_sm--30">
        <div class="section-title <?php echo esc_attr($settings['rbt_about_align']) ?>">
            <?php $this->rbt_section_title_render('about', $this->get_settings()); ?>
        </div>
        <?php if($settings['rbt_rbt_button_button_show'] === 'yes'){ ?>
            <div class="mt--40  <?php echo esc_attr($settings['align']); ?>">
                <?php $this->rbt_link_control_render('rbt_button', $this->get_settings()); ?>
            </div>
        <?php } ?>
    </div>
</div>
<?php elseif ( $settings['tp_design_style']  == 'layout-4' ):?>
<div class="about-style-5 rainbow-section-gapBottom">
    <div class="container">
        <div class="row">
            <div class="col-lg-10 offset-lg-1">
                <div class="row row--0 about-wrapper align-items-center theme-shape">
                    <div class="col-lg-6">
                        <?php if ($settings['about_thumbnail']['url'] || $settings['about_thumbnail']['id']) : ?>
                        <div class="thumbnail">
                            <?php
                            $this->add_render_attribute('about_thumbnail', 'src', $settings['about_thumbnail']['url']);
                            $this->add_render_attribute('about_thumbnail', 'alt', Control_Media::get_image_alt($settings['about_thumbnail']));
                            $this->add_render_attribute('about_thumbnail', 'title', Control_Media::get_image_title($settings['about_thumbnail']));
                            $this->add_render_attribute('about_thumbnail', 'class', 'w-100');
                            ?>
                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'about_thumbnail_size', 'about_thumbnail'); ?>
                        </div>
                        <?php endif; ?>
                    </div>
                    <div class="col-lg-6 mt_md--30 mt_sm--30">
                        <div class="content">
                            <div class="inner">
                                <h4 class="title">
                                    <?php $this->rbt_section_title_render('about', $this->get_settings()); ?></h4>
                                <ul class="contact-address">
                                <?php foreach ( $settings['abouts'] as $index => $item){ ?>
                                    <li>
                                    <?php if($item['counterup_icon_type'] !== 'image'){ ?>
                                    <?php if (!empty($item['counterup_icon']) || !empty($item['counterup_selected_icon']['value'])) : ?>
                                        <?php rbt_render_icon($item, 'counterup_icon', 'counterup_selected_icon'); ?>
                                    <?php endif; ?>
                                    <?php } else {
                                    if (!empty($item['counterup_image'])){ ?>
                                        <?php echo Group_Control_Image_Size::get_attachment_image_html($item, 'full', 'counterup_image'); ?>
                                    <?php } ?>
                                    <?php } ?>
                                    <?php echo esc_html($item['about_title']); ?>
                                    </li>
                                    <?php } ?>
                                </ul>

                                <?php if($settings['rbt_rbt_button_button_show'] === 'yes'){ ?>
                                    <div class="download-button mt--20">
                                        <div class="mt--40  <?php echo esc_attr($settings['align']); ?>">
                                            <?php $this->rbt_link_control_render('rbt_button', $this->get_settings()); ?>
                                        </div>
                                    </div>
                                <?php } ?>

                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<?php else:?>
<!-- Start About Area  -->
<div class="rainbow-about-area rainbow-section-gap">
    <div class="about-wrapper">
        <div class="container">
            <div class="row row--30 align-items-center">
                <?php if ($settings['about_thumbnail']['url'] || $settings['about_thumbnail']['id']) : ?>
                <div class="col-lg-5 col-md-12">
                    <div class="thumbnail">
                        <?php
                                $this->add_render_attribute('about_thumbnail', 'src', $settings['about_thumbnail']['url']);
                                $this->add_render_attribute('about_thumbnail', 'alt', Control_Media::get_image_alt($settings['about_thumbnail']));
                                $this->add_render_attribute('about_thumbnail', 'title', Control_Media::get_image_title($settings['about_thumbnail']));
                                $this->add_render_attribute('about_thumbnail', 'class', 'w-100');
                                ?>
                        <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'about_thumbnail_size', 'about_thumbnail'); ?>
                    </div>
                </div>
                <?php endif; ?>
                <div class="col-lg-7 col-md-12 mt_md--40 mt_sm--40">
                    <div class="content sal-animate" data-sal="slide-left" data-sal-duration="800">
                        <div class="section-title <?php echo esc_attr($settings['rbt_about_align']) ?>">
                            <?php $this->rbt_section_title_render('about', $this->get_settings()); ?>
                        </div>
                        <?php if($settings['rbt_rbt_button_button_show'] === 'yes'){ ?>
                            <div class="mt--40  <?php echo esc_attr($settings['align']); ?>">
                                <?php $this->rbt_link_control_render('rbt_button', $this->get_settings()); ?>
                            </div>
                        <?php } ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!-- Start About Area  -->
<?php
endif; 
    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_About());