<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Accordion extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-accordion';
    }

    public function get_title()
    {
        return esc_html__('Accordion', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['accordion', 'tab', 'doob'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            '_accordion',
            [
                'label' => esc_html__( 'Accordion', 'doob' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'accordion_title', [
                'label' => esc_html__( 'Accordion Item', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'This is accordion item title' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'accordion_description',
            [
                'label' => esc_html__('Description', 'doob'),
                'description' => rbt_get_allowed_html_desc( 'intermediate' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => 'Facilis fugiat hic ipsam iusto laudantium libero maiores minima molestiae mollitia repellat rerum sunt ullam voluptates? Perferendis, suscipit.',
                'label_block' => true,
            ]
        );
        $this->add_control(
            'accordions',
            [
                'label' => esc_html__( 'Repeater Accordion', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'accordion_title' => esc_html__( 'This is accordion item title #1', 'doob' ),
                    ],
                    [
                        'accordion_title' => esc_html__( 'This is accordion item title #2', 'doob' ),
                    ],
                    [
                        'accordion_title' => esc_html__( 'This is accordion item title #3', 'doob' ),
                    ],
                    [
                        'accordion_title' => esc_html__( 'This is accordion item title #4', 'doob' ),
                    ],
                ],
                'title_field' => '{{{ accordion_title }}}',
            ]
        );

        $this->add_control(
            'space_accordion_item',
            [
                'label' => esc_html__( 'Accordion space gap', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .accordion-item + .accordion-item' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'accordion_style',
            [
                'label' => esc_html__('Select Style', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '1',
                'options' => [
                    '1' => esc_html__('Style 1', 'doob'),
                    '2' => esc_html__('Style 2', 'doob'),
                    '3' => esc_html__('Style 3', 'doob'),
                    '4' => esc_html__('Style 4', 'doob'),
                ],

            ]
        );

        $this->end_controls_section();

        // Style Component
        $this->rbt_basic_style_controls('accordion_title', 'Title', '.accordion-item .accordion-button');
        $this->rbt_basic_style_controls('accordion_description', 'Description', '.rn-card .rn-card-body');

        // Area Style
        $this->rbt_section_style_controls('accordion_area', 'Area Style', '.rainbow-accordion-style');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        if($settings['accordion_style'] == '2'){
            $style = "rainbow-accordion-02";
        } elseif ( $settings['accordion_style'] == '3' ){
            $style = "rainbow-accordion-03";
        }  elseif ( $settings['accordion_style'] == '4' ){
            $style = "rainbow-accordion-04";
        } else {
            $style = "rainbow-accordion-01";
        }


        if($settings['accordions']){ ?>
        <div class="rainbow-accordion-style accordion <?php echo esc_attr($style); ?>">
            <div id="accordion-<?php echo esc_attr($this->get_id()); ?>" class="accordion">

                <?php foreach ( $settings['accordions'] as $index => $item){
                    $collapsed = ($index !== '0' ) ? 'collapsed' : '';
                    $aria_expanded = ($index == '0' ) ? "true" : "false";
                    $show = ($index == '0' ) ? "show" : "";
                    ?>
                    <!-- Start Single Card  -->
                    <div class="accordion-item card">
                        <div class="accordion-header card-header" id="heading-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>">
                            <button class="accordion-button <?php echo esc_attr($collapsed); ?>" data-bs-toggle="collapse" data-bs-target="#collapse-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" aria-expanded=<?php echo esc_attr($aria_expanded); ?> aria-controls="collapse-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>">
                                <?php echo esc_html($item['accordion_title']); ?>
                            </button>
                        </div>
                        <div id="collapse-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" class="collapse <?php echo esc_attr($show); ?>"  data-bs-parent="#accordion-<?php echo esc_attr($this->get_id()); ?>">
                            <div class="accordion-body card-body">
                                <?php echo rbt_kses_intermediate($item['accordion_description']); ?>
                            </div>
                        </div>
                    </div>
                    <!-- End Single Card  -->
                <?php } ?>



            </div>
        </div>
        <?php
        }



    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Accordion());