<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Advance_Pricing extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-advance-pricing';
    }

    public function get_title()
    {
        return esc_html__('Advance Pricing', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['pricing', 'pricing table','single', 'advance', 'doob'];
    }

    protected function register_controls()
    {
        // Title and content
        $this->rbt_section_title('advance_pricing', 'Section - Title and Content', '', 'Pricing Plan', 'h2', 'There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration.');

        $this->start_controls_section(
            'doob_advance_pricing',
            [
                'label' => esc_html__( 'Pricing Plan', 'doob' ),
            ]
        );

        $this->add_control(
            'pricing_title', [
                'label' => esc_html__( 'Title', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Active Plan Mode.' , 'doob' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'pricing_sub_title', [
                'label' => esc_html__( 'Sub Title', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Lorem ipsum dolor sit amet consectetur adipisicing elit. Nemo, quisquam.' , 'doob' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'pricing_price',
            [
                'label' => esc_html__( 'Price', 'doob' ),
                'type' => Controls_Manager::TEXT,
                'default' => '129',
                'dynamic' => [
                    'active' => true
                ]
            ]
        );
        $this->add_control(
            'pricing_price_currency',
            [
                'label' => esc_html__( 'Currency', 'doob' ),
                'type' => Controls_Manager::TEXT,
                'default' => '$',
                'dynamic' => [
                    'active' => true
                ]
            ]
        );
        $this->add_control(
            'pricing_period', [
                'label' => esc_html__( 'Period', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( '/mo' , 'doob' ),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();


        // Button
        $this->rbt_link_controls('advance_pricing_pn_button', 'Purchase Now Button', 'Purchase Now');
        $this->rbt_link_controls('advance_pricing_ug_button', 'Upgrade Button', 'Upgrade');


        $this->start_controls_section(
            'doob_advance_pricing_rating',
            [
                'label' => esc_html__( 'Rating', 'doob' ),
            ]
        );

        $this->add_control(
            'show_rating',
            [
                'label' => __('Show Rating', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'return_value' => 'yes',
                'description' => esc_html__('Enable or disable Show Rating. Default: On', 'doob'),
            ]
        );
        $this->add_control(
            'rating',
            [
                'label' => __('Rating', 'doob'),
                'type' => Controls_Manager::SELECT,
                'default' => '5',
                'options' => [
                    '1' => __('1 Star', 'doob'),
                    '2' => __('2 Stars', 'doob'),
                    '3' => __('3 Stars', 'doob'),
                    '4' => __('4 Stars', 'doob'),
                    '5' => __('5 Stars', 'doob'),
                ],
                'condition' => [
                    'show_rating' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'rating_description', [
                'label' => esc_html__( 'Description', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Rated 4.9/5 Stars in 1000+ reviews.' , 'doob' ),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();




        $this->start_controls_section(
            'doob_advance_pricing_list',
            [
                'label' => esc_html__( 'Pricing Content', 'doob' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'pricing_features_title', [
                'label' => esc_html__( 'Features Title', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Advance Plans You can Get.' , 'doob' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'pricing_features_list', [
                'label' => esc_html__( 'Features List', 'doob' ),
                'description' => esc_html__( 'Create new line by Enter', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => '5 PPC Campaigns
 Digital Marketing
 Marketing Agency
 Seo Friendly',
                'label_block' => true,
            ]
        );
        // Repeater Control
        $this->add_control(
            'pricing_table_content',
            [
                'label' => esc_html__( 'Pricing Table Content', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'pricing_features_title' => esc_html__( 'Advance Plans You can Get.', 'doob' ),
                        'pricing_features_list' => esc_html__( '5 PPC Campaigns
 Digital Marketing
 Marketing Agency
 Seo Friendly', 'doob' ),
                    ],
                    [
                        'pricing_features_title' => esc_html__( 'Basic Plans Uou can Get.', 'doob' ),
                        'pricing_features_list' => esc_html__( '10 PPC Campaigns
 Digital Marketing
 Marketing Agency
 Seo Friendly
 App Development
 Social Development', 'doob' ),
                    ],
                ],
                'title_field' => '{{{ pricing_features_title }}}',
            ]
        );
        $this->end_controls_section();


        $this->start_controls_section(
            'doob_advance_pricing_control',
            [
                'label' => esc_html__( 'Area Control', 'doob' ),
            ]
        );
        $this->add_control(
            'pricing_content_width',
            [
                'label' => esc_html__( 'Content Width', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'default' => esc_html__('Box (Offset)', 'doob'),
                    'container' => esc_html__('Container', 'doob'),
                    'full' => esc_html__('Container Full Wide', 'doob'),
                ],
                'default' => 'default',
            ]
        );
        $this->end_controls_section();

        // Style Component
        $this->rbt_basic_style_controls('advance_pricing_before_title', 'Section - Before Title', '.section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('advance_pricing_title', 'Section - Title', '.section-title .title');
        $this->rbt_basic_style_controls('advance_pricing_description', 'Section - Description', '.section-title p');


        // Link Style
        $this->rbt_link_controls_style('advance_pricing_pn_button_style', 'Purchase Now Button Style', '.btn-default', 'btn-medium', 'btn-default');
        $this->rbt_link_controls_style('advance_pricing_ug_button_style', 'Upgrade Button Style', '.btn-border', 'btn-medium', 'btn-default btn-border');



        $this->rbt_basic_style_controls('advance_pricing_table_title', 'Table - Title', '.advance-pricing .pricing-left .main-title');
        $this->rbt_basic_style_controls('advance_pricing_table_currency', 'Table - Description', '.advance-pricing .pricing-left .description');
        $this->rbt_basic_style_controls('advance_pricing_table_price', 'Table - Price', '.advance-pricing .pricing-left .price-wrapper .price-amount');
        $this->rbt_basic_style_controls('advance_pricing_table_period', 'Table - Period', '.advance-pricing .pricing-left .price-wrapper .price-amount sup');

        $this->rbt_basic_style_controls('advance_pricing_table_rating_description', 'Table - Rating Description', '.advance-pricing .pricing-left .subtitle');

        $this->rbt_basic_style_controls('advance_pricing_table_fet_list_title', 'Table - Features Title', '.advance-pricing .pricing-right .price-title');
        $this->rbt_basic_style_controls('advance_pricing_table_fet_list', 'Table - Features List', '.advance-pricing .pricing-right .plan-offer-list');
        $this->rbt_basic_style_controls('advance_pricing_table_fet_list_icon', 'Table - Features List Icon', '.plan-offer-list li i, .plan-offer-list li svg');

        $this->rbt_section_style_controls('advance_pricing_table_area', 'Section Style', '.rainbow-pricingtable-area');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();
        // Container
        if($settings['pricing_content_width'] == 'full'){
            $content_width = "wrapper plr--100 plr_md--15 plr_sm--15";
            $cal_class = "col-lg-12";
        } elseif ($settings['pricing_content_width'] == 'container'){
            $content_width = "container";
            $cal_class = "col-lg-12";
        } else  {
            $content_width = "container";
            $cal_class = "col-lg-8 offset-lg-2";
        }

        // Rating
        $has_star           = $settings['show_rating'] == 'yes' ? true : false;
        $rating  			= $settings['rating'];
        $nonrating 		  	= 5 - (int)$rating ;


        ?>
        <!-- Start Pricing Plan Area  -->
        <div class="rainbow-pricingtable-area rainbow-section-gap">
            <div class="<?php echo esc_attr($content_width); ?>">

                <?php if ($settings['rbt_advance_pricing_section_title_show'] == 'yes'){ ?>
                    <div class="row">
                        <div class="<?php echo esc_attr($cal_class); ?>">
                            <div class="section-title <?php echo esc_attr($settings['rbt_advance_pricing_align']); ?>">
                                <?php $this->rbt_section_title_render('advance_pricing', $this->get_settings()); ?>
                            </div>
                        </div>
                    </div>
                    <div class="row mt--30">
                        <div class="<?php echo esc_attr($cal_class); ?>">
                            <div class="advance-pricing">
                                <div class="inner">
                                    <div class="row row--0">
                                        <div class="col-lg-6">
                                            <div class="pricing-left">
                                                <?php if(!empty($settings['pricing_title'])){ ?>
                                                    <h3 class="main-title"><?php echo esc_html($settings['pricing_title']); ?></h3>
                                                <?php } ?>
                                                <?php if(!empty($settings['pricing_sub_title'])){ ?>
                                                    <p class="description"><?php echo esc_html($settings['pricing_sub_title']); ?></p>
                                                <?php } ?>
                                                <div class="price-wrapper">
                                                    <span class="price-amount"><?php echo esc_html($settings['pricing_price_currency']); ?><?php echo esc_html($settings['pricing_price']); ?><sup><?php echo esc_html($settings['pricing_period']); ?></sup></span>
                                                </div>
                                                <div class="pricing-btn-group">
                                                    <?php if($settings['rbt_advance_pricing_pn_button_button_show'] === 'yes'){ ?>
                                                        <?php $this->rbt_link_control_render('advance_pricing_pn_button', $this->get_settings()); ?>
                                                    <?php } ?>
                                                    <?php if($settings['rbt_advance_pricing_ug_button_button_show'] === 'yes'){ ?>
                                                        <?php $this->rbt_link_control_render('advance_pricing_ug_button', $this->get_settings()); ?>
                                                    <?php } ?>
                                                </div>
                                                <?php if ($has_star): ?>
                                                    <div class="rating">
                                                        <ul>
                                                            <?php foreach (range(1, $rating) as $key): ?>
                                                                <li class="has-rating list-inline-item">
                                                                    <i class="star-icon">
                                                                        <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-star-fill" viewBox="0 0 16 16">
                                                                            <path d="M3.612 15.443c-.386.198-.824-.149-.746-.592l.83-4.73L.173 6.765c-.329-.314-.158-.888.283-.95l4.898-.696L7.538.792c.197-.39.73-.39.927 0l2.184 4.327 4.898.696c.441.062.612.636.282.95l-3.522 3.356.83 4.73c.078.443-.36.79-.746.592L8 13.187l-4.389 2.256z"/>
                                                                        </svg>
                                                                    </i>
                                                                </li>
                                                            <?php endforeach; ?>
                                                            <?php for ($i=1; $i <= $nonrating; $i++): ?>
                                                                <li class="nonrating list-inline-item">
                                                                    <i class="star-icon">
                                                                        <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-star-fill" viewBox="0 0 16 16">
                                                                            <path d="M3.612 15.443c-.386.198-.824-.149-.746-.592l.83-4.73L.173 6.765c-.329-.314-.158-.888.283-.95l4.898-.696L7.538.792c.197-.39.73-.39.927 0l2.184 4.327 4.898.696c.441.062.612.636.282.95l-3.522 3.356.83 4.73c.078.443-.36.79-.746.592L8 13.187l-4.389 2.256z"/>
                                                                        </svg>
                                                                    </i>
                                                                </li>
                                                            <?php endfor; ?>
                                                        </ul>
                                                    </div>
                                                <?php endif ?>
                                                <?php if($settings['rating_description']){ ?>
                                                    <span class="subtitle"><?php echo esc_html($settings['rating_description']); ?></span>
                                                <?php } ?>
                                            </div>
                                        </div>

                                        <?php if($settings['pricing_table_content']){ ?>
                                        <div class="col-lg-6">
                                            <div class="pricing-right">
                                                <div class="pricing-offer">


                                                    <?php foreach ($settings['pricing_table_content'] as $table ){ ?>

                                                    <div class="single-list">

                                                        <?php if($table['pricing_features_title']){ ?>
                                                            <h4 class="price-title"><?php echo esc_html($table['pricing_features_title']); ?></h4>
                                                        <?php } ?>

                                                        <?php  $lines = explode("\n", $table['pricing_features_list']); // or use PHP PHP_EOL constant ?>
                                                        <?php if(!empty($lines)){ ?>
                                                            <ul class="plan-offer-list">
                                                                <?php foreach ( $lines as $line ) {
                                                                    echo '<li><i class="feather-check"></i> '. trim( $line ) .'</li>';
                                                                } ?>
                                                            </ul>
                                                        <?php } ?>


                                                    </div>

                                                    <?php } ?>

                                                </div>
                                            </div>
                                        </div>
                                        <?php } ?>

                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php } ?>


            </div>
        </div>
        <!-- End Pricing Plan Area  -->
        <?php

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Advance_Pricing());