<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Advance_Tabs extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-advance-tabs';
    }

    public function get_title()
    {
        return esc_html__('Advance Tabs', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['tabs', 'advance', 'image tab', 'doob'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            '_tab',
            [
                'label' => esc_html__( 'Tab', 'doob' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'tab_title', [
                'label' => esc_html__( 'Tab Item', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'This is tab item title' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'tab_short_description', [
                'label' => esc_html__( 'Short Description', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__( 'Use Doob template you can build a corporate website a short time.' , 'doob' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'images',
            [
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );
        $repeater->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'tab_thumbnail',
                'default' => 'full',
                'separator' => 'before',
                'exclude' => [
                    'custom'
                ]
            ]
        );



        $repeater->add_control(
            'tab_description',
            [
                'label' => esc_html__('Description', 'doob'),
                'description' => rbt_get_allowed_html_desc( 'advance' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => 'Lorem ipsum dolor sit, amet consectetur adipisicing elit. Veniam laudantium neque cumque, magni, modi aut a dolores deleniti recusandae dolor quod aliquid aperiam. Delectus voluptate quam deserunt expedita temporibus ab!',
                'label_block' => true,
            ]
        );
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Repeater Tab', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'tab_title' => esc_html__( 'Our history', 'doob' ),
                    ],
                    [
                        'tab_title' => esc_html__( 'Our mission', 'doob' ),
                    ],
                    [
                        'tab_title' => esc_html__( 'Friendly Support', 'doob' ),
                    ],
                ],
                'title_field' => '{{{ tab_title }}}',
            ]
        );

        $this->add_control(
            'tab_layout',
            [
                'label' => esc_html__( 'Layout', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'left' => esc_html__('Left (Default)', 'doob'),
                    'right' => esc_html__('Right', 'doob'),
                    'top' => esc_html__('Top', 'doob'),
                    'bottom' => esc_html__('Bottom', 'doob'),
                ],
                'default' => 'left',
            ]
        );

        $this->end_controls_section();

        // Style Component
        $this->rbt_basic_style_controls('tabs_title', 'Title', '.rainbow-default-tab .tab-button .tabs__tab .nav-link .tab_title');
        $this->rbt_basic_style_controls('tabs_description', 'Description', '.rainbow-default-tab .rainbow-tab-content .tab_description');

        $this->rbt_section_style_controls('tabs_title_bg', 'Tab Item', '.rainbow-default-tab .tab-button .tabs__tab .nav-link.active');
        $this->rbt_section_style_controls('tabs_description_bg', 'Tab Content', '.rainbow-default-tab .rainbow-tab-content');

        // Area Style
        $this->rbt_section_style_controls('tabs_area', 'Area Style', '.rainbow-default-tab');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        // Image Settings
        if( $settings['tab_layout'] == '2'){
            $style_class = "rainbow-default-tab style-two";
        } else {
            $style_class = "rainbow-default-tab";
        }



        if( $settings['tab_layout'] == 'right'){
            ?>
            <div class="html-tabs <?php echo esc_attr($style_class); ?>">
                <div class="row row--30">

                    <div class="col-lg-8 col-md-12 col-sm-12 col-12">
                        <div class="tab-content" id="myTabContent-<?php echo esc_attr($this->get_id()); ?>">
                            <?php
                            foreach ( $settings['tabs'] as $index => $item ){
                                $active = ($index == '0') ? "show active" : "";
                                ?>
                                <div class="tab-pane fade advance-tab-content-1 <?php echo esc_attr($active); ?>" id="rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tabpanel">
                                    <div class="thumbnail">
                                        <?php if(!empty(wp_get_attachment_image( $item['images']['id']))){ ?>
                                            <?php echo wp_get_attachment_image( $item['images']['id'], $item['tab_thumbnail_size'] ); ?>
                                        <?php } else { ?>
                                            <?php echo Group_Control_Image_Size::get_attachment_image_html($item, 'full', 'images') ?>
                                        <?php } ?>

                                        <?php if(!empty($item['tab_description'])){ ?>
                                            <div class="advance-tab-content-inner mt--20">
                                                <?php echo rbt_kses_advance($item['tab_description']); ?>
                                            </div>
                                        <?php } ?>

                                    </div>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-12 col-sm-12 col-12 mt_md--30 mt_sm--30">
                        <div class="advance-tab-button advance-tab-button-1 right-align">
                            <ul class="nav nav-tabs tab-button-list" id="myTab-<?php echo esc_attr($this->get_id()); ?>" role="tablist">
                                <?php
                                foreach ( $settings['tabs'] as $index => $item ){
                                    $active = ($index == '0') ? "show active" : "";
                                    $aria_selected = ($index == '0' ) ? "true" : "false";
                                    ?>
                                    <li class="nav-item">
                                        <a class="nav-link tab-button <?php echo esc_attr($active); ?>" id="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" data-bs-toggle="tab" data-bs-target="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" href="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tab" aria-controls="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" aria-selected="<?php echo esc_attr($aria_selected); ?>">
                                            <div class="tab">
                                                <h4 class="title"><?php echo esc_html($item['tab_title']); ?></h4>
                                                <p class="description"><?php echo esc_html($item['tab_short_description']); ?></p>
                                            </div>
                                        </a>
                                    </li>
                                <?php } ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        } elseif( $settings['tab_layout'] == 'top') {
            ?>
            <div class="html-tabs <?php echo esc_attr($style_class); ?>">
                <div class="row row--30">

                    <div class="col-lg-12 mb--30">
                        <div class="advance-tab-button advance-tab-button-1 right-bottom">
                            <ul class="row nav nav-tabs tab-button-list" id="myTab-<?php echo esc_attr($this->get_id()); ?>" role="tablist">
                                <?php
                                foreach ( $settings['tabs'] as $index => $item ){
                                    $active = ($index == '0') ? "show active" : "";
                                    $aria_selected = ($index == '0' ) ? "true" : "false";
                                    ?>
                                    <li class="col-lg-4 nav-item text-center">
                                        <a class="nav-link tab-button <?php echo esc_attr($active); ?>" id="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" data-bs-toggle="tab" data-bs-target="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" href="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tab" aria-controls="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" aria-selected="<?php echo esc_attr($aria_selected); ?>">
                                            <div class="tab">
                                                <h4 class="title"><?php echo esc_html($item['tab_title']); ?></h4>
                                                <p class="description"><?php echo esc_html($item['tab_short_description']); ?></p>
                                            </div>
                                        </a>
                                    </li>
                                <?php } ?>
                            </ul>
                        </div>

                    </div>

                    <div class="col-lg-12">
                        <div class="tab-content" id="myTabContent-<?php echo esc_attr($this->get_id()); ?>">
                            <?php
                            foreach ( $settings['tabs'] as $index => $item ){
                                $active = ($index == '0') ? "show active" : "";
                                ?>
                                <div class="tab-pane fade advance-tab-content-1 <?php echo esc_attr($active); ?>" id="rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tabpanel">
                                    <div class="thumbnail">
                                        <?php if(!empty(wp_get_attachment_image( $item['images']['id']))){ ?>
                                            <?php echo wp_get_attachment_image( $item['images']['id'], $item['tab_thumbnail_size'] ); ?>
                                        <?php } else { ?>
                                            <?php echo Group_Control_Image_Size::get_attachment_image_html($item, 'full', 'images') ?>
                                        <?php } ?>

                                        <?php if(!empty($item['tab_description'])){ ?>
                                            <div class="advance-tab-content-inner mt--20">
                                                <?php echo rbt_kses_advance($item['tab_description']); ?>
                                            </div>
                                        <?php } ?>

                                    </div>
                                </div>
                            <?php } ?>
                        </div>
                    </div>

                </div>
            </div>
            <?php
        }  elseif( $settings['tab_layout'] == 'bottom') {
            ?>
            <div class="html-tabs <?php echo esc_attr($style_class); ?>">
                <div class="row row--30">

                    <div class="col-lg-12">
                        <div class="tab-content" id="myTabContent-<?php echo esc_attr($this->get_id()); ?>">
                            <?php
                            foreach ( $settings['tabs'] as $index => $item ){
                                $active = ($index == '0') ? "show active" : "";
                                ?>
                                <div class="tab-pane fade advance-tab-content-1 <?php echo esc_attr($active); ?>" id="rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tabpanel">
                                    <div class="thumbnail">
                                        <?php if(!empty(wp_get_attachment_image( $item['images']['id']))){ ?>
                                            <?php echo wp_get_attachment_image( $item['images']['id'], $item['tab_thumbnail_size'] ); ?>
                                        <?php } else { ?>
                                            <?php echo Group_Control_Image_Size::get_attachment_image_html($item, 'full', 'images') ?>
                                        <?php } ?>

                                        <?php if(!empty($item['tab_description'])){ ?>
                                            <div class="advance-tab-content-inner mt--20">
                                                <?php echo rbt_kses_advance($item['tab_description']); ?>
                                            </div>
                                        <?php } ?>

                                    </div>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                    <div class="col-lg-12 mt--30">
                        <div class="advance-tab-button advance-tab-button-1 right-top">
                            <ul class="row nav nav-tabs tab-button-list" id="myTab-<?php echo esc_attr($this->get_id()); ?>" role="tablist">
                                <?php
                                foreach ( $settings['tabs'] as $index => $item ){
                                    $active = ($index == '0') ? "show active" : "";
                                    $aria_selected = ($index == '0' ) ? "true" : "false";
                                    ?>
                                    <li class="col-lg-4 nav-item text-center">
                                        <a class="nav-link tab-button <?php echo esc_attr($active); ?>" id="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" data-bs-toggle="tab" data-bs-target="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" href="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tab" aria-controls="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" aria-selected="<?php echo esc_attr($aria_selected); ?>">
                                            <div class="tab">
                                                <h4 class="title"><?php echo esc_html($item['tab_title']); ?></h4>
                                                <p class="description"><?php echo esc_html($item['tab_short_description']); ?></p>
                                            </div>
                                        </a>
                                    </li>
                                <?php } ?>
                            </ul>
                        </div>

                    </div>
                </div>
            </div>
            <?php
        } else {
            ?>
            <div class="html-tabs <?php echo esc_attr($style_class); ?>">
                <div class="row row--30">
                    <div class="col-lg-4 col-md-12 col-sm-12 col-12 mt_md--30 mt_sm--30">
                        <div class="advance-tab-button advance-tab-button-1">
                            <ul class="nav nav-tabs tab-button-list" id="myTab-<?php echo esc_attr($this->get_id()); ?>" role="tablist">
                                <?php
                                foreach ( $settings['tabs'] as $index => $item ){
                                    $active = ($index == '0') ? "show active" : "";
                                    $aria_selected = ($index == '0' ) ? "true" : "false";
                                    ?>
                                    <li class="nav-item">
                                        <a class="nav-link tab-button <?php echo esc_attr($active); ?>" id="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" data-bs-toggle="tab" data-bs-target="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" href="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tab" aria-controls="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" aria-selected="<?php echo esc_attr($aria_selected); ?>">
                                            <div class="tab">
                                                <h4 class="title"><?php echo esc_html($item['tab_title']); ?></h4>
                                                <p class="description"><?php echo esc_html($item['tab_short_description']); ?></p>
                                            </div>
                                        </a>
                                    </li>
                                <?php } ?>
                            </ul>
                        </div>
                    </div>
                    <div class="col-lg-8 col-md-12 col-sm-12 col-12">
                        <div class="tab-content" id="myTabContent-<?php echo esc_attr($this->get_id()); ?>">
                            <?php
                            foreach ( $settings['tabs'] as $index => $item ){
                                $active = ($index == '0') ? "show active" : "";
                                ?>
                                <div class="tab-pane fade advance-tab-content-1 <?php echo esc_attr($active); ?>" id="rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tabpanel">
                                    <div class="thumbnail">
                                        <?php if(!empty(wp_get_attachment_image( $item['images']['id']))){ ?>
                                            <?php echo wp_get_attachment_image( $item['images']['id'], $item['tab_thumbnail_size'] ); ?>
                                        <?php } else { ?>
                                            <?php echo Group_Control_Image_Size::get_attachment_image_html($item, 'full', 'images') ?>
                                        <?php } ?>

                                        <?php if(!empty($item['tab_description'])){ ?>
                                            <div class="advance-tab-content-inner mt--20">
                                                <?php echo rbt_kses_advance($item['tab_description']); ?>
                                            </div>
                                        <?php } ?>

                                    </div>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Advance_Tabs());