<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Main_Banner extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-main-banner';
    }

    public function get_title()
    {
        return esc_html__('Main Banner', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['main banner', 'banner', 'creative main', 'doob'];
    }

    protected function register_controls()
    {

        // Title and content
        $this->rbt_section_title('title_and_content', 'Title & Content', 'DIGITAL CONSULTING main', 'Unique Business Consulting.', 'h1', 'We help our clients succeed by creating brand identities, digital experiences, and print materials.', 'text-center', false, true);
        $this->rbt_link_controls('button_one', 'Button One', 'Purchase Now');
        $this->rbt_link_controls('button_two', 'Button Two', 'Contact Us');
        // layout Panel
        $this->start_controls_section(
            'tp_layout',
            [
                'label' => esc_html__('Design Layout', 'tp-core'),
            ] 
        );
        $this->add_control(
            'tp_design_style', 
            [
                'label' => esc_html__('Select Layout', 'tp-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Financec Banner', 'tp-core'),
                    'layout-2' => esc_html__('Corporate Banner', 'tp-core'),
                    'layout-3' => esc_html__('Company Banner', 'tp-core'),
                    'layout-4' => esc_html__('Marketing Agency Banner', 'tp-core'),
                    'layout-5' => esc_html__('Consulting Banner', 'tp-core'),
                    'layout-6' => esc_html__('SEO Agency Banner', 'tp-core'),
                    'layout-7' => esc_html__('Personal Portfolio Banner', 'tp-core'),
                    'layout-8' => esc_html__('Event Conference Banner', 'tp-core'),
                    'layout-9' => esc_html__('Freelancer Banner', 'tp-core'),
                    'layout-10' => esc_html__('Collaborate Banner', 'tp-core'),
                ],
                'default' => 'layout-1',
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'advanced_option',
            [
                'label' => esc_html__('Advanced Options', 'doob'),
            ]
        );
        // Height Control
        $this->rbt_height_control();

        $this->add_control(
            'enable_parallax',
            [
                'label' => esc_html__( 'Enable Parallax', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'doob' ),
                'label_off' => esc_html__( 'No', 'doob' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'parallax_speed',
            [
                'label' => esc_html__( 'Parallax Speed', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1,
                        'step' => .1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 0.3,
                ],
                'condition' => [
                    'enable_parallax' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'enable_particles',
            [
                'label' => esc_html__( 'Enable Particles', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'doob' ),
                'label_off' => esc_html__( 'No', 'doob' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );
        $this->add_control(
            'enable_shap',
            [
                'label' => esc_html__( 'Enable Shap', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'doob' ),
                'label_off' => esc_html__( 'No', 'doob' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );
        $this->add_control(
            'particles_color',
            [
                'label' => esc_html__( 'Particles Color', 'doob' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'enable_particles' => 'yes',
                ],
            ]
        );
        $this->add_control(
            'particles_opacity',
            [
                'label' => esc_html__( 'Particles Opacity', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [ 
                    'px' => [
                        'min' => .1,
                        'max' => 1,
                        'step' => .1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 0.5,
                ],
                'condition' => [
                    'enable_particles' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'doob_banner_list',
            [
                'label' => esc_html__('Banner list', 'doob'),
                'condition' => [
                    'tp_design_style' => ['layout-2', 'layout-3']
                ]
            ]
        );
        $repeater = new \Elementor\Repeater();


        $repeater->add_control(
            'banner_icon_type',
            [
                'label' => esc_html__('Select Icon Type', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'image',
                'options' => [
                    'image' => esc_html__('Image', 'doob'),
                    'icon' => esc_html__('Icon', 'doob'),
                ],
            ]
        );

        $repeater->add_control(
            'banner_image',
            [
                'label' => esc_html__('Upload Image', 'doob'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'banner_icon_type' => 'image'
                ]

            ]
        );
        if (rbt_is_elementor_version('<', '2.6.0')) {
            $repeater->add_control(
                'banner_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'fa fa-star',
                    'condition' => [
                        'banner_icon_type' => 'icon'
                    ]
                ]
            );
        } else {
            $repeater->add_control(
                'banner_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-star',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'banner_icon_type' => 'icon'
                    ]
                ]
            ); 
        }
        $repeater->add_control(
            'banner_title', [
                'label' => esc_html__('Title', 'doob'),
                'description' => rbt_get_allowed_html_desc( 'basic' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('banner Title', 'doob'),
                'label_block' => true,
            ]
        );


        $this->add_control(
            'banner_list',
            [
                'label' => esc_html__('banners - List', 'doob'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'banner_title' => esc_html__('Business Stratagy', 'doob'),
                    ],
                    [
                        'banner_title' => esc_html__('Website Development', 'doob')
                    ],
                    [
                        'banner_title' => esc_html__('Marketing & Reporting', 'doob')
                    ],
    
                ],
                'title_field' => '{{{ banner_title }}}',
            ]
        );
        $this->end_controls_section();
              // _tp_image
		$this->start_controls_section(
            '_tp_image',
            [
                'label' => esc_html__('Thumbnail', 'tp-core'),
                'condition' => [
                    'tp_design_style' => ['layout-3', 'layout-4', 'layout-6', 'layout-8', 'layout-10']
                ]
            ]
         
        );
        $this->add_control(
            'tp_image',
            [
                'label' => esc_html__( 'Choose Image', 'tp-core' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );


        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'tp_image_size',
                'default' => 'full',
                'exclude' => [
                    'custom'
                ]
            ]
        );

       
        $this->end_controls_section();
		$this->start_controls_section(
            '_tp_hero_video',
            [
                'label' => esc_html__('Video Url', 'tp-core'),
                'condition' => [
                    'tp_design_style' => ['layout-8']
                ]
            ]
         
        );
        $this->add_control(
            'title',
            [
                'label' => esc_html__('Hero Video', 'doob'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('#.', 'doob'),
            ]
        );

        $this->end_controls_section();
        
        $this->start_controls_section(
            'sec_option_list',
            [
                'label' => esc_html__('Clip  List', 'doob'),
                'condition' => [
                    'tp_design_style' => ['layout-4']
                ]

            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'title',
            [
                'label' => esc_html__('Slide List Title', 'doob'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Finance.', 'doob'),
            ]
        );


        $this->add_control(
            'cd_option_list',
            [
                'label' => esc_html__('Slide List', 'doob'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),

                'default' => [

                    [
                        'title' => esc_html__('Finance.', 'doob'),
                    ],
                    [
                        'title' => esc_html__('Consulting.', 'doob'),
                    ],
                    [
                        'title' => esc_html__('Agency.', 'doob'),
                    ],

                ],
                'title_field' => '{{{ title }}}',
            ]
        );
        $this->end_controls_section();
  


        

        // Style Component
        $this->rbt_basic_style_controls('cb_before_title', 'Before Title', '.inner .subtitle');
        $this->rbt_basic_style_controls('cb_title', 'Title', '.inner .title');
        $this->rbt_basic_style_controls('cb_before_description', 'Description', '.inner .description');

        // Link style
        $this->rbt_link_controls_style('button_one_style', 'Button One', '.rbt-button');
        $this->rbt_link_controls_style('button_two_style', 'Button Two', '.rbt-button', 'btn-medium', 'btn-default btn-border');

        $this->rbt_section_style_controls('cb_area', 'Section Style', '.slider-area');
        $this->rbt_section_style_controls('cb_area_overlay', 'Section Style Overlay', '.slider-area:before');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();
        $this->add_render_attribute('title_args', 'class', 'title display-one');

        $parallax_ratio = '';
        $parallax_class = '';

        $enable_parallax = $settings['enable_parallax'];
        $parallax_speed = ($settings['parallax_speed']) ? $settings['parallax_speed']['size'] : "";
        if ($enable_parallax){
            $parallax_ratio = "data-stellar-background-ratio=\"$parallax_speed\"";
            $parallax_class = 'parallax';
        }
        $area_args = [
            'parallax'          => ('yes' === $settings['enable_parallax']),
            'particles'         => ('yes' === $settings['enable_particles']),
            'particles_color'   => $settings['particles_color'],
            'particles_opacity' => ($settings['particles_opacity']) ? $settings['particles_opacity']['size'] : "",
            'id'                => 'particles-js-'. $this->get_id()
        ];
        $this->add_render_attribute('doob-main-banner-data', 'data-settings', wp_json_encode($area_args));

        ?>

<?php if ( $settings['tp_design_style']  == 'layout-2' ):?>

<!-- Start Slider Area  -->
<div class="slider-area slider-style-1 variation-default height-950 bg_image slider-area" data-black-overlay="2">
    <div class="container">
        <div class="row">
            <div class="col-lg-12">
                <div class="inner <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                    <?php if (!empty($settings['rbt_title_and_content_before_title'])) { ?>
                    <h4 class="subtitle">
                        <span
                            class="theme-gradient"><?php echo rbt_kses_basic( $settings['rbt_title_and_content_before_title'] ); ?></span>
                    </h4>
                    <?php } ?>
                    <?php
                        if ($settings['rbt_title_and_content_title_tag']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['rbt_title_and_content_title_tag']),
                                $this->get_render_attribute_string('title_args'),
                                rbt_kses_intermediate($settings['rbt_title_and_content_title'])
                            );
                        endif;
                        ?>
                    <ul class="list-icon">
                        <?php foreach ($settings['banner_list'] as $item){ ?>
                        <li>
                            <span class="icon background-transparent">
                                <i class="feather-check"></i>
                            </span>
                            <?php if(!empty($item['banner_title'])){ ?>
                            <?php echo rbt_kses_basic( $item['banner_title'] ); ?>
                            <?php } ?>
                        </li>
                        <?php } ?>
                    </ul>
                    <?php if($settings['rbt_button_one_button_show'] === 'yes' || $settings['rbt_button_two_button_show'] === 'yes'){ ?>
                    <div class="button-group mt--40 mt_sm--20">
                        <?php
                        if($settings['rbt_button_one_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_one', $this->get_settings());
                        }
                        if($settings['rbt_button_two_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_two', $this->get_settings());
                        }
                        ?>
                    </div>
                    <?php } ?>
                </div>
            </div>
        </div>
    </div>
</div>
<!-- End Slider Area  -->
<?php elseif ( $settings['tp_design_style']  == 'layout-3' ):
     $this->add_render_attribute('title_args', 'class', 'title theme-gradient display-one');
     if ( !empty($settings['tp_image']['url']) ) {
        $tp_image = !empty($settings['tp_image']['id']) ? wp_get_attachment_image_url( $settings['tp_image']['id'], $settings['tp_image_size_size']) : $settings['tp_image']['url'];
        $tp_image_alt = get_post_meta($settings["tp_image"]["id"], "_wp_attachment_image_alt", true);
    }
?>
<!-- Start Slider Area  -->
<div class="slider-area slider-style-1 bg-transparent banner-company height-750 slider-area">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-7 col-xl-6 order-2 order-lg-1 mt_md--40 mt_sm--40">
                <div class="inner <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                    <?php if (!empty($settings['rbt_title_and_content_before_title'])) { ?>
                    <span
                        class="subtitle"><?php echo rbt_kses_basic( $settings['rbt_title_and_content_before_title'] ); ?>
                    </span>
                    <?php } ?>
                    <?php
                        if ($settings['rbt_title_and_content_title_tag']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['rbt_title_and_content_title_tag']),
                                $this->get_render_attribute_string('title_args'),
                                rbt_kses_intermediate($settings['rbt_title_and_content_title'])
                            );
                        endif;
                        ?>
                    <ul class="list-icon">
                        <?php foreach ($settings['banner_list'] as $item){ ?>
                        <li><span class="icon">
                                <i class="feather-check"></i>
                            </span>
                            <?php if(!empty($item['banner_title'])){ ?>
                            <?php echo rbt_kses_basic( $item['banner_title'] ); ?>
                            <?php } ?>
                        </li>
                        <?php } ?>
                    </ul>
                    <?php if($settings['rbt_button_one_button_show'] === 'yes' || $settings['rbt_button_two_button_show'] === 'yes'){ ?>
                    <div class="button-group mt--40">
                        <?php
                        if($settings['rbt_button_one_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_one', $this->get_settings());
                        }
                        if($settings['rbt_button_two_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_two', $this->get_settings());
                        }
                        ?>

                    </div>
                    <?php } ?>
                </div>
            </div>
            <div class="col-lg-5 col-xl-6 order-1 order-lg-2">
                <?php if(!empty($tp_image)) : ?>
                <div class="frame-image">
                    <img src="<?php echo esc_url($tp_image); ?>" alt="<?php echo esc_attr($tp_image_alt); ?>">
                </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>
<!-- End Slider Area  -->
<?php elseif ( $settings['tp_design_style']  == 'layout-4' ):
     $this->add_render_attribute('title_args', 'class', 'title theme-gradient display-one');
     if ( !empty($settings['tp_image']['url']) ) {
        $tp_image = !empty($settings['tp_image']['id']) ? wp_get_attachment_image_url( $settings['tp_image']['id'], $settings['tp_image_size_size']) : $settings['tp_image']['url'];
        $tp_image_alt = get_post_meta($settings["tp_image"]["id"], "_wp_attachment_image_alt", true);
    }
?>
<!-- Start Slider Area  -->
<div class="slider-area slider-style-1 bg-transparent variation-2 height-750 slider-area">
    <div class="container">
        <div class="row">
            <div class="col-lg-8 order-2 order-lg-1 mt_md--40 mt_sm--40">
                <div class="inner <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                    <h1 class="title theme-gradient display-two">
                        <?php echo rbt_kses_intermediate($settings['rbt_title_and_content_title']); ?>
                        <span class="header-caption">
                            <span class="cd-headline clip is-full-width">
                                <span class="cd-words-wrapper">
                                    <?php
                                        $i = "";
                                        $i == 1;
                                        foreach ($settings['cd_option_list'] as $cd_option_list):
                                            $vihi = $i == 1 ? 'visible' : 'hidden';
                                            $i++;
                                            $slide_title = $cd_option_list['title'];
                                            ?>
                                    <b
                                        class="is-<?php echo esc_attr($vihi); ?> theme-gradient"><?php echo esc_html($slide_title); ?></b>
                                    <?php endforeach; ?>
                                </span>
                            </span>
                        </span>
                    </h1>
                    <?php if (!empty($settings['rbt_title_and_content_desctiption'])) { ?>
                    <p class="description">
                        <?php echo rbt_kses_intermediate( $settings['rbt_title_and_content_desctiption'] ); ?></p>
                    <?php } ?>
                    <?php if($settings['rbt_button_one_button_show'] === 'yes' || $settings['rbt_button_two_button_show'] === 'yes'){ ?>
                    <div class="button-group">
                        <?php
                        if($settings['rbt_button_one_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_one', $this->get_settings());
                        }
                        if($settings['rbt_button_two_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_two', $this->get_settings());
                        }
                        ?>
                    </div>
                    <?php } ?>
                </div>
            </div>
            <div class="col-lg-4 order-1 order-lg-2">
                <?php if(!empty($tp_image)) : ?>
                <div class="thumbnail">
                    <img src="<?php echo esc_url($tp_image); ?>" alt="<?php echo esc_attr($tp_image_alt); ?>">
                </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>
<!-- End Slider Area  -->
<?php elseif ( $settings['tp_design_style']  == 'layout-5' ):
     $this->add_render_attribute('title_args', 'class', 'title display-one inner');
     if ( !empty($settings['tp_image']['url']) ) {
        $tp_image = !empty($settings['tp_image']['id']) ? wp_get_attachment_image_url( $settings['tp_image']['id'], $settings['tp_image_size_size']) : $settings['tp_image']['url'];
        $tp_image_alt = get_post_meta($settings["tp_image"]["id"], "_wp_attachment_image_alt", true);
    }
?>
<!-- Start Slider Area  -->
<div class="slider-area slider-style-2 variation-2 height-850 bg_image slider-area">
    <div class="container">
        <div class="row">
            <div class="col-lg-8 col-xl-6">
                <div class="inner <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                    <div class="inner <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                        <?php
                        if ($settings['rbt_title_and_content_title_tag']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['rbt_title_and_content_title_tag']),
                                $this->get_render_attribute_string('title_args'),
                                rbt_kses_intermediate($settings['rbt_title_and_content_title'])
                            );
                        endif;
                        ?>
                        <?php if (!empty($settings['rbt_title_and_content_before_title'])) { ?>
                        <h6 class="tag-title">
                            <?php echo rbt_kses_basic( $settings['rbt_title_and_content_before_title'] ); ?></h6>
                        <?php } ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<?php elseif ( $settings['tp_design_style']  == 'layout-6' ):
     $this->add_render_attribute('title_args', 'class', 'title color-white display-one inner');
     if ( !empty($settings['tp_image']['url']) ) {
        $tp_image = !empty($settings['tp_image']['id']) ? wp_get_attachment_image_url( $settings['tp_image']['id'], $settings['tp_image_size_size']) : $settings['tp_image']['url'];
        $tp_image_alt = get_post_meta($settings["tp_image"]["id"], "_wp_attachment_image_alt", true);
    }
?>
<!-- Start Slider Area  -->
<div class="slider-area slider-style-6 shape-right height-750 slider-area">
    <div class="container">
        <div class="row row--30 align-items-center">
            <div class="order-2 order-lg-1 col-lg-6 mt_md--50 mt_sm--50 mt_lg--30">
                <div class="inner <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                    <?php
                        if ($settings['rbt_title_and_content_title_tag']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['rbt_title_and_content_title_tag']),
                                $this->get_render_attribute_string('title_args'),
                                rbt_kses_intermediate($settings['rbt_title_and_content_title'])
                            );
                        endif;
                        ?>
                    <?php if (!empty($settings['rbt_title_and_content_desctiption'])) { ?>
                    <p class="description color-white">
                        <?php echo rbt_kses_intermediate( $settings['rbt_title_and_content_desctiption'] ); ?></p>
                    <?php } ?>
                    <?php if($settings['rbt_button_one_button_show'] === 'yes' || $settings['rbt_button_two_button_show'] === 'yes'){ ?>
                    <div class="button-group mt--30 mt_sm--20">
                        <?php
                        if($settings['rbt_button_one_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_one', $this->get_settings());
                        }
                        if($settings['rbt_button_two_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_two', $this->get_settings());
                        }
                        ?>
                    </div>
                    <?php } ?>
                </div>
            </div>
            <div class="col-lg-6 order-1 order-lg-2">
                <?php if(!empty($tp_image)) : ?>
                <div class="thumbnail">
                    <img src="<?php echo esc_url($tp_image); ?>" alt="<?php echo esc_attr($tp_image_alt); ?>">
                </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
    <div class="shape-image"><img src="<?php echo get_template_directory_uri(  ); ?>/assets/images/bg/white-shape.svg"
            alt="Banner Images"></div>
</div>
<!-- End Slider Area  -->
<?php elseif ( $settings['tp_design_style']  == 'layout-7' ):
     $this->add_render_attribute('title_args', 'class', 'title display-one inner');
     if ( !empty($settings['tp_image']['url']) ) {
        $tp_image = !empty($settings['tp_image']['id']) ? wp_get_attachment_image_url( $settings['tp_image']['id'], $settings['tp_image_size_size']) : $settings['tp_image']['url'];
        $tp_image_alt = get_post_meta($settings["tp_image"]["id"], "_wp_attachment_image_alt", true);
    }
?>
<!-- Start Slider Area  -->
<div class="slider-perosonal-portfolio height-750 slider-bg-image slider-area" data-black-overlay="1">
    <div class="container">
        <div class="row row--30 align-items-center">
            <div class="col-12">
                <div class="inner <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                    <?php
                        if ($settings['rbt_title_and_content_title_tag']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['rbt_title_and_content_title_tag']),
                                $this->get_render_attribute_string('title_args'),
                                rbt_kses_intermediate($settings['rbt_title_and_content_title'])
                            );
                        endif;
                        ?>
                    <div class="button-group mt--30">
                        <?php
                        if($settings['rbt_button_one_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_one', $this->get_settings());
                        }
                        if($settings['rbt_button_two_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_two', $this->get_settings());
                        }
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!-- End Slider Area  -->
<?php elseif ( $settings['tp_design_style']  == 'layout-8' ):
     $this->add_render_attribute('title_args', 'class', 'title color-white display-one inner');
     if ( !empty($settings['tp_image']['url']) ) {
        $tp_image = !empty($settings['tp_image']['id']) ? wp_get_attachment_image_url( $settings['tp_image']['id'], $settings['tp_image_size_size']) : $settings['tp_image']['url'];
        $tp_image_alt = get_post_meta($settings["tp_image"]["id"], "_wp_attachment_image_alt", true);
    }
?>
<!-- Start Slider Area  -->
<div class="slider-area slider-style-6 shape-left inheader-not-transparent height-750">
    <div class="container">
        <div class="row row--30 align-items-center">
            <div class="order-2 order-lg-1 col-lg-6 mt_md--50 mt_sm--50 mt_lg--30">
                <div class="inner <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                    <?php
                        if ($settings['rbt_title_and_content_title_tag']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['rbt_title_and_content_title_tag']),
                                $this->get_render_attribute_string('title_args'),
                                rbt_kses_intermediate($settings['rbt_title_and_content_title'])
                            );
                        endif;
                        ?>
                    <?php if (!empty($settings['rbt_title_and_content_desctiption'])) { ?>
                    <p class="description color-white">
                        <?php echo rbt_kses_intermediate( $settings['rbt_title_and_content_desctiption'] ); ?></p>
                    <?php } ?>
                        <?php if($settings['rbt_button_one_button_show'] === 'yes' || $settings['rbt_button_two_button_show'] === 'yes'){ ?>
                    <div class="button-group mt--30 mt_sm--20">
                        <?php
                        if($settings['rbt_button_one_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_one', $this->get_settings());
                        }
                        if($settings['rbt_button_two_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_two', $this->get_settings());
                        }
                        ?>
                    </div>
                    <?php } ?>
                </div>
            </div>
            <div class="col-lg-6 order-1 order-lg-2">
                <div class="video-btn">
                    <div class="video-popup icon-center">
                        <div class="overlay-content">
                            <?php if(!empty($tp_image)) : ?>
                            <div class="thumbnail"><img src="<?php echo esc_url($tp_image); ?>"
                                    alt="<?php echo esc_attr($tp_image_alt); ?>"></div>
                            <?php endif; ?>
                            <div class="video-icon">
                                <a class="btn-default rounded-player popup-video"
                                    href=" <?php echo rbt_kses_intermediate( $settings['title'] ); ?>">
                                    <span><i class="feather-play"></i></span>
                                </a>
                            </div>
                        </div>
                    </div>
                    <div class="video-lightbox-wrapper"></div>
                </div>
            </div>
        </div>
    </div>
    <div class="shape-image"><img src="<?php echo get_template_directory_uri(  ); ?>/assets/images/bg/white-shape.svg"
            alt="Banner Images"></div>
</div>
<!-- End Slider Area  -->
<?php elseif ( $settings['tp_design_style']  == 'layout-9' ):
     $this->add_render_attribute('title_args', 'class', 'title display-one inner');
     if ( !empty($settings['tp_image']['url']) ) {
        $tp_image = !empty($settings['tp_image']['id']) ? wp_get_attachment_image_url( $settings['tp_image']['id'], $settings['tp_image_size_size']) : $settings['tp_image']['url'];
        $tp_image_alt = get_post_meta($settings["tp_image"]["id"], "_wp_attachment_image_alt", true);
    }
?>
<!-- Start Slider Area  -->
<div class="slider-area slider-style-2 variation-3 height-850 slider-bg-image bg_image bg_image--22 theme-shape slider-area">
    <div class="container">
        <div class="row">
            <div class="col-lg-6">
                <div class="inner <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                    <?php
                        if ($settings['rbt_title_and_content_title_tag']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['rbt_title_and_content_title_tag']),
                                $this->get_render_attribute_string('title_args'),
                                rbt_kses_intermediate($settings['rbt_title_and_content_title'])
                            );
                        endif;
                        ?>
                    <?php if (!empty($settings['rbt_title_and_content_desctiption'])) { ?>
                    <p class="description color-white">
                        <?php echo rbt_kses_intermediate( $settings['rbt_title_and_content_desctiption'] ); ?></p>
                    <?php } ?>
                    <?php if($settings['rbt_button_one_button_show'] === 'yes' || $settings['rbt_button_two_button_show'] === 'yes'){ ?>
                    <div class="button-group mt--40 mt_sm--20">
                    <?php
                        if($settings['rbt_button_one_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_one', $this->get_settings());
                        }
                        if($settings['rbt_button_two_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_two', $this->get_settings());
                        }
                        ?>
                    </div>
                    <?php } ?>
                </div>
            </div>
        </div>
    </div>
</div>
<?php elseif ( $settings['tp_design_style']  == 'layout-10' ):
     $this->add_render_attribute('title_args', 'class', 'display-two title inner ');
     if ( !empty($settings['tp_image']['url']) ) {
        $tp_image = !empty($settings['tp_image']['id']) ? wp_get_attachment_image_url( $settings['tp_image']['id'], $settings['tp_image_size_size']) : $settings['tp_image']['url'];
        $tp_image_alt = get_post_meta($settings["tp_image"]["id"], "_wp_attachment_image_alt", true);
    }
?>
            <!-- Start Slider Area  -->
            <div class="slider-area rainbow-section-gap slider-area">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6 col-md-6 col-sm-6 col-sm-12 order-2 order-lg-1">
                        <div class="inner collaborate <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                            <?php
                                if ($settings['rbt_title_and_content_title_tag']) :
                                    printf('<%1$s %2$s>%3$s</%1$s>',
                                        tag_escape($settings['rbt_title_and_content_title_tag']),
                                        $this->get_render_attribute_string('title_args'),
                                        rbt_kses_intermediate($settings['rbt_title_and_content_title'])
                                    );
                                endif;
                            ?>
                               <?php if (!empty($settings['rbt_title_and_content_desctiption'])) { ?>
                                    <p class="description color-white">
                                         <?php echo rbt_kses_intermediate( $settings['rbt_title_and_content_desctiption'] ); ?>
                                    </p>
                                <?php } ?>
                            <?php if($settings['rbt_button_one_button_show'] === 'yes' || $settings['rbt_button_two_button_show'] === 'yes'){ ?>
                            <div class="button-group">
                            <?php
                                if($settings['rbt_button_one_button_show'] === 'yes'){
                                    $this->rbt_link_control_render('button_one', $this->get_settings());
                                }
                                if($settings['rbt_button_two_button_show'] === 'yes'){
                                    $this->rbt_link_control_render('button_two', $this->get_settings());
                                }
                            ?>
                            </div>
                            <?php } ?>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-6 col-sm-12 order-1 order-lg-2">
                    <?php if(!empty($tp_image)) : ?>
                            <div class="thumbnail"><img src="<?php echo esc_url($tp_image); ?>"
                                    alt="<?php echo esc_attr($tp_image_alt); ?>"></div>
                            <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
        <!-- Start Slider Area  -->
<?php else:?>
<!-- Start Slider Area  -->
<div class="slider-area slider-bg-image slider-style-5 bg-overlay-solid height-850 bg_image slider-area" data-black-overlay="3">
    <div class="container">
        <div class="row">
            <div class="col-lg-12">
                <div class="inner <?php echo esc_attr($settings['rbt_title_and_content_align']) ?>">
                    <?php if (!empty($settings['rbt_title_and_content_before_title'])) { ?>
                    <h4 class="subtitle">
                        <?php echo rbt_kses_basic( $settings['rbt_title_and_content_before_title'] ); ?></h4>
                    <?php } ?>
                    <?php
                        if ($settings['rbt_title_and_content_title_tag']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['rbt_title_and_content_title_tag']),
                                $this->get_render_attribute_string('title_args'),
                                rbt_kses_intermediate($settings['rbt_title_and_content_title'])
                            );
                        endif;
                        ?>
                    <?php if($settings['rbt_button_one_button_show'] === 'yes' || $settings['rbt_button_two_button_show'] === 'yes'){ ?>
                    <div class="button-group mt--40 mt_sm--20">
                        <?php
                        if($settings['rbt_button_one_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_one', $this->get_settings());
                        }
                        if($settings['rbt_button_two_button_show'] === 'yes'){
                            $this->rbt_link_control_render('button_two', $this->get_settings());
                        }
                        ?>
                    </div>
                    <?php } ?>
                </div>
            </div>
        </div>
    </div>
</div>
<!-- End Slider Area  -->
<?php
endif; 
    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Main_Banner());