<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Blog extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-blog';
    }

    public function get_title()
    {
        return esc_html__('Blog', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['blog', 'news', 'post', 'doob'];
    }

    protected function register_controls()
    {


        // Section Title
        $this->rbt_section_title('blog', 'Section - Title and Content', '', 'Latest News', 'h2', 'There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration.');

        // Blog Query
        $this->rbt_query_controls('blog', 'Blog - ');


        // layout Panel
        $this->start_controls_section(
            'doob_blog',
            [
                'label' => esc_html__('Blog - Layout', 'doob'),
            ]
        );
        $this->add_control(
            'tp_design_style',
            [
                'label' => esc_html__('Select Layout', 'tpcore'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout 1', 'tpcore'),
                    'layout-2' => esc_html__('Layout 2', 'tpcore'),
                    'layout-3' => esc_html__('Layout 3', 'tpcore'),
                ],
                'default' => 'layout-1',
            ]
        );
        $this->add_control(
            'doob_blog_height',
            [
                'label' => esc_html__( 'Height', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-card' => 'min-height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'tp_design_style' => ['layout-1', 'layout-2']
               ]
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'blog_thumb_size', // // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
                'exclude' => ['custom'],
                'default' => 'doob-thumbnail-single',
                'condition' => [
                    'tp_design_style' => ['layout-1', 'layout-2']
               ]
            ]
        );

        $this->add_control(
            'doob_blog_category',
            [
                'label' => esc_html__( 'Category', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'doob' ),
                'label_off' => esc_html__( 'Hide', 'doob' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'doob_blog_button',
            [
                'label' => esc_html__( 'Button', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'doob' ),
                'label_off' => esc_html__( 'Hide', 'doob' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'doob_blog_date',
            [
                'label' => esc_html__( 'Date', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'doob' ),
                'label_off' => esc_html__( 'Hide', 'doob' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'doob_blog_pagination',
            [
                'label' => esc_html__( 'Pagination', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'doob' ),
                'label_off' => esc_html__( 'Hide', 'doob' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->end_controls_section();

        // Columns Panel
        $this->rbt_columns('blog_columns', 'Blog - Columns', '4', '6', '6', '12');
        // Style Component
        $this->rbt_basic_style_controls('blog_section_title_before_title', 'Section - Before Title', '.section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('blog_section_title_title', 'Section - Title', '.section-title .title');
        $this->rbt_basic_style_controls('blog_section_title_description', 'Section - Description', '.section-title p');

        // Gallery
        $this->rbt_basic_style_controls('blog_title', 'Blog - Title', '.im_box .content .title a');
        $this->rbt_basic_style_controls('blog_description', 'Blog - Category', '.im_box .content .category_list span');

        // Area
        $this->rbt_section_style_controls('blog_area', 'Section Style', '.rn-blog-area');


    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        $Doob_Helper = new \Doob_Helper();
        $doob_options = $Doob_Helper->doob_get_options();
        /**
         * Setup the post arguments.
         */
        $query_args = RBT_Helper::get_query_args('post', 'category', $this->get_settings());

        // The Query
        $query = new \WP_Query($query_args);

        $this->add_render_attribute('doob-blog', 'class', 'rn-blog-area rn-section-gap bg_color--1');
        $this->add_render_attribute('doob-blog', 'id', 'doob-blog-' . esc_attr($this->get_id()));
      
        ?>
<?php if ( $settings['tp_design_style']  == 'layout-2' ): 

?>
<!-- Start blog Area  -->
<div class="rn-blog-area ptb--120 bg_color--5" id="doob-blog-<?php echo esc_attr($this->get_id()) ?>">
    <div class="container">

        <?php if($settings['rbt_blog_section_title_show'] == 'yes'){ ?>
        <div class="row">
            <div class="col-lg-12">
                <div class="section-title section-title--2 <?php echo esc_attr($settings['rbt_blog_align']) ?>">
                    <?php $this->rbt_section_title_render('blog', $this->get_settings()); ?>
                </div>
            </div>
        </div>
        <?php } ?>


        <?php if ($query->have_posts()) { ?>
        <div class="row row--15">
            <?php while ($query->have_posts()) {
                            $query->the_post();
                            global $post;
                            $terms = get_the_terms($post->ID, 'category'); ?>
            <!-- Start Blog Area  -->
            <div
                class="mt--30 col-lg-<?php echo esc_attr($settings['rbt_blog_columns_for_desktop']); ?> col-md-<?php echo esc_attr($settings['rbt_blog_columns_for_laptop']); ?> col-sm-<?php echo esc_attr($settings['rbt_blog_columns_for_tablet']); ?> col-<?php echo esc_attr($settings['rbt_blog_columns_for_mobile']); ?>">
                <div class="rainbow-card box-card-style-default">
                    <div class="inner">
                        <?php if(has_post_thumbnail()){ ?>
                        <div class="thumbnail">
                            <a href="<?php the_permalink(); ?>" class="image">
                                <?php echo get_the_post_thumbnail( $post->ID, $settings['blog_thumb_size_size'], array( 'class' => 'w-100' ) ); ?>
                            </a>
                        </div>
                        <?php } ?>
                        <div class="content">
                            <div class="content_heading">
                                <ul class="rainbow-meta-list">
                                    <?php if($settings['doob_blog_category'] == 'yes'){ ?>
                                    <?php if ($terms && !is_wp_error($terms)): ?>
                                    <?php foreach ($terms as $term) { ?>
                                    <li><a
                                            href="<?php echo get_category_link($term->term_id); ?>"><span><?php echo esc_html($term->name); ?></span></a>
                                    </li>
                                    <?php } ?>
                                    <?php endif ?>
                                    <?php } ?>
                                    <?php if (!empty($settings['doob_blog_date'])):?>
                                    <?php if($settings['doob_blog_date'] == 'yes'){ ?>
                                    <li class="separator">/</li>
                                    <li><?php the_time( get_option('date_format') ); ?></li>
                                    <?php } ?>
                                    <?php endif; ?>
                                </ul>
                                <h4 class="title mt--0"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                </h4>
                            </div>
                            <?php if ($doob_options['doob_enable_readmore_btn'] == 'yes') { ?>
                                <?php if($settings['doob_blog_button'] == 'yes'){ ?>
                                <div class="content_footer mt--20">
                                    <div class="blog-btn">
                                        <a class="btn-default btn-small btn-border"
                                            href="<?php the_permalink(); ?>"><?php echo esc_html($doob_options['doob_readmore_text']); ?></a>
                                    </div>
                                </div>
                                <?php } ?>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End Blog Area  -->
            <?php } ?>
            <?php if($settings['doob_blog_pagination'] == 'yes' && '-1' != $settings['posts_per_page'] ){ ?>
            <div class="col-lg-12">
                <div class="rn-pagination text-center mt--60 mt_sm--30">
                    <?php
                                    $big = 999999999; // need an unlikely integer

                                    if (get_query_var('paged')) {
                                        $paged = get_query_var('paged');
                                    } else if (get_query_var('page')) {
                                        $paged = get_query_var('page');
                                    } else {
                                        $paged = 1;
                                    }

                                    echo paginate_links( array(
                                        'base'       => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
                                        'format'     => '?paged=%#%',
                                        'current'    => $paged,
                                        'total'      => $query->max_num_pages,
                                        'type'       =>'list',
                                        'prev_text'  =>'<i class="fas fa-angle-left"></i>',
                                        'next_text'  =>'<i class="fas fa-angle-right"></i>',
                                        'show_all'   => false,
                                        'end_size'   => 1,
                                        'mid_size'   => 4,
                                    ) );
                                    ?>
                </div>
            </div>
            <?php } ?>
            <?php wp_reset_postdata(); ?>
        </div>
        <?php } ?>



    </div>
</div>
<!-- Start blog Area  -->
<?php elseif ( $settings['tp_design_style']  == 'layout-3' ): 

?>
<div class="main-content">
    <div class="rainbow-blog-area rainbow-section-gap">
        <div class="container">
            <div class="row mt_dec--30">
                <div class="col-lg-12">

                    <?php if ($query->have_posts()) { ?>
                    <div class="row row--15">
                        <?php while ($query->have_posts()) {
                                $query->the_post();
                                global $post;
                                $terms = get_the_terms($post->ID, 'category'); 
                            ?>
                        <div
                            class="mt--30 col-lg-<?php echo esc_attr($settings['rbt_blog_columns_for_desktop']); ?> col-md-<?php echo esc_attr($settings['rbt_blog_columns_for_laptop']); ?> col-sm-<?php echo esc_attr($settings['rbt_blog_columns_for_tablet']); ?> col-<?php echo esc_attr($settings['rbt_blog_columns_for_mobile']); ?> mt--30">
                            <div class="rainbow-card box-card-style-default card-list-view">
                                <div class="inner">
                                    <?php if(has_post_thumbnail()){ ?>
                                    <div class="thumbnail">
                                        <a href="<?php the_permalink(); ?>" class="image">
                                            <?php echo get_the_post_thumbnail( $post->ID, $settings['blog_thumb_size_size'], array( 'class' => 'w-100' ) ); ?>
                                        </a>
                                    </div>
                                    <?php } ?>
                                    <div class="content">
                                        <h4 class="title mt--0"><a
                                                href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                            <ul class="rainbow-meta-list mt--10">
                                                <?php if($settings['doob_blog_category'] == 'yes'){ ?>
                                                    <?php if ($terms && !is_wp_error($terms)): ?>
                                                        <?php foreach ($terms as $term) { ?>
                                                            <li><a
                                                                        href="<?php echo get_category_link($term->term_id); ?>"><span><?php echo esc_html($term->name); ?></span></a>
                                                            </li>
                                                        <?php } ?>
                                                    <?php endif ?>
                                                <?php } ?>
                                                <?php if (!empty($settings['doob_blog_date'])):?>
                                                    <?php if($settings['doob_blog_date'] == 'yes'){ ?>
                                                        <li class="separator">/</li>
                                                        <li><?php the_time( get_option('date_format') ); ?></li>
                                                    <?php } ?>
                                                <?php endif; ?>
                                            </ul>
                                            <p class="descriptiion"><?php echo wp_trim_words(get_the_excerpt(), 15); ?>
                                            </p>
                                            <?php if ($doob_options['doob_enable_readmore_btn'] == 'yes') { ?>
                                                <?php if($settings['doob_blog_button'] == 'yes'){ ?>
                                                    <div class="content_footer mt--20">
                                                        <div class="blog-btn">
                                                            <a class="btn-default btn-small btn-border"
                                                               href="<?php the_permalink(); ?>"><?php echo esc_html($doob_options['doob_readmore_text']); ?></a>
                                                        </div>
                                                    </div>
                                                <?php } ?>
                                            <?php } ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php } ?>
                    </div>
                    <?php } ?>
                </div>
                <?php if($settings['doob_blog_pagination'] == 'yes' && '-1' != $settings['posts_per_page'] ){ ?>
                    <div class="col-lg-12">
                        <div class="rn-pagination text-center mt--60 mt_sm--30">
                            <?php
                            $big = 999999999; // need an unlikely integer

                            if (get_query_var('paged')) {
                                $paged = get_query_var('paged');
                            } else if (get_query_var('page')) {
                                $paged = get_query_var('page');
                            } else {
                                $paged = 1;
                            }

                            echo paginate_links( array(
                                'base'       => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
                                'format'     => '?paged=%#%',
                                'current'    => $paged,
                                'total'      => $query->max_num_pages,
                                'type'       =>'list',
                                'prev_text'  =>'<i class="fas fa-angle-left"></i>',
                                'next_text'  =>'<i class="fas fa-angle-right"></i>',
                                'show_all'   => false,
                                'end_size'   => 1,
                                'mid_size'   => 4,
                            ) );
                            ?>
                        </div>
                    </div>
                <?php } ?>
                <?php wp_reset_postdata(); ?>
            </div>
        </div>
    </div>
</div>

<?php else : 
	$this->add_render_attribute('title_args', 'class', 'tp-section-title');	
?>
<!-- Start blog Area  -->
<div class="rn-blog-area ptb--120 bg_color--5" id="doob-blog-<?php echo esc_attr($this->get_id()) ?>">
    <div class="container">

        <?php if($settings['rbt_blog_section_title_show'] == 'yes'){ ?>
        <div class="row">
            <div class="col-lg-12">
                <div class="section-title section-title--2 <?php echo esc_attr($settings['rbt_blog_align']) ?>">
                    <?php $this->rbt_section_title_render('blog', $this->get_settings()); ?>
                </div>
            </div>
        </div>
        <?php } ?>


        <?php if ($query->have_posts()) { ?>
        <div class="row row--15">
            <?php while ($query->have_posts()) {
                $query->the_post();
                global $post;
                $terms = get_the_terms($post->ID, 'category'); 
            ?>
            <!-- Start Blog Area  -->
            <div
                class="mt--30 col-lg-<?php echo esc_attr($settings['rbt_blog_columns_for_desktop']); ?> col-md-<?php echo esc_attr($settings['rbt_blog_columns_for_laptop']); ?> col-sm-<?php echo esc_attr($settings['rbt_blog_columns_for_tablet']); ?> col-<?php echo esc_attr($settings['rbt_blog_columns_for_mobile']); ?>">
                <div class="rainbow-card box-card-style-default">
                    <div class="inner">
                        <?php if(has_post_thumbnail()){ ?>
                        <div class="thumbnail">
                            <a href="<?php the_permalink(); ?>" class="image">
                                <?php echo get_the_post_thumbnail( $post->ID, $settings['blog_thumb_size_size'], array( 'class' => 'w-100' ) ); ?>
                            </a>
                        </div>
                        <?php } ?>
                        <div class="content">
                            <div class="content_heading">
                                <ul class="rainbow-meta-list">
                                    <?php if($settings['doob_blog_category'] == 'yes'){ ?>
                                        <?php if ($terms && !is_wp_error($terms)): ?>
                                            <?php foreach ($terms as $term) { ?>
                                                <li><a
                                                            href="<?php echo get_category_link($term->term_id); ?>"><span><?php echo esc_html($term->name); ?></span></a>
                                                </li>
                                            <?php } ?>
                                        <?php endif ?>
                                    <?php } ?>
                                    <?php if (!empty($settings['doob_blog_date'])):?>
                                        <?php if($settings['doob_blog_date'] == 'yes'){ ?>
                                            <li class="separator">/</li>
                                            <li><?php the_time( get_option('date_format') ); ?></li>
                                        <?php } ?>
                                    <?php endif; ?>
                                </ul>
                                <h4 class="title mt--0"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                </h4>
                            </div>
                            <?php if ($doob_options['doob_enable_readmore_btn'] == 'yes') { ?>
                                <?php if($settings['doob_blog_button'] == 'yes'){ ?>
                                    <div class="content_footer mt--20">
                                        <div class="blog-btn">
                                            <a class="btn-default btn-small btn-border"
                                               href="<?php the_permalink(); ?>"><?php echo esc_html($doob_options['doob_readmore_text']); ?></a>
                                        </div>
                                    </div>
                                <?php } ?>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End Blog Area  -->
            <?php } ?>
            <?php
                        if($settings['doob_blog_pagination'] == 'yes' && '-1' != $settings['posts_per_page'] ){ ?>
            <div class="col-lg-12">
                <div class="rn-pagination text-center mt--60 mt_sm--30">
                    <?php
                                    $big = 999999999; // need an unlikely integer

                                    if (get_query_var('paged')) {
                                        $paged = get_query_var('paged');
                                    } else if (get_query_var('page')) {
                                        $paged = get_query_var('page');
                                    } else {
                                        $paged = 1;
                                    }

                                    echo paginate_links( array(
                                        'base'       => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
                                        'format'     => '?paged=%#%',
                                        'current'    => $paged,
                                        'total'      => $query->max_num_pages,
                                        'type'       =>'list',
                                        'prev_text'  =>'<i class="fas fa-angle-left"></i>',
                                        'next_text'  =>'<i class="fas fa-angle-right"></i>',
                                        'show_all'   => false,
                                        'end_size'   => 1,
                                        'mid_size'   => 4,
                                    ) );
                                    ?>
                </div>
            </div>
            <?php } ?>
            <?php wp_reset_postdata(); ?>
        </div>
        <?php } ?>



    </div>
</div>
<!-- Start blog Area  -->
<?php
endif;
    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Blog());