<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Brand extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-brand';
    }

    public function get_title()
    {
        return esc_html__('Brand', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['brand', 'brand', 'brand logo', 'logo', 'customer', 'doob'];
    }

    protected function register_controls()
    {

        // Section Title
        $this->rbt_section_title('brand', 'Section - Title and Content', 'Top clients', 'We worked with brands.', 'h2', '');


        $this->start_controls_section(
            'doob_brand',
            [
                'label' => esc_html__('Brand', 'doob'),
            ]
        );

        $this->add_control(
            'brand_style',
            [
                'label' => esc_html__('Select Style', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '1',
                'options' => [
                    '1' => esc_html__('Border', 'doob'),
                    '2' => esc_html__('Flat Style', 'doob'),
                    '3' => esc_html__('Flat Style - Alt', 'doob'),
                    '4' => esc_html__('Slider', 'doob'),
                ],

            ]
        );

        $this->add_control(
            'brand_custom_column',
            [
                'label' => esc_html__('Custom Column', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '1',
                'options' => [
                    '1' => esc_html__('None', 'doob'),
                    '2' => esc_html__('Yes, Custom Column', 'doob'),
                ],

            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'brand_logo_image',
            [
                'label' => esc_html__('Logo', 'doob'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'brand_logo_link',
            [
                'label' => esc_html__( 'Website Url', 'doob' ),
                'type' => \Elementor\Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'doob' ),
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
            ]
        );

        $repeater->add_control(
            'brand_logo_name',
            [
                'label' => esc_html__('Brand Name', 'doob'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Brand Name', 'doob'),
            ]
        );

        $this->add_control(
            'brand_logo_list',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ brand_logo_name }}}',
                'default' => [
                    ['brand_logo_image' => ['url' => Utils::get_placeholder_image_src()]],
                    ['brand_logo_image' => ['url' => Utils::get_placeholder_image_src()]],
                    ['brand_logo_image' => ['url' => Utils::get_placeholder_image_src()]],
                    ['brand_logo_image' => ['url' => Utils::get_placeholder_image_src()]],
                    ['brand_logo_image' => ['url' => Utils::get_placeholder_image_src()]],
                    ['brand_logo_image' => ['url' => Utils::get_placeholder_image_src()]],
                ]
            ]
        );

        $this->start_controls_tabs(
            '_tabs_brand_image_effects',
            [
                'separator' => 'before',

            ]
        );
        $this->start_controls_tab( 'normal',
            [
                'label' => __( 'Normal', 'doob' ),
            ]
        );
        $this->add_group_control(
            Group_Control_Css_Filter::get_type(),
            [
                'name' => 'brand_css_filters',
                'label' => esc_html__('Image Effect', 'doob'),
                'selector' => '{{WRAPPER}} ul.brand-list li img',
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab( 'hover',
            [
                'label' => __( 'Hover', 'doob' ),
            ]
        );
        $this->add_group_control(
            Group_Control_Css_Filter::get_type(),
            [
                'name' => 'brand_css_filters_hover',
                'label' => esc_html__('Image Effect', 'doob'),
                'selector' => '{{WRAPPER}} ul.brand-list li:hover img',
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_control(
            'custom_class',
            [
                'label' => esc_html__('Add Custom Class', 'doob'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'doob_brand_dots',
            [
                'label' => esc_html__('Dots?', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'doob'),
                'label_off' => esc_html__('Hide', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => array(
                    'brand_style' => '4'
                ),
            ]
        );
        $this->add_control(
            'doob_brand_arrow',
            [
                'label' => esc_html__('Arrow Icons?', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'doob'),
                'label_off' => esc_html__('Hide', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => array(
                    'brand_style' => '4'
                ),
            ]
        );
        $this->add_control(
            'doob_brand_infinite',
            [
                'label' => esc_html__('Infinite?', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'doob'),
                'label_off' => esc_html__('No', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => array(
                    'brand_style' => '4'
                ),
            ]
        );
        $this->add_control(
            'doob_brand_autoplay',
            [
                'label' => esc_html__('Autoplay?', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'doob'),
                'label_off' => esc_html__('No', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => array(
                    'brand_style' => '4'
                ),
            ]
        );
        $this->add_control(
            'doob_brand_autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'doob'),
                'type' => Controls_Manager::TEXT,
                'default' => '2500',
                'title' => esc_html__('Enter autoplay speed', 'doob'),
                'label_block' => true,
                'condition' => array(
                    'doob_brand_autoplay' => 'yes',
                    'brand_style' => '4'
                ),
            ]
        );

        $this->end_controls_section();

        // Columns Panel
        $this->rbt_columns('brand_columns', 'Brand - Columns', '4', '6', '6', '12');

        $this->rbt_columns_carousel('brand_carousel_columns', 'Brand - Columns for Carousel Layout', '5', '3', '2', '2', '1');


        // Style Component
        $this->rbt_basic_style_controls('brand_section_title_before_title', 'Section - Before Title', '.section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('brand_section_title_title', 'Section - Title', '.section-title .title');
        $this->rbt_basic_style_controls('brand_section_title_description', 'Section - Description', '.section-title p');

        // Area
        $this->rbt_section_style_controls('brand_area', 'Section Style', '.rainbow-brand-area');


    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();


        $carousel_args = [
            'arrows' => ('yes' === $settings['doob_brand_arrow']),
            'dots' => ('yes' === $settings['doob_brand_dots']),
            'autoplay' => ('yes' === $settings['doob_brand_autoplay']),
            'autoplay_speed' => absint($settings['doob_brand_autoplay_speed']),
            'infinite' => ('yes' === $settings['doob_brand_infinite']),
            'for_xl_desktop' => absint($settings['rbt_brand_carousel_columns_for_xl_desktop']),
            'slidesToShow' => absint($settings['rbt_brand_carousel_columns_for_desktop']),
            'for_laptop' => absint($settings['rbt_brand_carousel_columns_for_laptop']),
            'for_tablet' => absint($settings['rbt_brand_carousel_columns_for_tablet']),
            'for_mobile' => absint($settings['rbt_brand_carousel_columns_for_mobile']),
            'for_xs_mobile' => absint($settings['rbt_brand_carousel_columns_for_xs_mobile']),
        ];
        $this->add_render_attribute('doob-carousel-brand-data', 'data-settings', wp_json_encode($carousel_args));

        if($settings['brand_style'] == '2'){
            $style = "brand-list brand-style-2";
        } elseif ( $settings['brand_style'] == '3' ){
            $style = "brand-list brand-style-2 variation-2";
        }  elseif ( $settings['brand_style'] == '4' ){
            $style = "rn-slick-activation rainbow-slick-arrow rainbow-slick-dot mb--40 brand-carousel-activation";
        } else {
            $style = "brand-style-1";
        }

        ?>
        <div class="rainbow-brand-area rainbow-section-gap">
            <div class="container">
                <?php if($settings['rbt_brand_section_title_show'] == 'yes'){ ?>
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12 col-12">
                            <div class="section-title mb--30 <?php echo esc_attr($settings['rbt_brand_align']) ?>">
                                <?php $this->rbt_section_title_render('brand', $this->get_settings()); ?>
                            </div>
                        </div>
                    </div>
                <?php } ?>



                <?php if($settings['brand_custom_column'] == '2'){ ?>

                    <div class="row">
                        <div class="col-lg-12 mt--40">
                            <div class="brand-list <?php echo esc_attr($style); ?> <?php echo esc_attr($settings['custom_class']); ?>" <?php echo $this->get_render_attribute_string('doob-carousel-brand-data'); ?>>
                                <div class="row">
                                    <?php
                                    $link = '';
                                    $target = '';
                                    $rel = '';
                                    foreach($settings['brand_logo_list'] as $key => $logo){
                                        $link = $logo['brand_logo_link']['url'];
                                        $target = $logo['brand_logo_link']['is_external'] ? ' target="_blank"' : '';
                                        $rel = $logo['brand_logo_link']['nofollow'] ? ' rel="nofollow"' : '';
                                        ?>
                                        <div class="text-center col-lg-<?php echo esc_attr($settings['rbt_brand_columns_for_desktop']); ?> col-md-<?php echo esc_attr($settings['rbt_brand_columns_for_laptop']); ?> col-sm-<?php echo esc_attr($settings['rbt_brand_columns_for_tablet']); ?> col-<?php echo esc_attr($settings['rbt_brand_columns_for_mobile']); ?>">
                                            <?php if (!empty($link)){ ?> <a href="<?php echo esc_url($link); ?>" <?php echo esc_attr($target); ?><?php echo esc_attr($rel); ?>> <?php } ?>
                                                <?php if(!empty(wp_get_attachment_image( $logo['brand_logo_image']['id']))){ ?>
                                                    <?php echo wp_get_attachment_image( $logo['brand_logo_image']['id'], 'full' ); ?>
                                                <?php } else { ?>
                                                    <?php echo Group_Control_Image_Size::get_attachment_image_html($logo, 'full', 'brand_logo_image') ?>
                                                <?php } ?>
                                                <?php if (!empty($link)){ ?> </a> <?php } ?>
                                        </div>
                                    <?php } ?>
                                </div>
                            </div>
                        </div>
                    </div>

                <?php } else { ?>
                    <div class="row">
                        <div class="col-lg-12 mt--40">
                            <ul class="brand-list <?php echo esc_attr($style); ?> <?php echo esc_attr($settings['custom_class']); ?>" <?php echo $this->get_render_attribute_string('doob-carousel-brand-data'); ?>>
                                <?php
                                $link = '';
                                $target = '';
                                $rel = '';
                                foreach($settings['brand_logo_list'] as $key => $logo){
                                    $link = $logo['brand_logo_link']['url'];
                                    $target = $logo['brand_logo_link']['is_external'] ? ' target="_blank"' : '';
                                    $rel = $logo['brand_logo_link']['nofollow'] ? ' rel="nofollow"' : '';
                                    ?>
                                    <li>
                                        <?php if (!empty($link)){ ?> <a href="<?php echo esc_url($link); ?>" <?php echo esc_attr($target); ?><?php echo esc_attr($rel); ?>> <?php } ?>
                                            <?php if(!empty(wp_get_attachment_image( $logo['brand_logo_image']['id']))){ ?>
                                                <?php echo wp_get_attachment_image( $logo['brand_logo_image']['id'], 'full' ); ?>
                                            <?php } else { ?>
                                                <?php echo Group_Control_Image_Size::get_attachment_image_html($logo, 'full', 'brand_logo_image') ?>
                                            <?php } ?>
                                            <?php if (!empty($link)){ ?> </a> <?php } ?>
                                    </li>
                                <?php } ?>
                            </ul>
                        </div>
                    </div>
                <?php } ?>





            </div>
        </div>



        <?php
    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Brand());
