<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_CallToAction extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-call-to-action';
    }

    public function get_title()
    {
        return esc_html__('Call To Action', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['call to action', 'action', 'title and button', 'cta', 'doob'];
    }

    protected function register_controls()
    {

        // Call To Action title and content
        $this->rbt_section_title('cta_title', 'Title and Content', '', 'Ready to start creating a standard website?', 'h2', 'Finest choice for your home & office');

        // Button
        $this->rbt_link_controls('cta_button', 'Button', 'Purchase Doob');

        $this->start_controls_section(
            '_cta_extra',
            [
                'label' => esc_html__('Advanced', 'doob'),
            ]
        );
        $this->add_control(
            'cta_button_position',
            [
                'label' => esc_html__( 'Layout', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'left' => esc_html__('Left', 'doob'),
                    'right' => esc_html__('Right', 'doob'),
                    'bottom' => esc_html__('Bottom', 'doob'),
                ],
                'default' => 'bottom',
            ]
        );
        $this->add_control(
            'cta_button_location',
            [
                'label' => esc_html__( 'Button', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'start' => esc_html__('Top', 'doob'),
                    'center' => esc_html__('Middle', 'doob'),
                    'end' => esc_html__('Bottom', 'doob'),
                ],
                'condition' => [
                    'cta_button_position!' => 'bottom',
                ]
            ]
        );
        $this->add_control(
            'cta_content_width',
            [
                'label' => esc_html__( 'Content Width', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'container' => esc_html__('Container', 'doob'),
                    'container-fluid' => esc_html__('Container Fluid', 'doob'),
                    'container-full' => esc_html__('Full Width', 'doob'),
                ],
                'default' => 'container',
            ]
        );
        $this->add_control(
            'cta_background',
            [
                'label' => esc_html__( 'Content Background', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'solid' => esc_html__('Solid', 'doob'),
                    'image' => esc_html__('Image', 'doob'),
                    'transparent' => esc_html__('Transparent', 'doob'),
                ],
                'default' => 'solid',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'cta_background_color',
                'label' => esc_html__('Background Color', 'doob'),
                'types' => ['classic', 'gradient'],
                'exclude' => ['image'],
                'selector' => '{{WRAPPER}} .clltoaction-style-default.style-4.bg-solid .content-wrapper',
                'separator' => 'before',
                'condition' => [
                    'cta_background' => 'solid',
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'cta_background_image',
                'label' => esc_html__('Background Image', 'doob'),
                'types' => ['classic', 'gradient'],
                'exclude' => [''],
                'selector' => '{{WRAPPER}} .clltoaction-style-default.style-4.bg-image .content-wrapper',
                'separator' => 'before',
                'condition' => [
                    'cta_background' => 'image',
                ]
            ]
        );
        $this->add_control(
            'cta_background_image_overlay',
            [
                'label' => esc_html__( 'Background Overlay', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'doob' ),
                'label_off' => esc_html__( 'No', 'doob' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'cta_background' => 'image',
                ]
            ]
        );
        $this->add_control(
            'cta_background_image_overlay_color',
            [
                'label' => esc_html__( 'Background Overly', 'doob' ),
                'type' => \Elementor\Controls_Manager::COLOR,

                'selectors' => [
                    '{{WRAPPER}} .clltoaction-style-default.style-4.overlay::before' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'cta_background' => 'image',
                    'cta_background_image_overlay' => 'yes',
                ]
            ]
        );
        $this->add_control(
            'cta_light_shape_show',
            [
                'label' => esc_html__( 'Light Shape', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'doob' ),
                'label_off' => esc_html__( 'Hide', 'doob' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'cta_background' => 'solid',
                ]
            ]
        );
        $this->end_controls_section();


        // Style Component
        $this->rbt_basic_style_controls('cta_title_before_title', 'Before Title', '.section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('cta_title_title', 'Title', '.section-title .title');
        $this->rbt_basic_style_controls('cta_title_title_clip', 'Clip', '.section-title .title .cd-headline .theme-gradient');
        $this->rbt_basic_style_controls('cta_title_description', 'Description', '.section-title p');


        // Link Style
        $this->rbt_link_controls_style('cta_button_style', 'Button', '.btn-default', 'btn-medium', 'btn-default');

        // Area Style
        $this->rbt_section_style_controls('cta_box_area', 'Box Area Style', '.clltoaction-style-default .content-wrapper');
    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        if($settings['cta_background'] == 'transparent'){
            $style = "bg-transparent";
        } elseif ( $settings['cta_background'] == 'image' ){
            $style = "bg-image";
        } else {
            $style = "bg-solid bg-color-blackest";
        }
        $overlay = ($settings['cta_background_image_overlay'] == 'yes') ? "overlay" : "";
        $overlaycontent = ($settings['cta_background_image_overlay'] == 'yes') ? "overlay-content" : "";
        $themeshape = ($settings['cta_light_shape_show'] == 'yes') ? "theme-shape" : "";

        if( $settings['cta_button_position'] == 'right'){ ?>
            <div class="rainbow-callto-action clltoaction-style-default style-4 <?php echo esc_attr($style); ?> <?php echo esc_attr($overlay); ?>">
                <div class="row align-items-center content-wrapper <?php echo esc_attr($themeshape) ?>">
                    <div class="col-lg-12">
                        <div class="inner <?php echo esc_attr($overlaycontent) ?>">
                            <div class="<?php echo esc_attr($settings['cta_content_width']) ?>">
                                <div class="row  align-items-<?php echo esc_attr($settings['cta_button_location']) ?>">
                                    <div class="col-lg-8">
                                        <div class="inner">
                                            <div class="content section-title <?php echo esc_attr($settings['rbt_cta_title_align']) ?>">
                                                <?php $this->rbt_section_title_render('cta_title', $this->get_settings()); ?>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-lg-4">
                                        <?php if($settings['rbt_cta_button_button_show'] === 'yes'){ ?>
                                            <div class="call-to-btn text-start text-lg-end">
                                                <?php $this->rbt_link_control_render('cta_button', $this->get_settings()); ?>
                                            </div>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php } elseif ($settings['cta_button_position'] == 'left'){ ?>
            <div class="rainbow-callto-action clltoaction-style-default style-4 <?php echo esc_attr($style); ?> <?php echo esc_attr($overlay); ?>">
                <div class="row align-items-center content-wrapper <?php echo esc_attr($themeshape) ?>">
                    <div class="col-lg-12">
                        <div class="inner <?php echo esc_attr($overlaycontent) ?>">
                            <div class="<?php echo esc_attr($settings['cta_content_width']) ?>">
                                <div class="row  align-items-<?php echo esc_attr($settings['cta_button_location']) ?>">
                                    <div class="col-lg-4">
                                        <?php if($settings['rbt_cta_button_button_show'] === 'yes'){ ?>
                                            <div class="call-to-btn text-start text-lg-start">
                                                <?php $this->rbt_link_control_render('cta_button', $this->get_settings()); ?>
                                            </div>
                                        <?php } ?>
                                    </div>
                                    <div class="col-lg-8">
                                        <div class="inner">
                                            <div class="content section-title <?php echo esc_attr($settings['rbt_cta_title_align']) ?>">
                                                <?php $this->rbt_section_title_render('cta_title', $this->get_settings()); ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php } else { ?>
            <div class="rainbow-callto-action clltoaction-style-default style-4 <?php echo esc_attr($style); ?> <?php echo esc_attr($overlay); ?>">
                <div class="align-items-center content-wrapper <?php echo esc_attr($themeshape) ?>">
                    <div class="inner <?php echo esc_attr($overlaycontent) ?>">
                        <div class="<?php echo esc_attr($settings['cta_content_width']) ?>">
                            <div class="content section-title <?php echo esc_attr($settings['rbt_cta_title_align']) ?>">
                                <?php $this->rbt_section_title_render('cta_title', $this->get_settings()); ?>
                                <?php if($settings['rbt_cta_button_button_show'] === 'yes'){ ?>
                                    <div class="call-to-btn sal-animate">
                                        <?php $this->rbt_link_control_render('cta_button', $this->get_settings()); ?>
                                    </div>
                                <?php } ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php }
    }
}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_CallToAction());