<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Contact extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-contact';
    }

    public function get_title()
    {
        return esc_html__('Contact', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['contact', 'contact form 7', 'hire me', 'say hello', 'doob'];
    }
    public function get_rbt_contact_form(){
        if ( ! class_exists( 'WPCF7' ) ) {
            return;
        }
        $rbt_cfa         = array();
        $rbt_cf_args     = array( 'posts_per_page' => -1, 'post_type'=> 'wpcf7_contact_form' );
        $rbt_forms       = get_posts( $rbt_cf_args );
        $rbt_cfa         = ['0' => esc_html__( 'Select Form', 'doob' ) ];
        if( $rbt_forms ){
            foreach ( $rbt_forms as $rbt_form ){
                $rbt_cfa[$rbt_form->ID] = $rbt_form->post_title;
            }
        }else{
            $rbt_cfa[ esc_html__( 'No contact form found', 'doob' ) ] = 0;
        }
        return $rbt_cfa;
    }
    protected function register_controls()
    {

        $this->start_controls_section(
            'doob_contact',
            [
                'label' => esc_html__('Contact Form', 'doob'),
            ]
        );

        $this->add_control(
            'doob_select_contact_form',
            [
                'label'   => esc_html__( 'Select Form', 'doob' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '0',
                'options' => $this->get_rbt_contact_form(),
            ]
        );

        $this->end_controls_section();

        // Area
        $this->rbt_section_style_controls('contact_area', 'Area Style', '.rbt-form-wrapper');

    }

    protected function render($instance = [])
    {
        $settings = $this->get_settings_for_display();
        if( !empty($settings['doob_select_contact_form']) ){ ?>
            <div class="rbt-form-wrapper"> <?php
                echo do_shortcode( '[contact-form-7  id="'.$settings['doob_select_contact_form'].'"]' );
            ?> </div> <?php
        } else {
            echo '<div class="alert alert-info"><p>' . __('Please Select contact form.', 'doob' ). '</p></div>';
        }
    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Contact());