<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Counterup_circle extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-counterup-circle';
    }

    public function get_title()
    {
        return esc_html__('Counterup Circle', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['counter', 'fun fact', 'funfact', 'counter up', 'doob'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            '_counterup_icon',
            [
                'label' => esc_html__('Icon', 'doob'),
            ]
        );

        $this->add_control(
            'counterup_icon_show',
            [
                'label' => esc_html__( 'Counter Icon', 'doob' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'doob' ),
                'label_off' => esc_html__( 'Hide', 'doob' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'counterup_icon_type',
            [
                'label' => esc_html__('Select Icon Type', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'icon',
                'options' => [
                    'image' => esc_html__('Image', 'doob'),
                    'icon' => esc_html__('Icon', 'doob'),
                ],
                'condition' => [
                    'counterup_icon_show' => 'yes',
                ]
            ]
        );

        $this->add_control(
            'counterup_image',
            [
                'label' => esc_html__('Upload Image', 'doob'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'counterup_icon_show' => 'yes',
                    'counterup_icon_type' => 'image'
                ]

            ]
        );
        if (rbt_is_elementor_version('<', '2.6.0')) {
            $this->add_control(
                'counterup_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'fa fa-star',
                    'condition' => [
                        'counterup_icon_show' => 'yes',
                        'counterup_icon_type' => 'icon'
                    ]
                ]
            );
        } else {
            $this->add_control(
                'counterup_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-star',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'counterup_icon_show' => 'yes',
                        'counterup_icon_type' => 'icon'
                    ]
                ]
            );
        }
        $this->end_controls_section();

        $this->start_controls_section(
            'doob_counterup',
            [
                'label' => esc_html__('Counterup', 'doob'),
            ]
        );
        $this->add_control(
            'counterup_number',
            [
                'label' => esc_html__('Number', 'doob'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '50',
                'label_block' => true,
            ]
        );

        $this->add_control(
            'counterup_number_sup',
            [
                'label' => esc_html__('Select Funfact Number Sup', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'counter-none',
                'options' => [
                    'counter-none' => esc_html__('None', 'doob'),
                    'counter-plus' => esc_html__('Plus(+)', 'doob'),
                    'counter-percentage' => esc_html__('Percentage(%)', 'doob'),
                    'counter-k' => esc_html__('Thousand(K)', 'doob'),
                ],
                'label_block' => true,
            ]
        );

        $this->add_control(
            'counterup_title', [
                'label' => esc_html__('Title', 'doob'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__('Happy Clients.', 'doob'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'counterup_description', [
                'label' => esc_html__('Description', 'doob'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__('Corporate Ipsum is simply dummy text of the printing and typesetting industry', 'doob'),
                'label_block' => true,
            ]
        );

        $this->add_responsive_control(
            'counterup_description_align',
            [
                'label' => esc_html__( 'Alignment', 'doob' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'text-left' => [
                        'title' => esc_html__( 'Left', 'doob' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'text-center' => [
                        'title' => esc_html__( 'Center', 'doob' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'text-right' => [
                        'title' => esc_html__( 'Right', 'doob' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default' => 'text-center',
                'toggle' => true,
            ]
        );
        $this->add_control(
            'custom_class',
            [
                'label' => esc_html__('Add Custom Class', 'doob'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        // Style Component
        $this->rbt_basic_style_controls('counterup_number', 'Number', '.im_counterup .counter');
        $this->rbt_basic_style_controls('counterup_number_sup', 'Number Sup', '.im_counterup .counter::after');
        $this->rbt_basic_style_controls('counterup_description', 'Description', '.im_counterup .description');
        $this->rbt_icon_style('counterup_icon', 'Services - Icon/Image/SVG', '.im_counterup .icon');
        // Area
        $this->rbt_section_style_controls('counterup_box', 'Counter Box', '.im_counterup');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        ?>


<div
    class="radial-progress-single <?php echo esc_attr($settings['counterup_description_align']); ?> <?php echo esc_attr($settings['custom_class']); ?>">
    <?php if(!empty($settings['counterup_number'])){ ?>
    <div class="radial-progress" data-percent="<?php echo esc_html($settings['counterup_number']) ?>"
        data-bar-color="#059DFF" data-track-color="#0f0f11">
        <div class="circle-text">
            <span
                class="count <?php echo $settings['counterup_number_sup'] ?>"><?php echo esc_html($settings['counterup_number']) ?></span>
        </div>
    </div>
    <?php } ?>
    <div class="circle-info">
        <?php if(!empty($settings['counterup_title'])){ ?>
        <h4 class="title"><?php echo esc_html($settings['counterup_title']) ?></h4>
        <?php } ?>
        <?php if(!empty($settings['counterup_description'])){ ?>
        <h6 class="subtitle"><?php echo esc_html($settings['counterup_description']) ?></h6>
        <?php } ?>
    </div>
</div>

<?php

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Counterup_circle());