<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Counterup extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-counterup';
    }

    public function get_title()
    {
        return esc_html__('Counterup', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['counter', 'fun fact', 'funfact', 'counter up', 'doob'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            '_counterup_icon',
            [
                'label' => esc_html__('Icon', 'doob'),
            ]
        );

        $this->add_control(
            'counterup_icon_show',
            [
                'label' => esc_html__( 'Counter Icon', 'doob' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'doob' ),
                'label_off' => esc_html__( 'Hide', 'doob' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'counterup_icon_type',
            [
                'label' => esc_html__('Select Icon Type', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'icon',
                'options' => [
                    'image' => esc_html__('Image', 'doob'),
                    'icon' => esc_html__('Icon', 'doob'),
                ],
                'condition' => [
                    'counterup_icon_show' => 'yes',
                ]
            ]
        );

        $this->add_control(
            'counterup_image',
            [
                'label' => esc_html__('Upload Image', 'doob'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'counterup_icon_show' => 'yes',
                    'counterup_icon_type' => 'image'
                ]

            ]
        );
        if (rbt_is_elementor_version('<', '2.6.0')) {
            $this->add_control(
                'counterup_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'fa fa-star',
                    'condition' => [
                        'counterup_icon_show' => 'yes',
                        'counterup_icon_type' => 'icon'
                    ]
                ]
            );
        } else {
            $this->add_control(
                'counterup_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-star',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'counterup_icon_show' => 'yes',
                        'counterup_icon_type' => 'icon'
                    ]
                ]
            );
        }
        $this->end_controls_section();

        $this->start_controls_section(
            'doob_counterup',
            [
                'label' => esc_html__('Counterup', 'doob'),
            ]
        );
        $this->add_control(
            'counterup_number',
            [
                'label' => esc_html__('Number', 'doob'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '50',
                'label_block' => true,
            ]
        );

        $this->add_control(
            'counterup_number_sup',
            [
                'label' => esc_html__('Select Funfact Number Sup', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'counter-none',
                'options' => [
                    'counter-none' => esc_html__('None', 'doob'),
                    'counter-plus' => esc_html__('Plus(+)', 'doob'),
                    'counter-percentage' => esc_html__('Percentage(%)', 'doob'),
                    'counter-k' => esc_html__('Thousand(K)', 'doob'),
                ],
                'label_block' => true,
            ]
        );

        $this->add_control(
            'counterup_title', [
                'label' => esc_html__('Title', 'doob'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__('Happy Clients.', 'doob'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'counterup_description', [
                'label' => esc_html__('Description', 'doob'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__('Corporate Ipsum is simply dummy text of the printing and typesetting industry', 'doob'),
                'label_block' => true,
            ]
        );


        $this->add_control(
            'counterup_layout_style',
            [
                'label' => esc_html__('Counterup Style', 'doob'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout One', 'doob'),
                    'layout-2' => esc_html__('Layout Two', 'doob'),
                    'layout-3' => esc_html__('Layout Three', 'doob'),
                    'layout-4' => esc_html__('Layout Four', 'doob'),
                    'layout-5' => esc_html__('Layout Five', 'doob'),
                ],
                'default' => 'layout-1'
            ]
        );

        $this->add_responsive_control(
            'counterup_description_align',
            [
                'label' => esc_html__( 'Alignment', 'doob' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'text-left' => [
                        'title' => esc_html__( 'Left', 'doob' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'text-center' => [
                        'title' => esc_html__( 'Center', 'doob' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'text-right' => [
                        'title' => esc_html__( 'Right', 'doob' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default' => 'text-center',
                'toggle' => true,
            ]
        );
        $this->add_control(
            'custom_class',
            [
                'label' => esc_html__('Add Custom Class', 'doob'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        // Style Component
        $this->rbt_basic_style_controls('counterup_number', 'Number', '.im_counterup .counter');
        $this->rbt_basic_style_controls('counterup_number_sup', 'Number Sup', '.im_counterup .counter::after');
        $this->rbt_basic_style_controls('counterup_description', 'Description', '.im_counterup .description');
        $this->rbt_icon_style('counterup_icon', 'Services - Icon/Image/SVG', '.im_counterup .icon');
        // Area
        $this->rbt_section_style_controls('counterup_box', 'Counter Box', '.im_counterup');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();



        $layout = $settings['counterup_layout_style'];

        if($layout == 'layout-1'){
            $counterup_class = 'count-box counter-style-1';
        }elseif($layout == 'layout-2'){
            $counterup_class = 'count-box counter-style-2';
        }elseif($layout =='layout-3'){
            $counterup_class = 'count-box counter-style-2 color-variation';
        }elseif($layout == 'layout-4'){
            $counterup_class = 'count-box counter-style-2 border-style';
        }elseif($layout == 'layout-5'){
            $counterup_class = 'count-box counter-style-4';
        }else{
            $counterup_class = 'count-box counter-style-1';
        }

        ?>
        <div class="<?php echo esc_attr($counterup_class); ?> ">
            <div class="im_counterup <?php echo esc_attr($settings['counterup_description_align']); ?> <?php echo esc_attr($settings['custom_class']); ?>">
                <div class="inner">
                    <?php if($settings['counterup_icon_show'] == 'yes'){ ?>
                        <?php if($settings['counterup_icon_type'] !== 'image'){ ?>
                            <?php if (!empty($settings['counterup_icon']) || !empty($settings['counterup_selected_icon']['value'])) : ?>
                                <div class="icon">
                                    <?php rbt_render_icon($settings, 'counterup_icon', 'counterup_selected_icon'); ?>
                                </div>
                            <?php endif; ?>
                        <?php } else {
                            if (!empty($settings['counterup_image'])){ ?>
                                <div class="icon">
                                    <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'full', 'counterup_image'); ?>
                                </div>
                            <?php } ?>
                        <?php } ?>
                    <?php } ?>

                    <?php if(!empty($settings['counterup_number'])){ ?>
                        <div class="count-number">
                            <span class="counter <?php echo $settings['counterup_number_sup'] ?>"><?php echo esc_html($settings['counterup_number']) ?></span>
                        </div>
                    <?php } ?>
                    <?php if(!empty($settings['counterup_title'])){ ?>
                        <h5 class="title"><?php echo esc_html($settings['counterup_title']) ?></h5>
                    <?php } ?>
                    <?php if(!empty($settings['counterup_description'])){ ?>
                        <p class="description"><?php echo esc_html($settings['counterup_description']) ?></p>
                    <?php } ?>


                </div>
            </div>
        </div>
        <?php

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Counterup());