<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Custom_Menu extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-custom-menu';
    }

    public function get_title()
    {
        return esc_html__('Custom Menu', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    private function get_available_menus() {
        $menus = wp_get_nav_menus();
        $options = [];
        foreach ( $menus as $menu ) {
            $options[ $menu->slug ] = $menu->name;
        }
        return $options;
    }

    public function get_keywords()
    {
        return ['custom menu', 'nav', 'megamenu item', 'menu', 'header', 'doob'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'general_section',
            [
                'label' => esc_html__('General', 'doob'),
            ]
        );


        $this->add_control(
            'source',
            [
                'label' => __( 'Data source', 'doob' ),
                'description' => __( 'Select Data source of the custom menu, it can be an existent wp menu or custom menu items added here the Items option.', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'wp_menus',
                'options' => [
                    'wp_menus' => __( 'WP Menus', 'doob' ),
                    'custom' => __( 'Custom', 'doob' ),
                ],
            ]
        );


        $menus = $this->get_available_menus();

        if ( ! empty( $menus ) ) {
            $this->add_control(
                'menu_slug',
                [
                    'label' => __( 'Menu', 'doob' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => $menus,
                    'default' => array_keys( $menus )[0],
                    'save_default' => true,
                    'separator' => 'after',
                    'description'  => sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to manage your menus.', 'doob' ), admin_url( 'nav-menus.php' ) ),
                    'condition' => [
                        'source' => 'wp_menus'
                    ],
                ]
            );
        } else {
            $this->add_control(
                'menu_slug',
                [
                    'type' => Controls_Manager::RAW_HTML,
                    'raw' => sprintf( __( '<strong>There are no menus in your site.</strong><br>Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'doob' ), admin_url( 'nav-menus.php?action=edit&menu=0' ) ),
                    'separator' => 'after',
                    'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
                    'condition' => [
                        'source' => 'wp_menus'
                    ],
                ]
            );
        }

        $repeater = new Repeater();

        $repeater->add_control(
            'label', [
                'label' => __( 'Label', 'doob' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'url', [
                'label' => __( 'URL (link)', 'doob' ),
                'type' => Controls_Manager::TEXT,
                'default' => '#',
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'target',
            [
                'label' => esc_html__( 'Open in new window', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'doob' ),
                'label_off' => esc_html__( 'Hide', 'doob' ),
                'return_value' => 'yes',
                'label_on' => __( 'Yes', 'doob' ),
                'label_off' => __( 'No', 'doob' ),
                'default' => '',
            ]
        );

        $repeater->add_control(
            'badge', [
                'label' => __( 'Badge', 'doob' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => __( 'Items', 'doob' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ label }}}',
                'condition' => [
                    'source' => 'custom'
                ],
                'separator' => 'before',
            ]
        );


        $this->add_responsive_control(
            'menu_alignment',
            [
                'label' => __( 'Menu alignment', 'doob' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'doob' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'doob' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'doob' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}' => 'text-align: {{VALUE}}',
                    '{{WRAPPER}} .reset-ul li a' => 'justify-content: {{VALUE}}',
                ],
                'toggle' => true,
            ]
        );

        $this->add_responsive_control(
            'spacing',
            [
                'label' => __( 'Links space bottom', 'doob' ),
                'description' => __( 'Space between items.', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .custom-menu-item > li:not(:first-child)' => 'margin-top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .custom-menu-item > li:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'links_padding',
            [
                'label' => __( 'Links padding', 'doob' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .custom-menu-item > li > a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ]
            ]
        );

        $this->add_control(
            'links_border_radius',
            [
                'label' => __( 'Links border radius', 'doob' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .custom-menu-item > li > a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'links_bg_color',
            [
                'label' => esc_html__('Background Color (Hover)', 'doob'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .custom-menu-item > li > a:hover' => 'background: {{VALUE}} !important;',
                ],
            ]
        );
        

        $this->end_controls_section();

        $this->rbt_basic_style_controls('menu_typography', 'Typography & Color', ' .custom-menu-item > li > a');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();
        $menu_slug = (isset($settings['menu_slug'] )? $settings['menu_slug'] : '' );
        $source = $settings['source'];
        $items = $settings['items'];

        $ul_classes = array(
            'mega-menu-item',
            'custom-menu-item'
        );

        if ('wp_menus' === $source){
            if( is_nav_menu( $menu_slug ) ) {
                wp_nav_menu( array(
                    'menu'           => $menu_slug,
                    'container'      => 'ul',
                    'container_id'   => '',
                    'container_class' => '',
                    'before'         => false,
                    'after'          => false,
                    'menu_class'     => esc_attr( implode( ' ', $ul_classes ) ),
                    'fallback_cb' => false,
                    'walker'         => class_exists( 'DoobNavWalker' ) ? new \DoobNavWalker : '',

                ) );
            } else {
                wp_nav_menu( array(
                    'container'   => 'ul',
                    'container_id'   => '',
                    'before'      => false,
                    'after'       => false,
                    'menu_class'     => esc_attr( implode( ' ', $ul_classes ) ),
                    'walker'         => class_exists( 'DoobNavWalker' ) ? new \DoobNavWalker : '',
                ));

            };
        } else { ?>
            <ul class="<?php echo esc_attr( implode( ' ', $ul_classes ) ); ?>">
                <?php
                    foreach ( $items as $item ) {
                        if (empty($item['url'])) {
                            continue;
                        }
                        ?>
                        <li>
                            <a href="<?php echo esc_url( $item['url'] ) ?>" target="<?php echo esc_attr( $item['target'] === 'yes' ? '_blank' : '_self' ) ?>">
                                <?php echo do_shortcode( $item['label'] ); ?>
                                <?php if( !empty( $item['badge'] ) ) { ?>
                                    <span class="rainbow-badge-card"> <?php echo esc_html($item['badge']); ?> </span><?php
                                } ?>

                            </a>
                        </li>
                        <?php
                    }
                ?>
            </ul>
        <?php }

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Custom_Menu());