<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Gallery extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-gallery';
    }

    public function get_title()
    {
        return esc_html__('Gallery', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['gallery', 'portfolio', 'doob'];
    }

    protected function register_controls()
    {

        // Title and content
        $this->rbt_section_title('gallery', 'Section - Title and Content', 'Photo', 'Portfolio Gallery', 'h2', '', 'text-center', true, 'no');

        $this->start_controls_section(
            '_section_doob_gallery',
            [
                'label' => esc_html__( 'Gallery - Content', 'doob' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );


        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'doob_gallery_images',
            [
                'label' => esc_html__( 'Choose Image', 'doob' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );


        $this->add_control(
            'doob_gallery',
            [
                'label' => esc_html__( 'Add Gallery Images', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => esc_html__( 'Gallery Image', 'doob' ),

                'default' => [
                    [
                        'doob_gallery_images' => \Elementor\Utils::get_placeholder_image_src(),

                    ],
                    [
                        'doob_gallery_images' => \Elementor\Utils::get_placeholder_image_src(),

                    ],
                    [
                        'doob_gallery_images' => \Elementor\Utils::get_placeholder_image_src(),

                    ],
                    [
                        'doob_gallery_images' => \Elementor\Utils::get_placeholder_image_src(),

                    ],
                    [
                        'doob_gallery_images' => \Elementor\Utils::get_placeholder_image_src(),

                    ],
                    [
                        'doob_gallery_images' => \Elementor\Utils::get_placeholder_image_src(),

                    ],
                    [
                        'doob_gallery_images' => \Elementor\Utils::get_placeholder_image_src(),

                    ],
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'gallery_thumbnail',
                'default' => 'doob-gallery-thumb',
                'separator' => 'before',
                'exclude' => [
                    'custom'
                ]
            ]
        );

        $this->end_controls_section();

        // Columns Panel
        $this->rbt_columns('gallery_columns', 'Gallery - Columns', '4', '6', '6', '12');


        // Style Component
        $this->rbt_basic_style_controls('section_title_before_title', 'Section - Before Title', '.section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('section_title_title', 'Section - Title', '.section-title .title');
        $this->rbt_basic_style_controls('section_title_description', 'Section - Description', '.section-title p');

        // Area
        $this->rbt_section_style_controls('gallery_area', 'Section Style', '.rn-gallery-area');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();
        if ( empty( $settings['doob_gallery'] ) ) {
            return;
        }

        $id_int     = substr( $this->get_id_int(), 0, 3 );
        $this->add_render_attribute( 'rbt-gallery', 'class', 'rainbow-gallery-area rainbow-section-gap' );
        $this->add_render_attribute( 'rbt-gallery', 'id', 'rbt-gallery-'.esc_attr( $this->get_id() ));

        ?>
        <!-- Start Gallery Area  -->
        <div <?php echo $this->get_render_attribute_string('rbt-gallery'); ?> <?php echo $this->get_render_attribute_string('rbt-gallery-data'); ?>>
            <div class="gallery-section-inner">

                <?php if($settings['rbt_gallery_section_title_show'] == 'yes'){ ?>
                    <div class="container">
                        <div class="row">
                            <div class="col-lg-12 mb--20">
                                <div class="section-title <?php echo esc_attr($settings['rbt_gallery_align']) ?>">
                                    <?php $this->rbt_section_title_render('gallery', $this->get_settings()); ?>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php } ?>

                <?php if(!empty($settings['doob_gallery'])){ ?>
                    <div class="row mt_dec--30 row--15 animated-lightbox" id="animated-lightbox-<?php echo esc_attr($this->get_id()); ?>">
                        <?php
                        foreach ($settings['doob_gallery'] as $index => $gallery){
                            $big_image  = (!empty(wp_get_attachment_image_url( $gallery['doob_gallery_images']['id'], 'full'))) ? wp_get_attachment_image_url( $gallery['doob_gallery_images']['id'], 'full') : Utils::get_placeholder_image_src();
                            ?>
                                <a class="col-lg-<?php echo esc_attr($settings['rbt_gallery_columns_for_desktop']); ?> col-md-<?php echo esc_attr($settings['rbt_gallery_columns_for_laptop']); ?> col-sm-<?php echo esc_attr($settings['rbt_gallery_columns_for_tablet']); ?> col-<?php echo esc_attr($settings['rbt_gallery_columns_for_mobile']); ?> mt--30 " href="<?php echo esc_url($big_image); ?>">
                                    <div class="rainbow-gallery icon-center">
                                        <div class="thumbnail">
                                            <?php if(!empty(wp_get_attachment_image( $gallery['doob_gallery_images']['id']))){ ?>
                                                <?php echo wp_get_attachment_image( $gallery['doob_gallery_images']['id'], $settings['gallery_thumbnail_size'] ); ?>
                                            <?php } else { ?>
                                                <?php echo Group_Control_Image_Size::get_attachment_image_html($gallery, 'full', 'doob_gallery_images') ?>
                                            <?php } ?>
                                        </div>
                                        <div class="video-icon">
                                            <div class="btn-default rounded-player sm-size">
                                                <span><i class="feather-zoom-in"></i></span>
                                            </div>
                                        </div>
                                    </div>
                                </a>
                        <?php } ?>
                    </div>
                <?php } ?>



            </div>
        </div>
        <!-- End Gallery Area  -->
        <?php
    }
}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Gallery());