<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Library_Tabs extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-library-tabs';
    }

    public function get_title()
    {
        return esc_html__('Library Tabs', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['Library tabs', 'doob'];
    }

    public function get_post_template()
    {
        $posts = get_posts(
            array(
                'post_type' => 'elementor_library',
                'orderby' => 'title',
                'order' => 'ASC',
                'posts_per_page' => '-1',
            )
        );
        $templates = array();
        foreach ($posts as $post) {
            $templates[] = array(
                'id' => $post->ID,
                'name' => $post->post_title,
            );
        }
        return $templates;
    }

    public function get_saved_data()
    {
        $saved_widgets = $this->get_post_template();
        $options[-1] = __('Select', 'doob');
        if (count($saved_widgets)) {
            foreach ($saved_widgets as $saved_row) {
                $options[$saved_row['id']] = $saved_row['name'];
            }
        } else {
            $options['no_template'] = __('It seems that, you have not saved any template yet.', 'doob');
        }
        return $options;
    }

    public function get_content_type()
    {
        $content_type = array(
            'content' => esc_html__('Content', 'doob'),
            'saved_rows' => esc_html__('Saved Section', 'doob'),
            'saved_page_templates' => esc_html__('Saved Page', 'doob'),
        );
        return $content_type;
    }

    
    protected function register_controls()
    {

        $this->start_controls_section(
            '_tab',
            [
                'label' => esc_html__( 'Tab', 'doob' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'tab_title', [
                'label' => esc_html__( 'Tab Item', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'This is tab item title' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'library_tab_library',
            [
                'label' => __('Elementor Library', 'doob'),
                'type' => Controls_Manager::SELECT2,
                'default' => '-1',
                'options' => $this->get_saved_data(),
            ]
        );
        $this->add_control(
            'library_tabs',
            [
                'label' => esc_html__( 'Repeater Tab', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'tab_title' => esc_html__( 'Our history', 'doob' ),
                    ],
                    [
                        'tab_title' => esc_html__( 'Our mission', 'doob' ),
                    ],
                    [
                        'tab_title' => esc_html__( 'Friendly Support', 'doob' ),
                    ],
                ],
                'title_field' => '{{{ tab_title }}}',
            ]
        );

        $this->add_responsive_control(
            'space_tab_item_align',
            [
                'label' => esc_html__('Alignment', 'doob'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'start' => [
                        'title' => esc_html__('Left', 'doob'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'doob'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'end' => [
                        'title' => esc_html__('Right', 'doob'),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__('Justify', 'doob'),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => 'start',
                'toggle' => false,
            ]
        );

        $this->add_control(
            'space_tab_item',
            [
                'label' => esc_html__( 'Tab space gap', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-default-tab ul li + li' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'space_tab_content',
            [
                'label' => esc_html__( 'Tab Content Space', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-default-tab .rainbow-tab-content' => 'padding: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'tab_style',
            [
                'label' => esc_html__( 'Style', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    '1' => esc_html__('Default', 'doob'),
                    '2' => esc_html__('Layout Two', 'doob'),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();

        // Style Component
        $this->rbt_basic_style_controls('tabs_title', 'Title', '.rainbow-default-tab .tab-button .tabs__tab .nav-link .tab_title');
        $this->rbt_basic_style_controls('tabs_description', 'Description', '.rainbow-default-tab .rainbow-tab-content .tab_description');

        $this->rbt_section_style_controls('tabs_title_bg', 'Tab Item', '.rainbow-default-tab .tab-button .tabs__tab .nav-link.active');
        $this->rbt_section_style_controls('tabs_description_bg', 'Tab Content', '.rainbow-default-tab .rainbow-tab-content');

        // Area Style

        $this->rbt_section_style_controls('tabs_area', 'Area Style', '.rainbow-default-tab');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        // Image Settings
        if( $settings['tab_style'] == '2'){
            $style_class = "rainbow-default-tab style-two";
        } else {
            $style_class = "rainbow-default-tab";
        }

        ?>
        <div class="rainbow-default-tab <?php echo esc_attr($style_class); ?>">
            <ul class="nav nav-library-tabs tab-button  justify-content-<?php echo esc_attr($settings['space_tab_item_align']); ?>" id="myTab-<?php echo esc_attr($this->get_id()); ?>" role="tablist">
                <?php
                foreach ( $settings['library_tabs'] as $index => $item ){
                    $active = ($index == '0') ? "show active" : "";
                    $aria_selected = ($index == '0' ) ? "true" : "false";
                    ?>
                    <li class="nav-item tabs__tab">
                        <a class="nav-link <?php echo esc_attr($active); ?>" id="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" data-bs-toggle="tab" data-bs-target="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" href="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tab" aria-controls="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" aria-selected="<?php echo esc_attr($aria_selected); ?>"><span class="tab_title"><?php echo esc_html($item['tab_title']); ?></span></a>
                    </li>
                <?php } ?>

            </ul>
            <div class="rainbow-tab-content tab-content" id="myTabContent-<?php echo esc_attr($this->get_id()); ?>">
                <?php
                foreach ( $settings['library_tabs'] as $index => $item ){
                    $active = ($index == '0') ? "show active" : "";

                    $library_elementor_library = $item['library_tab_library'];

                    ?>
                    <div class="tab-pane fade <?php echo esc_attr($active); ?>" id="rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tabpanel">
                        <div class="tab_description">

                            <?php echo $content_1 = \Elementor\Plugin::$instance->frontend->get_builder_content_for_display($library_elementor_library); ?>

                        </div>



                    </div>
                <?php } ?>
            </div>
        </div>
        <?php
    }
}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Library_Tabs());