<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Pricing extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-pricing';
    }

    public function get_title()
    {
        return esc_html__('Pricing', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['pricing', 'pricing table', 'doob'];
    }

    protected function register_controls()
    {
        // Title and content
        $this->rbt_section_title('pricing', 'Section - Title and Content', '', 'Pricing Plan', 'h2', 'There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration.');

        $this->start_controls_section(
            'doob_pricing',
            [
                'label' => esc_html__( 'Pricing Plan', 'doob' ),
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'pricing_title', [
                'label' => esc_html__( 'Title', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Free' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'pricing_price',
            [
                'label' => esc_html__( 'Price', 'doob' ),
                'type' => Controls_Manager::TEXT,
                'default' => '50',
                'dynamic' => [
                    'active' => true
                ]
            ]
        );
        $repeater->add_control(
            'pricing_price_currency',
            [
                'label' => esc_html__( 'Currency', 'doob' ),
                'type' => Controls_Manager::TEXT,
                'default' => '$',
                'dynamic' => [
                    'active' => true
                ]
            ]
        );
        $repeater->add_control(
            'pricing_sub_title', [
                'label' => esc_html__( 'Sub Title', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'USD Per Month' , 'doob' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'pricing_features_list', [
                'label' => esc_html__( 'Features List', 'doob' ),
                'description' => esc_html__( 'Create new line by Enter', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => '5 PPC Campaigns Per Day
Unlimited Digital Marketing
Unlimited Marketing Agency
Unlimited Facebook Marketing
Unlimited Video Camplaigns',
                'label_block' => true,
            ]
        );

        // Start Button
        $repeater->add_control(
            'rbt_pricing_button_button_show',
            [
                'label' => esc_html__( 'Show Button', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'doob' ),
                'label_off' => esc_html__( 'Hide', 'doob' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $repeater->add_control(
            'rbt_pricing_button_text',
            [
                'label' => esc_html__('Button Text', 'doob'),
                'type' => Controls_Manager::TEXT,
                'default' => 'Purchase Now',
                'title' => esc_html__('Enter button text', 'doob'),
                'label_block' => true,
                'condition' => [
                    'rbt_pricing_button_button_show' => 'yes'
                ],
            ]
        );
        $repeater->add_control(
            'rbt_pricing_button_link_type',
            [
                'label' => esc_html__('Button Link Type', 'doob'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'label_block' => true,
                'condition' => [
                    'rbt_pricing_button_button_show' => 'yes'
                ],
            ]
        );
        $repeater->add_control(
            'rbt_pricing_button_link',
            [
                'label' => esc_html__('Button link', 'doob'),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__('https://your-link.com', 'doob'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'condition' => [
                    'rbt_pricing_button_link_type' => '1',
                    'rbt_pricing_button_button_show' => 'yes'
                ],
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'rbt_pricing_button_page_link',
            [
                'label' => esc_html__('Select Button Page', 'doob'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => rbt_get_all_pages(),
                'condition' => [
                    'rbt_pricing_button_link_type' => '2',
                    'rbt_pricing_button_button_show' => 'yes'
                ]
            ]
        );
        // End Button
        $repeater->add_control(
            'pricing_featured',
            [
                'label' => esc_html__('Featured', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'doob'),
                'label_off' => esc_html__('No', 'doob'),
                'return_value' => 'yes',
            ]
        );
        // End Link

        // Repeater Control
        $this->add_control(
            'pricing_table',
            [
                'label' => esc_html__( 'Pricing table', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'pricing_title' => esc_html__( 'Basic', 'doob' ),
                        'pricing_featured' => 'no',
                    ],
                    [
                        'pricing_title' => esc_html__( 'Medium', 'doob' ),
                        'pricing_price' => esc_html__( '99', 'doob' ),
                        'pricing_featured' => 'yes',
                    ],
                    [
                        'pricing_title' => esc_html__( 'Advanced', 'doob' ),
                        'pricing_price' => esc_html__( '199', 'doob' ),
                        'pricing_featured' => 'no',
                    ],
                ],
                'title_field' => '{{{ pricing_title }}}',
            ]
        );
        $this->add_control(
            'pricing_style',
            [
                'label' => esc_html__( 'Style', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'one' => esc_html__('Style One', 'doob'),
                    'two' => esc_html__('Style Two', 'doob'),
                    'three' => esc_html__('Style Three', 'doob'),
                ],
                'default' => 'one',
            ]
        );
        $this->add_control(
            'pricing_columns_gap',
            [
                'label' => esc_html__( 'Columns Gap', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'default' => esc_html__('Default', 'doob'),
                    'no' => esc_html__('No Gap', 'doob'),
                    'narrow' => esc_html__('Narrow', 'doob'),
                    'wide' => esc_html__('Wide', 'doob'),
                ],
                'default' => 'default',
            ]
        );
        $this->add_control(
            'pricing_content_width',
            [
                'label' => esc_html__( 'Content Width', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'default' => esc_html__('Container', 'doob'),
                    'full' => esc_html__('Container Full Wide', 'doob'),
                ],
                'default' => 'default',
            ]
        );
        $this->add_control(
            'pricing_content_alignments',
            [
                'label' => esc_html__( 'Content Alignments', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'left' => esc_html__('Left', 'doob'),
                    'center' => esc_html__('Center', 'doob'),
                    'right' => esc_html__('Right', 'doob'),
                ],
                'default' => 'left',
            ]
        );
        $this->end_controls_section();

        // Columns Panel
        $this->rbt_columns('pricing_columns', 'Columns', '4', '6', '12', '12');


        // Style Component
        $this->rbt_basic_style_controls('pricing_before_title', 'Section - Before Title', '.section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('pricing_title', 'Section - Title', '.section-title .title');
        $this->rbt_basic_style_controls('pricing_description', 'Section - Description', '.section-title p');

        $this->rbt_basic_style_controls('pricing_table_title', 'Table - Title', '.pricing-header .title');
        $this->rbt_basic_style_controls('pricing_table_currency', 'Table - Currency', '.pricing-header .pricing span.currency');
        $this->rbt_basic_style_controls('pricing_table_price', 'Table - Price', '.pricing-header .pricing span.price');
        $this->rbt_basic_style_controls('pricing_table_sub_title', 'Table - Sub Title', '.pricing-header .pricing span.subtitle');
        $this->rbt_basic_style_controls('pricing_table_fet_list', 'Table - Features List', '.pricing-body .list-style--1 li');
        $this->rbt_basic_style_controls('pricing_table_fet_list_icon', 'Table - Features List Icon', '.pricing-body .list-style--1 li i, .pricing-body .list-style--1 li svg');

        $this->rbt_section_style_controls('pricing_table_area', 'Section Style', '.rainbow-pricing-area');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        // Style
        if($settings['pricing_style'] == 'two'){
            $pricing_style = "style-2";
        } elseif ($settings['pricing_style'] == 'three'){
            $pricing_style = "style-5";
        } else  {
            $pricing_style = "style-1";
        }

        $content_width = ($settings['pricing_content_width'] == 'full') ? "wrapper plr--100 plr_md--15 plr_sm--15" : "container";

        // Column
        if($settings['pricing_columns_gap'] == 'no'){
            $row_class = "row row--0";
        } elseif ($settings['pricing_columns_gap'] == 'narrow'){
            $row_class = "row row--5";
        } elseif ($settings['pricing_columns_gap'] == 'wide'){
            $row_class = "row row--60";
        } else  {
            $row_class = "row row--30";
        }

        // Content Alignment
        if($settings['pricing_content_alignments'] == 'center'){
            $content_alignments = "justify-content-center";
        } elseif ($settings['pricing_columns_gap'] == 'right'){
            $content_alignments = "justify-content-end";
        } else  {
            $content_alignments = "justify-content-left";
        }

        ?>
        <!-- Start Pricing Plan Area  -->
        <div class="rainbow-pricing-area rainbow-section-gap rainbow-pricing-<?php echo esc_attr($pricing_style); ?>">
            <div class="<?php echo esc_attr($content_width); ?>">
                <?php if ($settings['rbt_pricing_section_title_show'] == 'yes'){ ?>
                    <div class="row mb--40 mb_sm--0">
                        <div class="col-lg-12">
                            <div class="section-title <?php echo esc_attr($settings['rbt_pricing_align']); ?>">
                                <?php $this->rbt_section_title_render('pricing', $this->get_settings()); ?>
                            </div>
                        </div>
                    </div>
                <?php } ?>
                <?php if($settings['pricing_table']){ ?>
                    <div class="<?php echo esc_attr($row_class); ?> <?php echo esc_attr($content_alignments); ?> ">
                        <?php foreach ($settings['pricing_table'] as $table ){
                            $active = ($table['pricing_featured'] === 'yes') ? 'active' : ''; ?>
                            <div  data-unique-id="rbt-pricing-table-<?php echo $table['_id']; ?>" class="rbt-pricing-table-<?php echo $table['_id']; ?> col-lg-<?php echo esc_attr($settings['rbt_pricing_columns_for_desktop']); ?> col-md-<?php echo esc_attr($settings['rbt_pricing_columns_for_laptop']); ?> col-sm-<?php echo esc_attr($settings['rbt_pricing_columns_for_tablet']); ?> col-<?php echo esc_attr($settings['rbt_pricing_columns_for_mobile']); ?> elementor-repeater-item-<?php echo $table['_id']; ?>">
                                <div class="rainbow-pricing <?php echo esc_attr($pricing_style); ?> <?php echo esc_attr($active); ?>">
                                    <div class="pricing-table-inner">
                                        <div class="pricing-header">
                                            <?php if($table['pricing_title']){ ?>
                                                <h4 class="title"><?php echo esc_html($table['pricing_title']); ?></h4>
                                            <?php } ?>
                                            <?php if($table['pricing_price'] || $table['pricing_sub_title']){ ?>
                                                <div class="pricing">
                                                    <?php if($table['pricing_price']){ ?>
                                                        <div class="price-wrapper"><span class="currency"><?php echo esc_html($table['pricing_price_currency']); ?></span><span class="price"><?php echo esc_html($table['pricing_price']); ?></span></div>
                                                    <?php } ?>
                                                    <?php if($table['pricing_sub_title']){ ?>
                                                        <span class="subtitle"><?php echo esc_html($table['pricing_sub_title']); ?></span>
                                                    <?php } ?>
                                                </div>
                                            <?php } ?>
                                        </div>
                                        <?php  $lines = explode("\n", $table['pricing_features_list']); // or use PHP PHP_EOL constant ?>
                                        <?php if(!empty($lines)){ ?>
                                            <div class="pricing-body">
                                                <ul class="list-style--1">
                                                    <?php foreach ( $lines as $line ) {
                                                        echo '<li><i class="feather-check"></i> '. trim( $line ) .'</li>';
                                                    } ?>
                                                </ul>
                                            </div>
                                        <?php } ?>
                                        <?php if($table['rbt_pricing_button_button_show'] == 'yes'){ ?>
                                            <div class="pricing-footer">
                                                <?php
                                                // Link
                                                $href = "#";
                                                $target = "_self";
                                                $rel = "nofollow";
                                                if ('2' == $table['rbt_pricing_button_link_type']) {
                                                    $href = get_permalink($table['rbt_pricing_button_page_link']);
                                                    $target = "_self";
                                                    $rel = "nofollow";
                                                } else {
                                                    if (!empty($table['rbt_pricing_button_link']['url'])) {
                                                        $href = $table['rbt_pricing_button_link']['url'];
                                                    }
                                                    if ($table['rbt_pricing_button_link']['is_external']) {
                                                        $target = "_blank";
                                                    }
                                                    if (!empty($table['rbt_pricing_button_link']['nofollow'])) {
                                                        $rel = "nofollow";
                                                    }
                                                }
                                                // Button
                                                $active_button = ($table['pricing_featured'] === 'yes') ? '' : 'btn-border';

                                                if (!empty($table['rbt_pricing_button_link']['url']) || isset($table['rbt_pricing_button_link_type'])) {
                                                    $button_html = '<a class="btn-default ' .$active_button . ' " href="'. $href .'" target="'. $target .'" rel="'.$rel.'">' . '<span class="button-text">' . $table['rbt_pricing_button_text'] . '</span></a>';
                                                }
                                                if (!empty($table['rbt_pricing_button_text'])) {
                                                    echo $button_html;
                                                }
                                                ?>
                                            </div>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                        <?php } ?> <!-- End Foreach  -->
                    </div> <!-- End Row  -->
                <?php } ?>
            </div>
        </div>
        <!-- End Pricing Plan Area  -->
        <?php

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Pricing());