<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Service_Card extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-service-card';
    }

    public function get_title()
    {
        return esc_html__('Service Card', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['service card','card', 'service item', 'doob'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'doob_service_card',
            [
                'label' => esc_html__('Service Card', 'doob'),
            ]
        );


        $this->add_control(
            'service_icon_type',
            [
                'label' => esc_html__('Select Icon Type', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'image',
                'options' => [
                    'image' => esc_html__('Image', 'doob'),
                    'icon' => esc_html__('Icon', 'doob'),
                ],
            ]
        );

        $this->add_control(
            'service_image',
            [
                'label' => esc_html__('Upload Image', 'doob'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'service_icon_type' => 'image'
                ]

            ]
        );
        if (rbt_is_elementor_version('<', '2.6.0')) {
            $this->add_control(
                'service_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'fa fa-star',
                    'condition' => [
                        'service_icon_type' => 'icon'
                    ]
                ]
            );
        } else {
            $this->add_control(
                'service_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-star',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'service_icon_type' => 'icon'
                    ]
                ]
            );
        }
        $this->add_control(
            'service_title', [
                'label' => esc_html__('Title', 'doob'),
                'description' => rbt_get_allowed_html_desc( 'basic' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Service Title', 'doob'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'service_description',
            [
                'label' => esc_html__('Description', 'doob'),
                'description' => rbt_get_allowed_html_desc( 'advance' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => 'There are many variations of passages of Lorem Ipsum available, but the majority have suffered.',
                'label_block' => true,
            ]
        );
        $this->add_control(
            'services_link_switcher',
            [
                'label' => esc_html__( 'Add Services link', 'doob' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'doob' ),
                'label_off' => esc_html__( 'No', 'doob' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'services_link_type',
            [
                'label' => esc_html__( 'Service Link Type', 'doob' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1' => 'Custom Link',
                    '2' => 'Internal Page',
                ],
                'default' => '1',
                'condition' => [
                    'services_link_switcher' => 'yes'
                ]
            ]
        );
        $this->add_control(
            'services_link',
            [
                'label' => esc_html__( 'Service Link link', 'doob' ),
                'type' => \Elementor\Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'doob' ),
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'condition' => [
                    'services_link_type' => '1',
                    'services_link_switcher' => 'yes',
                ]
            ]
        );
        $this->add_control(
            'services_page_link',
            [
                'label' => esc_html__( 'Select Service Link Page', 'doob' ),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => rbt_get_all_pages(),
                'condition' => [
                    'services_link_type' => '2',
                    'services_link_switcher' => 'yes',
                ]
            ]
        );

        $this->add_control(
            'services_read_more_button',
            [
                'label' => esc_html__( 'Add Read More Button', 'doob' ),
                'description' => esc_html__( 'This options only work for layout three', 'doob' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'doob' ),
                'label_off' => esc_html__( 'No', 'doob' ),
                'return_value' => 'yes',
                'default' => 'no',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'services_read_more_button_text', [
                'label' => esc_html__('More Button Text', 'doob'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Read More', 'doob'),
                'label_block' => true,
                'condition' => [
                    'services_read_more_button' => 'yes',
                ]
            ]
        );

        $this->add_responsive_control(
            'service_align',
            [
                'label' => esc_html__( 'Alignment', 'doob' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'text-left' => [
                        'title' => esc_html__( 'Left', 'doob' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'text-center' => [
                        'title' => esc_html__( 'Center', 'doob' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'text-right' => [
                        'title' => esc_html__( 'Right', 'doob' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'toggle' => true,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'service_layout_style',
            [
                'label' => esc_html__('Services Style', 'doob'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('Layout One', 'doob'),
                    'layout-2' => esc_html__('Layout Two', 'doob'),
                    'layout-3' => esc_html__('Layout Three', 'doob'),
                    'layout-4' => esc_html__('Layout Four', 'doob'),
                    'layout-5' => esc_html__('Layout Five', 'doob'),
                    'layout-6' => esc_html__('Layout Six', 'doob'),
                    'layout-7' => esc_html__('Layout Seven', 'doob'),
                    'layout-8' => esc_html__('Layout Eight', 'doob'),
                    'layout-9' => esc_html__('Layout Nine', 'doob'),
                ],
                'default' => 'layout-1'
            ]
        );

        $this->end_controls_section();


        $this->rbt_icon_style('service_icon', 'Services - Icon/Image/SVG', '.single-service .icon');
        $this->rbt_basic_style_controls('service_title', 'Service - Title', '.single-service .content .title');
        $this->rbt_basic_style_controls('service_description', 'Service - Description', '.single-service .content p');

        $this->rbt_section_style_controls('services_box', 'Services Box Style', '.service');


    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        $layout = $settings['service_layout_style'];

        if($layout == 'layout-1'){
            $service_class = 'service service__style--1 bg-color-blackest radius rbt-border-none';
        }elseif($layout == 'layout-2'){
            $service_class = 'service service__style--1 bg-color-blackest radius rbt-border';
        }elseif($layout =='layout-3'){
            $service_class = 'card-box card-style-1';
        }elseif($layout == 'layout-4'){
            $service_class = 'service service__style--2';
        }elseif($layout == 'layout-5'){
            $service_class = 'service service__style--1 icon-circle-style';
        }elseif($layout == 'layout-6'){
            $service_class = 'service service__style--1 icon-circle-style with-working-process';
        }elseif($layout == 'layout-7'){
            $service_class = 'service gallery-style';
        }elseif($layout == 'layout-8'){
            $service_class = 'service service-eight';
        }elseif($layout == 'layout-9'){
            $service_class = 'service service__style--1 bg-color-blackest radius rbt-border';
        }else{
            $service_class = 'service service__style--1 bg-color-blackest radius rbt-border-none';
        }

        ?>
        <div class="service-item">
            <?php
            // Link
            if ('2' == $settings['services_link_type']) {
                $link = get_permalink($settings['services_page_link']);
                $target = '_self';
                $rel = 'nofollow';
            } else {
                $link = !empty($settings['services_link']['url']) ? $settings['services_link']['url'] : '';
                $target = !empty($settings['services_link']['is_external']) ? '_blank' : '';
                $rel = !empty($settings['services_link']['nofollow']) ? 'nofollow' : '';
            }
            ?>
            <div class="single-service">
                <?php if ($settings['services_link_switcher'] == 'yes'){ ?>
                <a href="<?php echo esc_url($link); ?>" <?php if($target != ''){ ?> target="<?php echo esc_attr($target); ?>" <?php } ?> <?php if($rel != ''){ ?> rel="<?php echo esc_attr($rel); ?>" <?php } ?>>
                    <?php } ?>
                    <div class="<?php echo esc_attr($service_class); ?>  <?php echo esc_attr($settings['service_layout_style']); ?> <?php echo esc_attr($settings['service_align']); ?>">
                        <div class="inner <?php if($layout == 'layout-8'){ echo 'd-flex'; } ?> ">

                            <?php if($layout !== 'layout-7'){
                                if($settings['service_icon_type'] !== 'image'){ ?>
                                    <?php if (!empty($settings['service_icon']) || !empty($settings['service_selected_icon']['value'])) : ?>
                                        <div class="icon">
                                            <?php rbt_render_icon($settings, 'service_icon', 'service_selected_icon'); ?>
                                            <?php if($layout == 'layout-6'){ ?>  <div class="line"></div> <?php } ?>
                                        </div>
                                    <?php endif; ?>
                                <?php } else {
                                    if (!empty($settings['service_image'])){ ?>
                                        <div class="icon image">
                                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'full', 'service_image'); ?>
                                            <?php if($layout == 'layout-6'){ ?>  <div class="line"></div> <?php } ?>
                                        </div>
                                    <?php } ?>
                                <?php } ?>
                            <?php } ?>


                            <?php if(!empty($settings['service_title']) || !empty($settings['service_description'])){
                                $this->add_render_attribute('service_title', 'class', 'title');
                                ?>
                                <div class="content">
                                    <?php if(!empty($settings['service_title'])){ ?>
                                        <?php printf('<h4 class="title">%1$s</h4>', rbt_kses_basic( $settings['service_title' ] ));?>
                                    <?php } ?>
                                    <?php if(!empty($settings['service_description'])){ ?>
                                        <p class="description b1 color-gray <?php if($layout !== 'layout-7'){ echo 'mb--0'; } ?> <?php if($layout == 'layout-8'){ echo 'mt--20'; } ?> "><?php echo rbt_kses_advance($settings['service_description']); ?></p>
                                    <?php } ?>

                                    <?php if( ($settings['services_read_more_button'] == 'yes' ) && !empty($settings['services_read_more_button_text'])){ ?>
                                        <div class="btn-default btn-small btn-border mt--20"><?php echo rbt_kses_basic( $settings['services_read_more_button_text' ] ) ?></div>
                                    <?php } ?>

                                </div>
                            <?php } ?>

                            <?php if($layout == 'layout-7'){
                                if($settings['service_icon_type'] !== 'image'){ ?>
                                    <?php if (!empty($settings['service_icon']) || !empty($settings['service_selected_icon']['value'])) : ?>
                                        <div class="icon">
                                            <?php rbt_render_icon($settings, 'service_icon', 'service_selected_icon'); ?>
                                            <?php if($layout == 'layout-6'){ ?>  <div class="line"></div> <?php } ?>
                                        </div>
                                    <?php endif; ?>
                                <?php } else {
                                    if (!empty($settings['service_image'])){ ?>
                                        <div class="icon image">
                                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'full', 'service_image'); ?>
                                            <?php if($layout == 'layout-6'){ ?>  <div class="line"></div> <?php } ?>
                                        </div>
                                    <?php } ?>
                                <?php } ?>
                            <?php } ?>


                        </div>
                    </div>
                    <?php if($settings['services_link_switcher'] == 'yes'){ ?> </a> <?php } ?>
            </div>
        </div>
        <?php

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Service_Card());