<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Social_Icon extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-social';
    }

    public function get_title()
    {
        return esc_html__('Social Icon', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['Social', 'doob'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'doob_social',
            [
                'label' => esc_html__('social', 'doob'),
            ]
        );
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'icon_url', [
                'label' => esc_html__( 'Icon Url', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( '#' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'counterup_icon_type',
            [
                'label' => esc_html__('Select Icon Type', 'doob'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'icon',
                'options' => [
                    'image' => esc_html__('Image', 'doob'),
                    'icon' => esc_html__('Icon', 'doob'),
                ],
            ]
        );

        $repeater->add_control(
            'counterup_image',
            [
                'label' => esc_html__('Upload Image', 'doob'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'counterup_icon_type' => 'image'
                ]

            ]
        );
        if (rbt_is_elementor_version('<', '2.6.0')) {
            $repeater->add_control(
                'counterup_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'fa fa-star',
                    'condition' => [
                        'counterup_icon_type' => 'icon'
                    ]
                ]
            );
        } else {
            $repeater->add_control(
                'counterup_selected_icon',
                [
                    'show_label' => false,
                    'type' => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'label_block' => true,
                    'default' => [
                        'value' => 'fas fa-star',
                        'library' => 'solid',
                    ],
                    'condition' => [
                        'counterup_icon_type' => 'icon'
                    ]
                ]
            );
        }
        $this->add_control(
            'abouts',
            [
                'label' => esc_html__( 'Repeater about', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'about_title' => esc_html__( '<i class="feather-twitter"></i>', 'doob' ),
                    ],
                    [
                        'about_title' => esc_html__( '<i class="feather-twitter"></i>', 'doob' ),
                    ],
                ],
            ]
        );


        $this->end_controls_section();

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        ?>
<ul class="social-icon social-default justify-content-start mt--30">
<?php foreach ( $settings['abouts'] as $index => $item){
                            ?>
    <li data-sal="slide-up" data-sal-duration="400" data-sal-delay="200" class="sal-animate">
        <a
            href="<?php esc_url($item['icon_url']);?>">
            <?php
            if($item['counterup_icon_type'] !== 'image'){ ?>
        <?php if (!empty($item['counterup_icon']) || !empty($item['counterup_selected_icon']['value'])) : ?>
        <?php rbt_render_icon($item, 'counterup_icon', 'counterup_selected_icon'); ?>
        <?php endif; ?>
        <?php } else {
        if (!empty($item['counterup_image'])){ ?>
        <?php echo Group_Control_Image_Size::get_attachment_image_html($item, 'full', 'counterup_image'); ?>
        <?php } ?>
        <?php } ?>
        </a>
    </li>
    <?php } ?>
</ul>

<?php

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Social_Icon());