<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Split extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-split';
    }

    public function get_title()
    {
        return esc_html__('Split', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['about', 'split about', 'split', 'doob'];
    }

    protected function register_controls()
    {


        // Section Title
        $this->rbt_section_title('split_area_title', 'Section - Title and Content', 'About', 'Split Section', 'h2', '', 'text-center', true,'no');

        // layout Panel
        $this->start_controls_section(
            'tp_layout',
            [
                'label' => esc_html__('Design Layout', 'tp-core'),
            ] 
        );
        $this->add_control(
            'tp_design_style', 
            [
                'label' => esc_html__('Select Layout', 'tp-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'layout-1' => esc_html__('layout-1', 'tp-core'),
                    'layout-2' => esc_html__('layout-2', 'tp-core'),
                    'layout-3' => esc_html__('layout-3', 'tp-core'),

                ],
                'default' => 'layout-1',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            '_split_thumbnail',
            [
                'label' => esc_html__('Thumbnail', 'doob'),
            ]
        );
        $this->add_control(
            'split_thumbnail',
            [
                'label' => esc_html__( 'Choose Image', 'doob' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'split_thumbnail_size',
                'default' => 'full',
                'exclude' => [
                    'custom'
                ]
            ]
        );

        $this->add_responsive_control(
            'split_thumbnail_height',
            [
                'label' => esc_html__( 'Image Height', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-splite-style .thumbnail img' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'split_thumbnail_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'doob' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-splite-style .thumbnail img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'split_thumbnail_position',
            [
                'label' => esc_html__( 'Image Position', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'left' => esc_html__('Left', 'doob'),
                    'right' => esc_html__('Right', 'doob'),
                ],
                'default' => 'left',
            ]
        );

        $this->add_control(
            'split_content_background',
            [
                'label' => esc_html__( 'Content Background', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'solid' => esc_html__('Solid', 'doob'),
                    'transparent' => esc_html__('Transparent', 'doob'),
                ],
                'default' => 'transparent',
            ]
        );


        $this->end_controls_section();
		$this->start_controls_section(
            '_tp_hero_video',
            [
                'label' => esc_html__('Video Url', 'tp-core'),
                'condition' => [
                    'tp_design_style' => ['layout-2', 'layout-3']
                ]
            ]
         
        );
        $this->add_control(
            'video_title',
            [
                'label' => esc_html__('Hero Video', 'doob'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('See how it works', 'doob'),
            ]
        );
        $this->add_control(
            'video_url',
            [
                'label' => esc_html__('Hero Video Url', 'doob'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('#.', 'doob'),
            ]
        );

        $this->end_controls_section();
        // Section Title
        $this->rbt_section_title('split_section_title', 'Title and Content', '', 'What is DOOB?', 'h2', 'Randomised words which look even slightly believable. If you are to use a passage of Lorem Ipsum. You need to be sure there is not anything embarrassing hidden in the middle of text. in some form, by injectedeed bedhumour, or randomised even.', 'text-left');

        $this->start_controls_section(
            '_list',
            [
                'label' => esc_html__( 'Lists', 'doob' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'list_title', [
                'label' => esc_html__( 'List Item', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Item 1' , 'doob' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'lists',
            [
                'label' => esc_html__( 'Lists contents', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => esc_html__( '- Doug DeMarco, Design Prototyping Manager', 'doob' ),
                    ],
                    [
                        'list_title' => esc_html__( '- 108 million paying subscribers', 'doob' ),
                    ],
                    [
                        'list_title' => esc_html__( '- Over 1.7 billion hours of music played monthly', 'doob' ),
                    ],
                    [
                        'list_title' => esc_html__( '- 4,000+ employees working across 16 offices', 'doob' ),
                    ],
                ],
                'title_field' => '{{{ list_title }}}',
            ]
        );

        $this->add_control(
            'space_list_item',
            [
                'label' => esc_html__( 'List space gap', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-splite-style .split-inner .split-list li' => 'margin-top: {{SIZE}}{{UNIT}}; margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section();
        
        $this->rbt_link_controls('split_button', 'Button', 'Contact With Us');



        // Style Component
        $this->rbt_basic_style_controls('split_area_title_section_before_title', 'Section - Before Title', '.section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('split_area_title_section_title', 'Section - Title', '.section-title .title');
        $this->rbt_basic_style_controls('split_area_title_section_description', 'Section - Description', '.section-title p');


        // Content Component
        $this->rbt_basic_style_controls('split_section_title_before_title', 'Content - Before Title', '.rainbow-splite-style .section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('split_section_title_title', 'Content - Title', '.rainbow-splite-style .section-title .title');
        $this->rbt_basic_style_controls('split_section_title_description', 'Content - Description', '.rainbow-splite-style .section-title p');

        // List Component
        $this->rbt_basic_style_controls('split_list_item', 'List Item', 'rainbow-splite-style .split-inner .split-list li');


        // Link Style
        $this->rbt_link_controls_style('split_button_style', 'Button', '.btn-default', 'btn-medium', 'btn-default');



        $this->rbt_section_style_controls('split_content_style', 'Content Area', '.rainbow-splite-style .split-inner');
        $this->rbt_section_style_controls('split_section_style', 'Section Area', '.rainbow-split-area');


    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();



        // Image Settings
        if( $settings['split_thumbnail_position'] == 'right'){
            $thumbnail_col_class = "col-lg-12 col-xl-6 col-12 order-2";
            $content_col_class = "col-lg-12 col-xl-6 col-12 order-1";
            $thumbnail_class = "image-right-content";
        } else {
            $thumbnail_col_class = "col-lg-12 col-xl-6 col-12";
            $content_col_class = "col-lg-12 col-xl-6 col-12";
            $thumbnail_class = "image-left-content";
        }

        // Content
        $content_bg_color = ($settings['split_content_background'] == 'solid') ? "bg-color-blackest" : "";


        ?>
<?php if ( $settings['tp_design_style']  == 'layout-2' ):?>

<!--Start Section Two Area  -->
<div class="slider-area rainbow-section-gap">
    <div class="container">
        <div class="row align-items-center">
            <div class="<?php echo esc_attr($thumbnail_col_class) ?>">
                <div class="thumbnail <?php echo esc_attr($thumbnail_class) ?>">
                    <?php
                        $this->add_render_attribute('split_thumbnail', 'src', $settings['split_thumbnail']['url']);
                        $this->add_render_attribute('split_thumbnail', 'alt', Control_Media::get_image_alt($settings['split_thumbnail']));
                        $this->add_render_attribute('split_thumbnail', 'title', Control_Media::get_image_title($settings['split_thumbnail']));
                        $this->add_render_attribute('split_thumbnail', 'class', 'w-100');
                        ?>
                    <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'split_thumbnail_size', 'split_thumbnail'); ?>
                </div>
            </div>
            <div class="col-lg-6 col-md-6 col-sm-12">
                <div
                    class="inner Collaborate-inner <?php echo esc_attr($settings['rbt_split_area_title_align']) ?>">
                    <?php $this->rbt_section_title_render('split_area_title', $this->get_settings()); ?>
                </div>
                <?php if ($settings['video_title']) : ?>
                <div class="button-group">
                    <a class="btn-collaborate-play popup-video"
                        href="<?php echo esc_url($settings['video_url']); ?>">
                        <i
                            class="feather-play"></i><span><?php echo rbt_kses_basic($settings['video_title']); ?></span>
                    </a>
                </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>
<!--End Section Two Area  -->
<?php elseif ( $settings['tp_design_style']  == 'layout-3' ):?>
<!--Start Section Three Area  -->
<div class="slider-area rainbow-section-gap ">
    <div class="container">
        <div class="row align-items-center">

            <div class="col-lg-6 col-md-6 col-sm-12">
                <div class="inner Collaborate-inner <?php echo esc_attr($settings['rbt_split_area_title_align']) ?>">
                    <?php $this->rbt_section_title_render('split_area_title', $this->get_settings()); ?>
                </div>
                <?php if ($settings['video_title']) : ?>
                <div class="button-group">
                    <a class="btn-collaborate-play popup-video" href="<?php echo esc_url($settings['video_url']); ?>">
                        <i class="feather-play"></i><span><?php echo rbt_kses_basic($settings['video_title']); ?></span>
                    </a>
                </div>
                <?php endif; ?>
            </div>

            <div class="<?php echo esc_attr($thumbnail_col_class) ?>">
                <div class="thumbnail <?php echo esc_attr($thumbnail_class) ?>">
                    <?php
                        $this->add_render_attribute('split_thumbnail', 'src', $settings['split_thumbnail']['url']);
                        $this->add_render_attribute('split_thumbnail', 'alt', Control_Media::get_image_alt($settings['split_thumbnail']));
                        $this->add_render_attribute('split_thumbnail', 'title', Control_Media::get_image_title($settings['split_thumbnail']));
                        $this->add_render_attribute('split_thumbnail', 'class', 'w-100');
                        ?>
                    <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'split_thumbnail_size', 'split_thumbnail'); ?>
                </div>
            </div>

        </div>
    </div>
</div>
<!--End Section Three Area  -->
<?php else:?>
<div class="rainbow-split-area rainbow-section-gap">
    <div class="wrapper">

        <?php if($settings['rbt_split_area_title_section_title_show'] == 'yes'){ ?>
        <div class="row">
            <div class="col-lg-12 mb--40">
                <div class="section-title <?php echo esc_attr($settings['rbt_split_area_title_align']) ?>">
                    <?php $this->rbt_section_title_render('split_area_title', $this->get_settings()); ?>
                </div>
            </div>
        </div>
        <?php } ?>

        <div class="rainbow-splite-style <?php echo esc_attr($content_bg_color) ?>">
            <div class="split-wrapper">
                <div class="row g-0 radius-10 align-items-center">
                    <?php if ($settings['split_thumbnail']['url'] || $settings['split_thumbnail']['id']) : ?>
                    <div class="<?php echo esc_attr($thumbnail_col_class) ?>">
                        <div class="thumbnail <?php echo esc_attr($thumbnail_class) ?>">
                            <?php
                                        $this->add_render_attribute('split_thumbnail', 'src', $settings['split_thumbnail']['url']);
                                        $this->add_render_attribute('split_thumbnail', 'alt', Control_Media::get_image_alt($settings['split_thumbnail']));
                                        $this->add_render_attribute('split_thumbnail', 'title', Control_Media::get_image_title($settings['split_thumbnail']));
                                        $this->add_render_attribute('split_thumbnail', 'class', 'w-100');
                                        ?>
                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'split_thumbnail_size', 'split_thumbnail'); ?>
                        </div>
                    </div>
                    <?php endif; ?>

                    <div class="<?php echo esc_attr($content_col_class) ?>">
                        <ul class="split-inner <?php echo esc_attr($settings['rbt_split_section_title_align']) ?>">

                            <div class="section-title section-title--2">

                                <?php $this->rbt_section_title_render('split_section_title', $this->get_settings()); ?>

                            </div>

                            <?php if ($settings['lists']){ ?>
                            <ul class="split-list">
                                <?php foreach ( $settings['lists'] as $index => $item ){ ?>
                                <li><?php echo esc_html($item['list_title']); ?></li>
                                <?php } ?>
                            </ul>
                            <?php } ?>

                            <?php if($settings['rbt_split_button_button_show'] === 'yes'){ ?>
                            <div class="view-more-button mt--35">
                                <?php $this->rbt_link_control_render('split_button', $this->get_settings()); ?>
                            </div>
                            <?php } ?>

                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
</div>
<?php
    endif; 
    } 

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Split());