<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Tabs extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-tabs';
    }

    public function get_title()
    {
        return esc_html__('Tabs', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['tabs', 'doob'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            '_tab',
            [
                'label' => esc_html__( 'Tab', 'doob' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'tab_title', [
                'label' => esc_html__( 'Tab Item', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'This is tab item title' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'tab_description',
            [
                'label' => esc_html__('Description', 'doob'),
                'description' => rbt_get_allowed_html_desc( 'advance' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => 'Lorem ipsum dolor sit, amet consectetur adipisicing elit. Veniam laudantium neque cumque, magni, modi aut a dolores deleniti recusandae dolor quod aliquid aperiam. Delectus voluptate quam deserunt expedita temporibus ab!',
                'label_block' => true,
            ]
        );
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Repeater Tab', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'tab_title' => esc_html__( 'Our history', 'doob' ),
                    ],
                    [
                        'tab_title' => esc_html__( 'Our mission', 'doob' ),
                    ],
                    [
                        'tab_title' => esc_html__( 'Friendly Support', 'doob' ),
                    ],
                ],
                'title_field' => '{{{ tab_title }}}',
            ]
        );

        $this->add_responsive_control(
            'space_tab_item_align',
            [
                'label' => esc_html__('Alignment', 'doob'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'start' => [
                        'title' => esc_html__('Left', 'doob'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'doob'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'end' => [
                        'title' => esc_html__('Right', 'doob'),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__('Justify', 'doob'),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => 'start',
                'toggle' => false,
            ]
        );

        $this->add_control(
            'space_tab_item',
            [
                'label' => esc_html__( 'Tab space gap', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-default-tab ul li + li' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'space_tab_content',
            [
                'label' => esc_html__( 'Tab Content Space', 'doob' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-default-tab .rainbow-tab-content' => 'padding: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'tab_style',
            [
                'label' => esc_html__( 'Style', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    '1' => esc_html__('Default', 'doob'),
                    '2' => esc_html__('Layout Two', 'doob'),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();

        // Style Component
        $this->rbt_basic_style_controls('tabs_title', 'Title', '.rainbow-default-tab .tab-button .tabs__tab .nav-link .tab_title');
        $this->rbt_basic_style_controls('tabs_description', 'Description', '.rainbow-default-tab .rainbow-tab-content .tab_description');

        $this->rbt_section_style_controls('tabs_title_bg', 'Tab Item', '.rainbow-default-tab .tab-button .tabs__tab .nav-link.active');
        $this->rbt_section_style_controls('tabs_description_bg', 'Tab Content', '.rainbow-default-tab .rainbow-tab-content');

        // Area Style

        $this->rbt_section_style_controls('tabs_area', 'Area Style', '.rainbow-default-tab');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        // Image Settings
        if( $settings['tab_style'] == '2'){
            $style_class = "rainbow-default-tab style-two";
        } else {
            $style_class = "rainbow-default-tab";
        }

        ?>
        <div class="rainbow-default-tab <?php echo esc_attr($style_class); ?>">
            <ul class="nav nav-tabs tab-button justify-content-<?php echo esc_attr($settings['space_tab_item_align']); ?>" id="myTab-<?php echo esc_attr($this->get_id()); ?>" role="tablist">
                <?php
                foreach ( $settings['tabs'] as $index => $item ){
                    $active = ($index == '0') ? "show active" : "";
                    $aria_selected = ($index == '0' ) ? "true" : "false";
                    ?>
                    <li class="nav-item tabs__tab">
                        <a class="nav-link <?php echo esc_attr($active); ?>" id="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" data-bs-toggle="tab" data-bs-target="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" href="#rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tab" aria-controls="tab-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" aria-selected="<?php echo esc_attr($aria_selected); ?>"><span class="tab_title"><?php echo esc_html($item['tab_title']); ?></span></a>
                    </li>
                <?php } ?>

            </ul>
            <div class="rainbow-tab-content tab-content" id="myTabContent-<?php echo esc_attr($this->get_id()); ?>">
                <?php
                foreach ( $settings['tabs'] as $index => $item ){
                    $active = ($index == '0') ? "show active" : "";
                    ?>
                    <div class="tab-pane fade <?php echo esc_attr($active); ?>" id="rn-<?php echo esc_attr($this->get_id()); ?>-<?php echo esc_attr($index); ?>" role="tabpanel">
                        <div class="tab_description"><?php echo rbt_kses_advance($item['tab_description']); ?></div>
                    </div>
                <?php } ?>
            </div>
        </div>
        
        <?php
    }
}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Tabs());

