<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Team extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-team';
    }

    public function get_title()
    {
        return esc_html__('Team', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['team', 'member', 'crew', 'staff', 'person', 'doob'];
    }

    protected static function get_profile_names()
    {
        return [
            '500px' => esc_html__('500px', 'doob'),
            'apple' => esc_html__('Apple', 'doob'),
            'behance' => esc_html__('Behance', 'doob'),
            'bitbucket' => esc_html__('BitBucket', 'doob'),
            'codepen' => esc_html__('CodePen', 'doob'),
            'delicious' => esc_html__('Delicious', 'doob'),
            'deviantart' => esc_html__('DeviantArt', 'doob'),
            'digg' => esc_html__('Digg', 'doob'),
            'dribbble' => esc_html__('Dribbble', 'doob'),
            'email' => esc_html__('Email', 'doob'),
            'facebook' => esc_html__('Facebook', 'doob'),
            'flickr' => esc_html__('Flicker', 'doob'),
            'foursquare' => esc_html__('FourSquare', 'doob'),
            'github' => esc_html__('Github', 'doob'),
            'houzz' => esc_html__('Houzz', 'doob'),
            'instagram' => esc_html__('Instagram', 'doob'),
            'jsfiddle' => esc_html__('JS Fiddle', 'doob'),
            'linkedin' => esc_html__('LinkedIn', 'doob'),
            'medium' => esc_html__('Medium', 'doob'),
            'pinterest' => esc_html__('Pinterest', 'doob'),
            'product-hunt' => esc_html__('Product Hunt', 'doob'),
            'reddit' => esc_html__('Reddit', 'doob'),
            'slideshare' => esc_html__('Slide Share', 'doob'),
            'snapchat' => esc_html__('Snapchat', 'doob'),
            'soundcloud' => esc_html__('SoundCloud', 'doob'),
            'spotify' => esc_html__('Spotify', 'doob'),
            'stack-overflow' => esc_html__('StackOverflow', 'doob'),
            'tripadvisor' => esc_html__('TripAdvisor', 'doob'),
            'tumblr' => esc_html__('Tumblr', 'doob'),
            'twitch' => esc_html__('Twitch', 'doob'),
            'twitter' => esc_html__('Twitter', 'doob'),
            'vimeo' => esc_html__('Vimeo', 'doob'),
            'vk' => esc_html__('VK', 'doob'),
            'website' => esc_html__('Website', 'doob'),
            'whatsapp' => esc_html__('WhatsApp', 'doob'),
            'wordpress' => esc_html__('WordPress', 'doob'),
            'xing' => esc_html__('Xing', 'doob'),
            'yelp' => esc_html__('Yelp', 'doob'),
            'youtube' => esc_html__('YouTube', 'doob'),
        ];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'doob_team',
            [
                'label' => esc_html__('Team', 'doob'),
            ]
        );

        $this->add_control(
            'image',
            [
                'label' => esc_html__('Photo', 'doob'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'large',
                'separator' => 'none',
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Name', 'doob'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => 'Member Name',
                'placeholder' => esc_html__('Type Member Name', 'doob'),
                'separator' => 'before',
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'job_title',
            [
                'label' => esc_html__('Job Title', 'doob'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Sr. Web Developer', 'doob'),
                'placeholder' => esc_html__('Type Member Job Title', 'doob'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'address',
            [
                'label' => esc_html__('Address', 'doob'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('CO Miego, AD,USA', 'doob'),
                'placeholder' => esc_html__('Type Member Address Here', 'doob'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'doob'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Yes, I am a product designer. I have a passion for product design.', 'doob'),
                'placeholder' => esc_html__('Type Member Description', 'doob'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'doob'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'doob'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'doob'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'doob'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'doob'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'doob'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'doob'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h4',
                'toggle' => false,
                'separator' => 'before',
            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label' => esc_html__('Alignment', 'doob'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'text-left' => [
                        'title' => esc_html__('Left', 'doob'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'text-center' => [
                        'title' => esc_html__('Center', 'doob'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'text-right' => [
                        'title' => esc_html__('Right', 'doob'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'toggle' => true,
            ]
        );
        $this->add_control(
            'team_layout',
            [
                'label' => esc_html__('Select Layout', 'doob'),
                'type' => Controls_Manager::SELECT,
                'default' => 'layout-1',
                'options' => [
                    'layout-1' => esc_html__('Layout One', 'doob'),
                    'layout-2' => esc_html__('Layout Two', 'doob'),
                    'layout-3' => esc_html__('Layout Three', 'doob'),
                    'layout-4' => esc_html__('Layout Four', 'doob'),
                ]
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            '_section_social',
            [
                'label' => esc_html__('Social Profiles', 'doob'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'name',
            [
                'label' => esc_html__('Profile Name', 'doob'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'select2options' => [
                    'allowClear' => false,
                ],
                'options' => self::get_profile_names()
            ]
        );

        $repeater->add_control(
            'link', [
                'label' => esc_html__('Profile Link', 'doob'),
                'placeholder' => esc_html__('Add your profile link', 'doob'),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'autocomplete' => false,
                'show_external' => false,
                'condition' => [
                    'name!' => 'email'
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );
        $this->add_control(
            'profiles',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '<# print(name.slice(0,1).toUpperCase() + name.slice(1)) #>',
                'default' => [
                    [
                        'link' => ['url' => 'https://facebook.com/'],
                        'name' => 'facebook'
                    ],
                    [
                        'link' => ['url' => 'https://linkedin.com/'],
                        'name' => 'linkedin'
                    ],
                    [
                        'link' => ['url' => 'https://twitter.com/'],
                        'name' => 'twitter'
                    ]
                ],
            ]
        );

        $this->add_control(
            'show_profiles',
            [
                'label' => esc_html__('Show Profiles', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'doob'),
                'label_off' => esc_html__('Hide', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
                'separator' => 'before',
                'style_transfer' => true,
            ]
        );


        $this->end_controls_section();

        $this->rbt_basic_style_controls('team_name', 'Name', '.title');
        $this->rbt_basic_style_controls('team_job_title', 'Job Title', '.subtitle');
        $this->rbt_basic_style_controls('team_address', 'Address', '.team-form');
        $this->rbt_basic_style_controls('team_description', 'Description', '.description');
        $this->start_controls_section(
            '_section_team_profiles',
            [
                'label' => esc_html__('Social Icons', 'doob'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'links_spacing',
            [
                'label' => esc_html__('Right Spacing', 'doob'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-team ul.social-icon li:not(:last-child)' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'links_padding',
            [
                'label' => esc_html__('Padding', 'doob'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-team ul.social-icon li:not(:last-child)' => 'padding: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'links_icon_size',
            [
                'label' => esc_html__('Icon Size', 'doob'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .rainbow-team ul.social-icon li a' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'links_color',
            [
                'label' => esc_html__('Icon Color', 'doob'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .rainbow-team ul.social-icon li a' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->end_controls_tab();

        $this->end_controls_tab();
        $this->end_controls_tabs();


    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();
        $this->add_render_attribute('title', 'class', 'title');


        if ('layout-2' == $settings['team_layout']) { ?>
            <div class="rainbow-team team-style-default style-two <?php echo esc_attr($settings['align']); ?>">
                <div class="inner">
                    <?php if ($settings['image']['url'] || $settings['image']['id']) :
                        $this->add_render_attribute('image', 'src', $settings['image']['url']);
                        $this->add_render_attribute('image', 'alt', Control_Media::get_image_alt($settings['image']));
                        $this->add_render_attribute('image', 'title', Control_Media::get_image_title($settings['image']));
                        $settings['hover_animation'] = 'disable-animation';
                        ?>
                        <div class="thumbnail">
                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image'); ?>
                        </div>
                    <?php endif; ?>
                    <div class="content">
                        <?php if ($settings['title']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                rbt_kses_basic($settings['title'])
                            );
                        endif; ?>
                        <?php if ($settings['job_title']) : ?>
                            <h6 class="subtitle theme-gradient"><?php echo rbt_kses_basic($settings['job_title']); ?></h6>
                        <?php endif; ?>

                        <?php if ($settings['address']) : ?>
                            <span class="team-form">
                                <i class="feather-map-pin"></i>
                                <span class="location"><?php echo rbt_kses_basic($settings['address']); ?></span>
                            </span>
                        <?php endif; ?>

                        <?php if ($settings['description']) : ?>
                            <p class="description"><?php echo rbt_kses_basic($settings['description']); ?></p>
                        <?php endif; ?>

                        <?php if ($settings['show_profiles'] && is_array($settings['profiles'])) : ?>
                            <ul class="social-icon social-default icon-naked mt--20">
                                <?php
                                foreach ($settings['profiles'] as $profile) :
                                    $icon = $profile['name'];
                                    $url = esc_url($profile['link']['url']);

                                    printf('<li><a target="_blank" rel="noopener"  href="%s" class="elementor-repeater-item-%s"><i class="fab fa-%s" aria-hidden="true"></i></a></li>',
                                        $url,
                                        esc_attr($profile['_id']),
                                        esc_attr($icon)
                                    );
                                endforeach; ?>
                            </ul>
                        <?php endif; ?>

                    </div>
                </div>

            </div>
        <?php } elseif ('layout-3' == $settings['team_layout']) { ?>
            <!-- Start Single Team Area  -->
            <div class="rainbow-team team-style-two <?php echo esc_attr($settings['align']); ?>">
                <div class="inner">
                    <?php if ($settings['image']['url'] || $settings['image']['id']) :
                        $this->add_render_attribute('image', 'src', $settings['image']['url']);
                        $this->add_render_attribute('image', 'alt', Control_Media::get_image_alt($settings['image']));
                        $this->add_render_attribute('image', 'title', Control_Media::get_image_title($settings['image']));
                        $settings['hover_animation'] = 'disable-animation';
                        ?>
                        <div class="thumbnail">
                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image'); ?>
                        </div>
                    <?php endif; ?>
                    <div class="content">
                        <?php if ($settings['title']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                rbt_kses_basic($settings['title'])
                            );
                        endif; ?>
                        <?php if ($settings['job_title']) : ?>
                            <h6 class="subtitle theme-gradient"><?php echo rbt_kses_basic($settings['job_title']); ?></h6>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
            <!-- End Single Team Area  -->
        <?php } elseif ('layout-4' == $settings['team_layout']) { ?>
            <!-- Start Single Team Area  -->
            <div class="rainbow-team team-style-three <?php echo esc_attr($settings['align']); ?>">
                <div class="inner">
                    <?php if ($settings['image']['url'] || $settings['image']['id']) :
                        $this->add_render_attribute('image', 'src', $settings['image']['url']);
                        $this->add_render_attribute('image', 'alt', Control_Media::get_image_alt($settings['image']));
                        $this->add_render_attribute('image', 'title', Control_Media::get_image_title($settings['image']));
                        $settings['hover_animation'] = 'disable-animation';
                        ?>
                        <div class="thumbnail">
                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image'); ?>
                        </div>
                    <?php endif; ?>
                    <div class="content">
                        <div class="team-info">
                            <?php if ($settings['title']) :
                                printf('<%1$s %2$s>%3$s</%1$s>',
                                    tag_escape($settings['title_tag']),
                                    $this->get_render_attribute_string('title'),
                                    rbt_kses_basic($settings['title'])
                                );
                            endif; ?>
                            <?php if ($settings['job_title']) : ?>
                                <h6 class="subtitle theme-gradient"><?php echo rbt_kses_basic($settings['job_title']); ?></h6>
                            <?php endif; ?>
                            <?php if ($settings['address']) : ?>
                                <span class="team-form">
                                    <i class="feather-map-pin"></i>
                                    <span class="location"><?php echo rbt_kses_basic($settings['address']); ?></span>
                                </span>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End Single Team Area  -->
        <?php } else { ?>
            <div class="rainbow-team team-style-default <?php echo esc_attr($settings['align']); ?>">
                <div class="inner">
                    <?php if ($settings['image']['url'] || $settings['image']['id']) :
                        $this->add_render_attribute('image', 'src', $settings['image']['url']);
                        $this->add_render_attribute('image', 'alt', Control_Media::get_image_alt($settings['image']));
                        $this->add_render_attribute('image', 'title', Control_Media::get_image_title($settings['image']));
                        $settings['hover_animation'] = 'disable-animation';
                        ?>
                        <div class="thumbnail">
                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image'); ?>
                        </div>
                    <?php endif; ?>
                    <div class="content">
                        <?php if ($settings['title']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                rbt_kses_basic($settings['title'])
                            );
                        endif; ?>
                        <?php if ($settings['job_title']) : ?>
                            <h6 class="subtitle theme-gradient"><?php echo rbt_kses_basic($settings['job_title']); ?></h6>
                        <?php endif; ?>

                        <?php if ($settings['address']) : ?>
                            <span class="team-form">
                                <i class="feather-map-pin"></i>
                                <span class="location"><?php echo rbt_kses_basic($settings['address']); ?></span>
                            </span>
                        <?php endif; ?>

                        <?php if ($settings['description']) : ?>
                            <p class="description"><?php echo rbt_kses_basic($settings['description']); ?></p>
                        <?php endif; ?>

                        <?php if ($settings['show_profiles'] && is_array($settings['profiles'])) : ?>
                            <ul class="social-icon social-default icon-naked mt--20">
                                <?php
                                foreach ($settings['profiles'] as $profile) :
                                    $icon = $profile['name'];
                                    $url = esc_url($profile['link']['url']);

                                    printf('<li><a target="_blank" rel="noopener"  href="%s" class="elementor-repeater-item-%s"><i class="fab fa-%s" aria-hidden="true"></i></a></li>',
                                        $url,
                                        esc_attr($profile['_id']),
                                        esc_attr($icon)
                                    );
                                endforeach; ?>
                            </ul>
                        <?php endif; ?>

                    </div>
                </div>

            </div>
        <?php }

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Team());