<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Testimonial_Slider extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-testimonial-slider';
    }

    public function get_title()
    {
        return esc_html__('Testimonial Slider', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['testimonial', 'review', 'client review', 'quote', 'doob'];
    }

    protected function register_controls()
    {

        // Section Title
        $this->rbt_section_title('review', 'Section - Title and Content', 'Client Feedback', 'Our Testimonial', 'h2', '');


        // Review group
        $this->start_controls_section(
            'review_list',
            [
                'label' => esc_html__( 'Review List', 'doob' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();


        $repeater->add_control(
            'reviewer_image',
            [
                'label' => esc_html__( 'Reviewer Image', 'doob' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );
        $repeater->add_control(
            'reviewer_name', [
                'label' => esc_html__( 'Reviewer Name', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'FATIMA ASRAFY' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'reviewer_title', [
                'label' => esc_html__( 'Reviewer Title', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( '- COO, AMERIMAR ENTERPRISES, INC.' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'reviewer_from', [
                'label' => esc_html__( 'Reviewer From', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'USA' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'review_content',
            [
                'label' => esc_html__( 'Review Content', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 10,
                'default' => 'Aklima The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections Bonorum et Malorum original.',
                'placeholder' => esc_html__( 'Type your review content here', 'doob' ),
            ]
        );

        $this->add_control(
            'reviews_list',
            [
                'label' => esc_html__( 'Review List', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' =>  $repeater->get_controls(),
                'default' => [
                    [
                        'reviewer_name' => esc_html__( 'FATIMA ASRAFY', 'doob' ),
                        'reviewer_title' => esc_html__( '- COO, AMERIMAR ENTERPRISES, INC.', 'doob' ),
                        'review_content' => esc_html__( 'Aklima The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections Bonorum et Malorum original.', 'doob' ),
                    ],
                    [
                        'reviewer_name' => esc_html__( 'FATIMA ASRAFY', 'doob' ),
                        'reviewer_title' => esc_html__( '- COO, AMERIMAR ENTERPRISES, INC.', 'doob' ),
                        'review_content' => esc_html__( 'Aklima The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections Bonorum et Malorum original.', 'doob' ),
                    ],
                    [
                        'reviewer_name' => esc_html__( 'FATIMA ASRAFY', 'doob' ),
                        'reviewer_title' => esc_html__( '- COO, AMERIMAR ENTERPRISES, INC.', 'doob' ),
                        'review_content' => esc_html__( 'Aklima The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections Bonorum et Malorum original.', 'doob' ),
                    ],
                    [
                        'reviewer_name' => esc_html__( 'FATIMA ASRAFY', 'doob' ),
                        'reviewer_title' => esc_html__( '- COO, AMERIMAR ENTERPRISES, INC.', 'doob' ),
                        'review_content' => esc_html__( 'Aklima The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections Bonorum et Malorum original.', 'doob' ),
                    ],
                    [
                        'reviewer_name' => esc_html__( 'FATIMA ASRAFY', 'doob' ),
                        'reviewer_title' => esc_html__( '- COO, AMERIMAR ENTERPRISES, INC.', 'doob' ),
                        'review_content' => esc_html__( 'Aklima The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections Bonorum et Malorum original.', 'doob' ),
                    ],
                    [
                        'reviewer_name' => esc_html__( 'FATIMA ASRAFY', 'doob' ),
                        'reviewer_title' => esc_html__( '- COO, AMERIMAR ENTERPRISES, INC.', 'doob' ),
                        'review_content' => esc_html__( 'Aklima The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections Bonorum et Malorum original.', 'doob' ),
                    ],
                    [
                        'reviewer_name' => esc_html__( 'FATIMA ASRAFY', 'doob' ),
                        'reviewer_title' => esc_html__( '- COO, AMERIMAR ENTERPRISES, INC.', 'doob' ),
                        'review_content' => esc_html__( 'Aklima The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections Bonorum et Malorum original.', 'doob' ),
                    ],
                    [
                        'reviewer_name' => esc_html__( 'FATIMA ASRAFY', 'doob' ),
                        'reviewer_title' => esc_html__( '- COO, AMERIMAR ENTERPRISES, INC.', 'doob' ),
                        'review_content' => esc_html__( 'Aklima The standard chunk of Lorem Ipsum used since the 1500s is reproduced below for those interested. Sections Bonorum et Malorum original.', 'doob' ),
                    ],

                ],
                'title_field' => '{{{ reviewer_name }}}',
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail_size',
                'default' => 'thumbnail',
                'exclude' => ['custom'],
                'separator' => 'none',
            ]
        );
        $this->add_control(
            'quote_icon',
            [
                'label' => esc_html__('Quote icon?', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'doob'),
                'label_off' => esc_html__('Hide', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();

        // layout Panel
        $this->start_controls_section(
            'doob_review_slider_options',
            [
                'label' => esc_html__('Sliding Options', 'doob'),
            ]
        );
        $this->add_control(
            'doob_review_dots',
            [
                'label' => esc_html__('Dots?', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'doob'),
                'label_off' => esc_html__('Hide', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'doob_review_arrow',
            [
                'label' => esc_html__('Arrow Icons?', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'doob'),
                'label_off' => esc_html__('Hide', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'doob_review_infinite',
            [
                'label' => esc_html__('Infinite?', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'doob'),
                'label_off' => esc_html__('No', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'doob_review_autoplay',
            [
                'label' => esc_html__('Autoplay?', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'doob'),
                'label_off' => esc_html__('No', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'doob_review_autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'doob'),
                'type' => Controls_Manager::TEXT,
                'default' => '2500',
                'title' => esc_html__('Enter autoplay speed', 'doob'),
                'label_block' => true,
            ]
        );
        $this->end_controls_section();


        // Style Component
        $this->rbt_basic_style_controls('review_section_before_title', 'Section - Before Title', '.section-title .sub-title');
        $this->rbt_basic_style_controls('review_section_title', 'Section - Title', '.section-title .title');
        $this->rbt_basic_style_controls('review_section_description', 'Section - Description', '.section-title p');

        // Item
        $this->rbt_basic_style_controls('testimonial_content', 'Testimonial - Contenet', '.testimonial-style-two .content .description');
        $this->rbt_basic_style_controls('testimonial_name', 'Testimonial - Name', '..testimonial-style-two .content .client-info .title');
        $this->rbt_basic_style_controls('testimonial_title', 'Testimonial - Title', '.testimonial-style-two .content .client-info .subtitle');
        $this->rbt_basic_style_controls('testimonial_form', 'Testimonial - From', '.testimonial-style-two .content .form');

        // Area
        $this->rbt_section_style_controls('testimonial_area', 'Area Background', '.rn-testimonial-area');


    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        $quote_icon = ($settings['quote_icon'] !== 'yes') ? 'quote-icon-none' : '';

        $carousel_args = [
            'arrows' => ('yes' === $settings['doob_review_arrow']),
            'dots' => ('yes' === $settings['doob_review_dots']),
            'autoplay' => ('yes' === $settings['doob_review_autoplay']),
            'autoplay_speed' => absint($settings['doob_review_autoplay_speed']),
            'infinite' => ('yes' === $settings['doob_review_infinite']),
        ];
        $this->add_render_attribute('doob-carousel-review-data', 'data-settings', wp_json_encode($carousel_args));

        ?>

        <?php if($settings['reviews_list']){ ?>
            <!-- Start testimonial Four -->
            <div class="rainbow-testimonial-area rainbow-section-gap <?php echo esc_attr($quote_icon); ?>">
                <div class="container">
                    <div class="row mb--20">
                        <div class="col-lg-12">
                            <div class="section-title mb--20 mb_sm--0 <?php echo esc_attr($settings['rbt_review_align']) ?>">
                                <?php $this->rbt_section_title_render('review', $this->get_settings()); ?>
                            </div>
                        </div>
                    </div>
                    <div class="row rainbow-slick-dot rainbow-slick-arrow testimonial-activation" <?php echo $this->get_render_attribute_string('doob-carousel-review-data'); ?>>

                    <?php foreach ($settings['reviews_list'] as $index => $item){ ?>

                        <div class="col-lg-12">
                            <!-- Start single Testimonial -->
                            <div class="testimonial-style-two">
                                <div class="row align-items-center row--20">
                                    <div class="order-2 order-md-1 col-lg-6 col-md-8 offset-lg-1">
                                        <div class="content mt_sm--40">
                                            <?php if(!empty($item['reviewer_from'])){?>
                                                <span class="form"><?php echo rbt_kses_basic($item['reviewer_from']); ?></span>
                                            <?php } ?>

                                            <?php if(!empty($item['review_content'])){?>
                                                <p class="description"><?php echo rbt_kses_intermediate($item['review_content']); ?></p>
                                            <?php } ?>

                                            <div class="client-info">
                                                <?php if(!empty($item['reviewer_name'])){?>
                                                    <h4 class="title"><?php echo rbt_kses_basic($item['reviewer_name']); ?></h4>
                                                <?php } ?>
                                                <?php if(!empty($item['reviewer_title'])){?>
                                                    <h6 class="subtitle"><?php echo rbt_kses_basic($item['reviewer_title']); ?></h6>
                                                <?php } ?>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="order-1 order-md-2 col-lg-4 col-md-4">
                                        <div class="thumbnail">
                                            <?php if(!empty(wp_get_attachment_image( $item['reviewer_image']['id']))){ ?>
                                                <?php echo wp_get_attachment_image( $item['reviewer_image']['id'], $settings['thumbnail_size_size'] ); ?>
                                            <?php } else { ?>
                                                <?php echo Group_Control_Image_Size::get_attachment_image_html($item, $settings['thumbnail_size_size'], 'reviewer_image') ?>
                                            <?php } ?>
                                        </div>
                                    </div>


                                </div>
                            </div>
                            <!-- End single Testimonial -->
                        </div>

                    <?php } ?>

                    </div>
                </div>
            </div>
            <!-- End testimonial Four  -->
        <?php } ?>

        <?php
    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Testimonial_Slider());