<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Testimonial extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-testimonial';
    }

    public function get_title()
    {
        return esc_html__('Testimonial', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['testimonial', 'review', 'client review', 'quote', 'member', 'crew', 'staff', 'person', 'doob'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'doob_testimonial',
            [
                'label' => esc_html__('Testimonial', 'doob'),
            ]
        );

        $this->add_control(
            'image',
            [
                'label' => esc_html__('Reviewer Image', 'doob'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'large',
                'separator' => 'none',
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Name', 'doob'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => 'Member Name',
                'placeholder' => esc_html__('Type Name', 'doob'),
                'separator' => 'before',
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'job_title',
            [
                'label' => esc_html__('Job Title', 'doob'),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Sr. Web Developer', 'doob'),
                'placeholder' => esc_html__('Type designation', 'doob'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );
        $this->add_control(
            'description',
            [
                'label' => esc_html__('Description', 'doob'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Doob is a sleek and modern WordPress theme with a clean and minimalist design.', 'doob'),
                'placeholder' => esc_html__('Type your review content here', 'doob'),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'doob'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'doob'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'doob'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'doob'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'doob'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'doob'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'doob'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h4',
                'toggle' => false,
                'separator' => 'before',
            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label' => esc_html__('Alignment', 'doob'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'text-left' => [
                        'title' => esc_html__('Left', 'doob'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'text-center' => [
                        'title' => esc_html__('Center', 'doob'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'text-right' => [
                        'title' => esc_html__('Right', 'doob'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'toggle' => true,
            ]
        );
        $this->add_control(
            'quote_icon',
            [
                'label' => esc_html__('Quote icon?', 'doob'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'doob'),
                'label_off' => esc_html__('Hide', 'doob'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'testimonial_layout',
            [
                'label' => esc_html__('Select Layout', 'doob'),
                'type' => Controls_Manager::SELECT,
                'default' => 'layout-1',
                'options' => [
                    'layout-1' => esc_html__('Layout One', 'doob'),
                    'layout-2' => esc_html__('Layout Two', 'doob'),
                    'layout-3' => esc_html__('Layout Three', 'doob'),
                ]
            ]
        );
        $this->end_controls_section();


        $this->rbt_basic_style_controls('testimonial_name', 'Name', '.title');
        $this->rbt_basic_style_controls('testimonial_job_title', 'Job Title', '.subtitle');
        $this->rbt_basic_style_controls('testimonial_description', 'Description', '.description');

        // Area
        $this->rbt_section_style_controls('testimonial_box', 'Box', '.inner');



        $this->end_controls_tab();
        $this->end_controls_tabs();


    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();
        $this->add_render_attribute('title', 'class', 'title');

        $quote_icon = ($settings['quote_icon'] !== 'yes') ? 'quote-icon-none' : '';

        if ('layout-2' == $settings['testimonial_layout']) { ?>
            <div class="rainbow-box-card card-style-default testimonial-style-one style-two  <?php echo esc_attr($settings['align']); ?> <?php echo esc_attr($quote_icon); ?>">
                <div class="inner">
                    <?php if ($settings['image']['url'] || $settings['image']['id']) :
                        $this->add_render_attribute('image', 'src', $settings['image']['url']);
                        $this->add_render_attribute('image', 'alt', Control_Media::get_image_alt($settings['image']));
                        $this->add_render_attribute('image', 'title', Control_Media::get_image_title($settings['image']));
                        $settings['hover_animation'] = 'disable-animation';
                        ?>
                        <div class="thumbnail">
                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image'); ?>
                        </div>
                    <?php endif; ?>
                    <div class="content">
                        <?php if ($settings['description']) : ?>
                            <p class="description"><?php echo rbt_kses_basic($settings['description']); ?></p>
                        <?php endif; ?>
                        <?php if ($settings['title']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                rbt_kses_basic($settings['title'])
                            );
                        endif; ?>
                        <?php if ($settings['job_title']) : ?>
                            <h6 class="subtitle theme-gradient"><?php echo rbt_kses_basic($settings['job_title']); ?></h6>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php } elseif ('layout-3' == $settings['testimonial_layout']) { ?>
            <div class="rainbow-box-card card-style-default testimonial-style-one style-two border-gradient <?php echo esc_attr($settings['align']); ?> <?php echo esc_attr($quote_icon); ?>">
                <div class="inner">
                    <?php if ($settings['image']['url'] || $settings['image']['id']) :
                        $this->add_render_attribute('image', 'src', $settings['image']['url']);
                        $this->add_render_attribute('image', 'alt', Control_Media::get_image_alt($settings['image']));
                        $this->add_render_attribute('image', 'title', Control_Media::get_image_title($settings['image']));
                        $settings['hover_animation'] = 'disable-animation';
                        ?>
                        <div class="thumbnail">
                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image'); ?>
                        </div>
                    <?php endif; ?>
                    <div class="content">
                        <?php if ($settings['description']) : ?>
                            <p class="description"><?php echo rbt_kses_basic($settings['description']); ?></p>
                        <?php endif; ?>
                        <?php if ($settings['title']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                rbt_kses_basic($settings['title'])
                            );
                        endif; ?>
                        <?php if ($settings['job_title']) : ?>
                            <h6 class="subtitle theme-gradient"><?php echo rbt_kses_basic($settings['job_title']); ?></h6>
                        <?php endif; ?>
                        
                    </div>
                </div>
            </div>
        <?php } else { ?>
            <div class="rainbow-box-card card-style-default testimonial-style-one  <?php echo esc_attr($settings['align']); ?> <?php echo esc_attr($quote_icon); ?>">
                <div class="inner">
                    <?php if ($settings['image']['url'] || $settings['image']['id']) :
                        $this->add_render_attribute('image', 'src', $settings['image']['url']);
                        $this->add_render_attribute('image', 'alt', Control_Media::get_image_alt($settings['image']));
                        $this->add_render_attribute('image', 'title', Control_Media::get_image_title($settings['image']));
                        $settings['hover_animation'] = 'disable-animation';
                        ?>
                        <div class="thumbnail">
                            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'thumbnail', 'image'); ?>
                        </div>
                    <?php endif; ?>
                    <div class="content">
                        <?php if ($settings['description']) : ?>
                            <p class="description"><?php echo rbt_kses_basic($settings['description']); ?></p>
                        <?php endif; ?>
                        <?php if ($settings['title']) :
                            printf('<%1$s %2$s>%3$s</%1$s>',
                                tag_escape($settings['title_tag']),
                                $this->get_render_attribute_string('title'),
                                rbt_kses_basic($settings['title'])
                            );
                        endif; ?>
                        <?php if ($settings['job_title']) : ?>
                            <h6 class="subtitle theme-gradient"><?php echo rbt_kses_basic($settings['job_title']); ?></h6>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php }

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Testimonial());