<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_VideoPopup extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-video-popup';
    }

    public function get_title()
    {
        return esc_html__('Video Popup', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['video popup', 'doob'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'doob_video_popup',
            [
                'label' => esc_html__('Video Popup', 'doob'),
            ]
        );


        $this->add_control(
            'video_popup_layout',
            [
                'label' => esc_html__('Select Layout', 'doob'),
                'type' => Controls_Manager::SELECT,
                'default' => 'basic',
                'options' => [
                    'basic' => esc_html__('Basic', 'doob'),
                    'advance' => esc_html__('Advance', 'doob'),
                ]
            ]
        );

        $this->add_control(
            'rbt_video_popup_video_url',
            [
                'label' => esc_html__( 'Video Link', 'doob' ),
                'description' => 'Video url example: https://www.youtube.com/watch?v=ZOoVOfieAF8',
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'https://www.youtube.com/watch?v=ZOoVOfieAF8',
                'placeholder' => esc_html__( 'Enter your youtube video url hare', 'doob' ),
            ]
        );
        $this->add_control(
            'rbt_video_popup_button_size',
            [
                'label' => esc_html__('Button Size', 'doob'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'size-large' => esc_html__('Large', 'doob'),
                    'size-medium' => esc_html__('Small', 'doob'),
                ],
                'default' => 'size-large',
            ]
        );
        $this->add_control(
            'rbt_video_popup_button_color',
            [
                'label' => esc_html__('Button Color', 'doob'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'theme-color' => esc_html__('Theme Color', 'doob'),
                    'white-color' => esc_html__('White Color', 'doob'),
                    'black-color' => esc_html__('Dark Color', 'doob'),
                ],
                'default' => 'theme-color'
            ]
        );
        $this->add_control(
            'rbt_video_popup_button_radius',
            [
                'label' => esc_html__('Button Border Radius', 'doob'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} a.popup-video' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );




        $this->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'doob'),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => 'Watch the creative process behind the digital marketing.',
                'placeholder' => esc_html__('Type title here', 'doob'),
                'separator' => 'before',
                'dynamic' => [
                    'active' => true,
                ],
                'condition' => [
                    'video_popup_layout' => 'advance',
                ]

            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'doob'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'doob'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'doob'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'doob'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'doob'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'doob'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'doob'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h3',
                'toggle' => false,
                'separator' => 'before',
                'condition' => [
                    'video_popup_layout' => 'advance',
                ]
            ]
        );


        $this->add_control(
            'rbt_video_popup_image',
            [
                'label' => esc_html__( 'Choose Image', 'doob' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'rbt_video_popup_image_size',
                'default' => 'full',
                'exclude' => [
                    'custom'
                ]
            ]
        );
        $this->add_control(
            'rbt_video_popup_image_radius',
            [
                'label' => esc_html__('Image Border Radius', 'doob'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 1000,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .thumbnail img, {{WRAPPER}} .thumbnail img, {{WRAPPER}} .video-gallery-content, {{WRAPPER}} .overlay::before' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'rbt_video_popup_button_position',
            [
                'label' => esc_html__( 'Content Position', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'centercenter' => esc_html__('Center Center', 'doob'),
                    'centertop' => esc_html__('Center Top', 'doob'),
                    'centerbottom' => esc_html__('Center Bottom', 'doob'),
                    'lefttop' => esc_html__('Left Top', 'doob'),
                    'leftbottom' => esc_html__('Left Bottom', 'doob'),
                    'righttop' => esc_html__('Right Top', 'doob'),
                    'rightbottom' => esc_html__('Right Bottom', 'doob'),
                ],
                'default' => 'leftbottom',
                'condition' => [
                    'video_popup_layout' => 'advance',
                ]
            ]
        );
        $this->add_control(
            'rbt_video_popup_overlay',
            [
                'label' => esc_html__( 'Background Overlay', 'doob' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'doob' ),
                'label_off' => esc_html__( 'No', 'doob' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'video_popup_layout' => 'advance',
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'rbt_video_popup_overlay_color',
                'label' => esc_html__('Overlay', 'doob'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .overlay::before',
                'separator' => 'before',
                'condition' => [
                    'rbt_video_popup_overlay' => 'yes',
                    'video_popup_layout' => 'advance',
                ]
            ]
        );


        $this->add_responsive_control(
            'rbt_video_popup_content_padding',
            [
                'label' => esc_html__('Content Padding', 'doob'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .video-gallery-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before',
                'condition' => [
                    'video_popup_layout' => 'advance',
                ]
            ]
        );

        // Height Control
        $this->rbt_height_control();

        $this->end_controls_section();


    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();
        $this->add_render_attribute('title', 'class', 'title');

        $layout = $settings['video_popup_layout'];
        $bg_image = $settings['rbt_video_popup_image']['url'];
        $overlay = ($settings['rbt_video_popup_overlay'] == 'yes') ? "overlay" : "";

        if($layout == 'advance'){ ?>
            <div class="rainbow-gallery icon-center video-gallery-content slider-bg-image rbt-height-control <?php echo esc_attr($overlay); ?> <?php echo esc_attr($settings['rbt_video_popup_button_position']); ?>" style="background-image: url('<?php echo esc_url($bg_image); ?>')">
                <div class="overlay-content">
                    <?php if(!empty($settings['rbt_video_popup_video_url'])){ ?>
                        <a class="btn-default rounded-player popup-video <?php echo esc_attr($settings['rbt_video_popup_button_size']); ?> <?php echo esc_attr($settings['rbt_video_popup_button_color']); ?>" href="<?php echo esc_url($settings['rbt_video_popup_video_url']); ?>">
                            <span> <i class="feather-play"></i> </span>
                        </a>
                    <?php } ?>

                    <?php if ($settings['title']) :
                        printf('<%1$s %2$s>%3$s</%1$s>',
                            tag_escape($settings['title_tag']),
                            $this->get_render_attribute_string('title'),
                            rbt_kses_basic($settings['title'])
                        );
                    endif; ?>
                </div>
            </div>
        <?php } else { ?>
            <div class="video-popup icon-center">
                <div class="thumbnail position-relative rbt-height-control">
                    <?php echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, 'rbt_video_popup_image_size', 'rbt_video_popup_image' );?>
                    <?php if(!empty($settings['rbt_video_popup_video_url'])){ ?>
                        <div class="video-icon">
                            <a class="btn-default rounded-player popup-video <?php echo esc_attr($settings['rbt_video_popup_button_size']); ?> <?php echo esc_attr($settings['rbt_video_popup_button_color']); ?>" href="<?php echo esc_url($settings['rbt_video_popup_video_url']); ?>">
                                <span><i class="feather-play"></i></span>
                            </a>
                        </div>
                    <?php } ?>
                </div>
            </div>
        <?php } ?>











        <?php
    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_VideoPopup());