<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Working_Process_Vertical extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-working-process-vertical';
    }

    public function get_title()
    {
        return esc_html__('Working Process Vertical', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['working process', 'vertical', 'timeline', 'step', 'doob'];
    }

    protected function register_controls()
    {

        // Title and content
        $this->rbt_section_title('workingprocessvertical', 'Section - Title and Content', 'Timeline', 'Working Process', 'h2', '');


        $this->start_controls_section(
            'doob_working_process_vertical_wrapper',
            [
                'label' => esc_html__('Working Process', 'doob'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'doob_working_process_vertical_step', [
                'label' => esc_html__( 'Step Text', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Step 1' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'doob_working_process_vertical_title', [
                'label' => esc_html__( 'Title', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Knowledge' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'doob_working_process_vertical_description',
            [
                'label' => esc_html__('Description', 'doob'),
                'description' => rbt_get_allowed_html_desc( 'advance' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__( 'This is the initial stage where the agency seeks to understand' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'doob_working_process_vertical_image',
            [
                'label' => esc_html__( 'Working Process Image', 'doob' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );
        $repeater->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail_size',
                'default' => 'thumbnail',
                'exclude' => ['custom'],
                'separator' => 'none',
            ]
        );
        $this->add_control(
            'doob_working_process_vertical',
            [
                'label' => esc_html__( 'Repeater Working Process', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'doob_working_process_vertical_step' => esc_html__( 'Step 01', 'doob' ),
                        'doob_working_process_vertical_title' => esc_html__( 'Knowledge', 'doob' ),
                        'doob_working_process_vertical_description' => esc_html__( 'This is the initial stage where the agency seeks to understand', 'doob' ),
                    ],
                    [
                        'doob_working_process_vertical_step' => esc_html__( 'Step 02', 'doob' ),
                        'doob_working_process_vertical_title' => esc_html__( 'Working', 'doob' ),
                        'doob_working_process_vertical_description' => esc_html__( 'This is where the agency will bring the concepts and prototypes to life.', 'doob' ),
                    ],
                    [
                        'doob_working_process_vertical_step' => esc_html__( 'Step 03', 'doob' ),
                        'doob_working_process_vertical_title' => esc_html__( 'Solution', 'doob' ),
                        'doob_working_process_vertical_description' => esc_html__( 'They will also ensure that the product is compatible with various.', 'doob' ),
                    ],
                ],
                'title_field' => '{{{ doob_working_process_vertical_title }}}',
            ]
        );

        $this->add_control(
            'doob_working_process_vertical_content_width',
            [
                'label' => esc_html__( 'Content Width', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'default' => esc_html__('Box', 'doob'),
                    'container' => esc_html__('Container', 'doob'),
                    'full' => esc_html__('Container Full Wide', 'doob'),
                ],
                'default' => 'default',
            ]
        );
        $this->add_control(
            'doob_working_process_vertical_styles',
            [
                'label' => esc_html__( 'Style', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'primary' => esc_html__('Primary', 'doob'),
                    'gradient' => esc_html__('Gradient', 'doob'),
                    'dot' => esc_html__('Dot', 'doob'),
                ],
                'default' => 'primary',
            ]
        );

        $this->end_controls_section();


        // Style Component
        $this->rbt_basic_style_controls('working_process_vertical_section_before_title', 'Section - Before Title', '.section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('working_process_vertical_section_title', 'Section - Title', '.section-title .title');
        $this->rbt_basic_style_controls('working_process_vertical_section_description', 'Section - Description', '.section-title p');

        $this->rbt_basic_style_controls('working_process_vertical_step', 'Step', '.single-timeline .single-content .inner .content .date-of-timeline');
        $this->rbt_basic_style_controls('working_process_vertical_title', 'Title', '.single-timeline .single-content .inner .content .title');
        $this->rbt_basic_style_controls('working_process_vertical_description', 'Description', '.single-timeline .single-content .inner .content .description');

        $this->rbt_section_style_controls('working_process_vertical', 'Box Style', '.single-timeline .single-content');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        // Content Width
        if($settings['doob_working_process_vertical_content_width'] == 'full'){
            $container_class = "wrapper plr--100 plr_md--15 plr_sm--15";
            $col_class = "col-lg-12 mt--50";
        } elseif ($settings['doob_working_process_vertical_content_width'] == 'container'){
            $container_class = "container";
            $col_class = "col-lg-12 mt--50";
        } else  {
            $container_class = "container";
            $col_class = "col-lg-10 offset-lg-1 mt--50";
        }

        // Style
        if($settings['doob_working_process_vertical_styles'] == 'dot'){
            $style_class = "dark-line";
        } elseif ($settings['doob_working_process_vertical_styles'] == 'gradient'){
            $style_class = "gradient-line";
        } else  {
            $style_class = "no-gradient";
        }

        ?>
        <div class="rainbow-timeline-area rainbow-section-gap">
            <div class="<?php echo esc_attr($container_class); ?>">
                <?php if ($settings['rbt_workingprocessvertical_section_title_show'] == 'yes'){ ?>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="section-title <?php echo esc_attr($settings['rbt_workingprocessvertical_align']); ?>">
                                <?php $this->rbt_section_title_render('workingprocessvertical', $this->get_settings()); ?>
                            </div>
                        </div>
                    </div>
                <?php } ?>
                <div class="row">
                    <div class="<?php echo esc_attr($col_class); ?>">
                        <div class="rainbow-timeline-wrapper timeline-style-one position-relative">
                            <div class="timeline-line"></div>
                            <?php foreach ($settings['doob_working_process_vertical'] as $process ){ ?>
                                
                                <div class="single-timeline elementor-repeater-item-<?php echo $process['_id']; ?>">
                                    <div class="timeline-dot">
                                        <div class="time-line-circle"></div>
                                    </div>
                                    <div class="single-content">
                                        <div class="inner">
                                            <div class="row row--30 align-items-center">
                                                <div class="col-lg-6 mt_md--40 mt_sm--40 order-2 order-lg-1">
                                                    <div class="content">
                                                        <?php if($process['doob_working_process_vertical_step']){ ?>
                                                            <span class="date-of-timeline"><?php echo esc_html($process['doob_working_process_vertical_step']); ?></span>
                                                        <?php } ?>
                                                        <?php if($process['doob_working_process_vertical_title']){ ?>
                                                            <h2 class="title"><?php echo esc_html($process['doob_working_process_vertical_title']); ?></h2>
                                                        <?php } ?>
                                                        <?php if($process['doob_working_process_vertical_description']){ ?>
                                                            <div class="description"><?php echo rbt_kses_advance($process['doob_working_process_vertical_description']); ?></div>
                                                        <?php } ?>
                                                    </div>
                                                </div>
                                                <div class="col-lg-6 order-1 order-lg-2">
                                                    <div class="thumbnail">
                                                        <?php if(!empty(wp_get_attachment_image( $process['doob_working_process_vertical_image']['id']))){ ?>
                                                            <?php echo wp_get_attachment_image( $process['doob_working_process_vertical_image']['id'], $process['thumbnail_size_size'] ); ?>
                                                        <?php } else { ?>
                                                            <?php echo Group_Control_Image_Size::get_attachment_image_html($process, $process['thumbnail_size_size'], 'doob_working_process_vertical_image') ?>
                                                        <?php } ?>

                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Working_Process_Vertical());