<?php
namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Doob_Elementor_Widget_Working_Process extends Widget_Base
{

    use \Elementor\DoobElementCommonFunctions;

    public function get_name()
    {
        return 'doob-working-process';
    }

    public function get_title()
    {
        return esc_html__('Working Process', 'doob');
    }

    public function get_icon()
    {
        return 'rt-icon';
    }

    public function get_categories()
    {
        return ['doob'];
    }

    public function get_keywords()
    {
        return ['working-process','timeline', 'step', 'doob'];
    }

    protected function register_controls()
    {

        // Title and content
        $this->rbt_section_title('workingprocess', 'Section - Title and Content', 'Timeline', 'Working Process', 'h2', '');


        $this->start_controls_section(
            'doob_working_process_wrapper',
            [
                'label' => esc_html__('Working Process', 'doob'),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'doob_working_process_title', [
                'label' => esc_html__( 'Title', 'doob' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Knowledge' , 'doob' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'doob_working_process_description',
            [
                'label' => esc_html__('Description', 'doob'),
                'description' => rbt_get_allowed_html_desc( 'intermediate' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__( 'This is the initial stage where the agency seeks to understand' , 'doob' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'doob_working_process',
            [
                'label' => esc_html__( 'Repeater Working Process', 'doob' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'doob_working_process_title' => esc_html__( 'Knowledge', 'doob' ),
                        'doob_working_process_description' => esc_html__( 'This is the initial stage where the agency seeks to understand', 'doob' ),
                    ],
                    [
                        'doob_working_process_title' => esc_html__( 'Working', 'doob' ),
                        'doob_working_process_description' => esc_html__( 'This is where the agency will bring the concepts and prototypes to life.', 'doob' ),
                    ],
                    [
                        'doob_working_process_title' => esc_html__( 'Solution', 'doob' ),
                        'doob_working_process_description' => esc_html__( 'They will also ensure that the product is compatible with various.', 'doob' ),
                    ],
                    [
                        'doob_working_process_title' => esc_html__( 'Process', 'doob' ),
                        'doob_working_process_description' => esc_html__( 'Once the product has been tested and approved deliver it to the client.', 'doob' ),
                    ],
                ],
                'title_field' => '{{{ doob_working_process_title }}}',
            ]
        );

        $this->add_control(
            'doob_working_process_content_width',
            [
                'label' => esc_html__( 'Content Width', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'default' => esc_html__('Box', 'doob'),
                    'container' => esc_html__('Container', 'doob'),
                    'full' => esc_html__('Container Full Wide', 'doob'),
                ],
                'default' => 'default',
            ]
        );
        $this->add_control(
            'doob_working_process_styles',
            [
                'label' => esc_html__( 'Style', 'doob' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    'primary' => esc_html__('Primary', 'doob'),
                    'gradient' => esc_html__('Gradient', 'doob'),
                    'dot' => esc_html__('Dot', 'doob'),
                ],
                'default' => 'primary',
            ]
        );

        $this->end_controls_section();

        // Columns Panel
        $this->rbt_columns('working_process_columns', 'Columns', '3', '6', '12', '12');


        // Style Component
        $this->rbt_basic_style_controls('working_process_section_before_title', 'Section - Before Title', '.section-title .subtitle .theme-gradient');
        $this->rbt_basic_style_controls('working_process_section_title', 'Section - Title', '.section-title .title');
        $this->rbt_basic_style_controls('working_process_section_description', 'Section - Description', '.section-title p');

        $this->rbt_basic_style_controls('working_process_title', 'Title', '.rainbow-timeline-single .title');
        $this->rbt_basic_style_controls('working_process_description', 'Description', '.rainbow-timeline-single .description');

        $this->rbt_section_style_controls('working_process', 'Box Style', '.rainbow-timeline-area .timeline-style-two');

    }

    protected function render($instance = [])
    {

        $settings = $this->get_settings_for_display();

        // Content Width
        if($settings['doob_working_process_content_width'] == 'full'){
            $container_class = "wrapper plr--100 plr_md--15 plr_sm--15";
            $col_class = "col-lg-12 mt--50";
        } elseif ($settings['doob_working_process_content_width'] == 'container'){
            $container_class = "container";
            $col_class = "col-lg-12 mt--50";
        } else  {
            $container_class = "container";
            $col_class = "col-lg-10 offset-lg-1 mt--50";
        }

        // Style
        if($settings['doob_working_process_styles'] == 'dot'){
            $style_class = "dark-line";
        } elseif ($settings['doob_working_process_styles'] == 'gradient'){
            $style_class = "gradient-line";
        } else  {
            $style_class = "no-gradient";
        }

        ?>
        <div class="rainbow-timeline-area rainbow-section-gap">
            <div class="<?php echo esc_attr($container_class); ?>">
                <?php if ($settings['rbt_workingprocess_section_title_show'] == 'yes'){ ?>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="section-title <?php echo esc_attr($settings['rbt_workingprocess_align']); ?>">
                                <?php $this->rbt_section_title_render('workingprocess', $this->get_settings()); ?>
                            </div>
                        </div>
                    </div>
                <?php } ?>
                <div class="row">
                    <div class="<?php echo esc_attr($col_class); ?>">
                        <div class="timeline-style-two bg-color-blackest">
                            <div class="row row--0">

                                <?php foreach ($settings['doob_working_process'] as $process ){ ?>
                                    <div class="rainbow-timeline-single <?php echo esc_attr($style_class); ?> col-lg-<?php echo esc_attr($settings['rbt_working_process_columns_for_desktop']); ?> col-md-<?php echo esc_attr($settings['rbt_working_process_columns_for_laptop']); ?> col-sm-<?php echo esc_attr($settings['rbt_working_process_columns_for_tablet']); ?> col-<?php echo esc_attr($settings['rbt_working_process_columns_for_mobile']); ?> elementor-repeater-item-<?php echo $process['_id']; ?>">
                                        <div class="rainbow-timeline">
                                            <?php if($process['doob_working_process_title']){ ?>
                                                <h6 class="title sal-animate" data-sal="slide-up" data-sal-duration="700" data-sal-delay="200"><?php echo esc_html($process['doob_working_process_title']); ?></h6>
                                            <?php } ?>

                                            <div class="progress-line">
                                                <div class="line-inner"></div>
                                            </div>
                                            <div class="progress-dot">
                                                <div class="dot-level">
                                                    <div class="dot-inner"></div>
                                                </div>
                                            </div>
                                            <?php if($process['doob_working_process_description']){ ?>
                                                <p class="description sal-animate" data-sal="slide-up" data-sal-duration="700" data-sal-delay="300"><?php echo rbt_kses_intermediate($process['doob_working_process_description']); ?></p>
                                            <?php } ?>

                                        </div>
                                    </div>

                                <?php } ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php

    }

}

Plugin::instance()->widgets_manager->register(new Doob_Elementor_Widget_Working_Process());