<?php
/**
 * @package doob
 */

if( !class_exists('Doob_Social_Media_Widget') ){
    class Doob_Social_Media_Widget extends WP_Widget{
        /**
         * Register widget with WordPress.
         */
        function __construct(){

            $widget_options = array(
                'description'                   => esc_html__('Global Social Media Widget. loaded the icons from theme options.', 'doob'),
                'customize_selective_refresh'   => true,
            );

            parent:: __construct('Doob_Social_Media_Widget', esc_html__( 'Doob: Global Social Media', 'doob'), $widget_options );

        }
        /**
         * Front-end display of widget.
         *
         * @see WP_Widget::widget()
         *
         * @param array $args     Widget arguments.
         * @param array $instance Saved values from database.
         */
        public function widget( $args, $instance ){

            $rainbow_socials = \Doob_Helper::rainbow_socials();

            $has_title = (!empty($instance['title'])) ? "mt--20" : "";

            echo wp_kses_post( $args['before_widget'] );
            if ( ! empty( $instance['title'] ) ) {
                echo wp_kses_post( $args['before_title'] ) . apply_filters( 'widget_title', esc_html( $instance['title'] ) ) . wp_kses_post( $args['after_title'] );
            }
            ?>

            <?php if ($rainbow_socials): ?>
                <div class="social-icone-wrapper <?php echo esc_attr($has_title); ?>">
                    <ul class="social-icon social-default justify-content-start">
                        <?php foreach ($rainbow_socials as $rbsocial): ?>
                            <li><a target="_blank" href="<?php echo esc_url($rbsocial['url']); ?>" title="<?php echo esc_attr($rbsocial['title']); ?>"><i
                                            class="<?php echo esc_attr($rbsocial['icon']); ?>"></i></a></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>

            <?php
            echo wp_kses_post( $args['after_widget'] );
        }
        /**
         * Sanitize widget form values as they are saved.
         *
         * @see WP_Widget::update()
         *
         * @param array $new_instance Values just sent to be saved.
         * @param array $old_instance Previously saved values from database.
         *
         * @return array Updated safe values to be saved.
         */
        public function update( $new_instance, $old_instance ){
            $instance              = array();
            $instance['title']     = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';

            if ( current_user_can( 'unfiltered_html' ) ) {
                $instance['content'] = $new_instance['content'];
            } else {
                $instance['content'] = wp_kses_post( $new_instance['content'] );
            }
            return $instance;
        }

        /**
         * Back-end widget form.
         *
         * @see WP_Widget::form()
         *
         * @param array $instance Previously saved values from database.
         */
        public function form($instance){
            $title = !empty( $instance['title'] ) ? $instance['title'] : '';
            ?>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php echo esc_html__('Title:' ,'doob') ?></label>
                <input id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" class="widefat" value="<?php echo esc_textarea( $title ); ?>">
            </p>
            <?php
        }
    }
}
function Doob_Social_Media_Widget(){
    register_widget('Doob_Social_Media_Widget');
}
add_action('widgets_init','Doob_Social_Media_Widget');