<?php

/**
 * @author  Rainbow-Themes
 * @since   1.0
 * @version 1.0
 * @package papr
 */
trait LayoutTrait
{
    public static function doob_left_get_sidebar()
    {
        $layout_abj = Doob_Helper::doob_layout_style_all();
        $layout = $layout_abj['layout'];
        if ($layout == 'left-sidebar') {
            get_sidebar();
        }
        return;
    }

    public static function doob_right_get_sidebar()
    {
        $layout_abj = Doob_Helper::doob_layout_style_all();
        $layout = $layout_abj['layout'];
        if ($layout == 'right-sidebar') {
            get_sidebar();
        }
        return;
    }

    /**
     * @return array
     * Header Layout
     */
    public static function doob_header_layout()
    {
        $doob_options = Doob_Helper::doob_get_options();
        $theme_prefix = DOOB_THEME_PREFIX;
        $condition_prefix = Doob_Helper::layout_settings();

        /**
         * Get Page Options value
         */
        $header_area = doob_get_acf_data($theme_prefix .  '_show_header');
        $header_style = doob_get_acf_data( $theme_prefix . "_select_header_style");
        $header_sticky = doob_get_acf_data( $theme_prefix . "_header_sticky");
        $header_transparent = doob_get_acf_data( $theme_prefix . "_header_transparent");

        /**
         * Set Condition
         */
        $header_area = (empty($header_area)) ? $doob_options['doob_enable_header'] : $header_area;
        $header_style = (empty($header_style) ||  $header_style == "0") ? $doob_options['doob_select_header_template'] : $header_style;
        $header_sticky = (empty($header_sticky)) ? $doob_options['doob_header_sticky'] : $header_sticky;
        $header_transparent = (empty($header_transparent)) ? $doob_options['doob_header_transparent'] : $header_transparent;
        /**
         * Load Value
         */
        $header_layout = [
            'header_area' => $header_area,
            'header_style' => $header_style,
            'header_sticky' => $header_sticky,
            'header_transparent' => $header_transparent,
        ];
        return $header_layout;

    }
    /**
     * @return array
     * Footer Layout
     */
    public static function doob_footer_layout()
    {
        $doob_options = Doob_Helper::doob_get_options();
        /**
         * Get Page Options value
         */
        $footer_area = doob_get_acf_data('doob_show_footer');
        $footer_style = doob_get_acf_data('doob_select_footer_style');
        /**
         * Set Condition
         */
        $footer_area = (empty($footer_area)) ? $doob_options['doob_footer_enable'] : $footer_area;
        $footer_style = (empty($footer_style) ||  $footer_style == "0") ? $doob_options['doob_select_footer_template'] : $footer_style;

        /**
         * Load Value
         */
        $footer_layout = [
            'footer_area' => $footer_area,
            'footer_style' => $footer_style,
        ];
        return $footer_layout;

    }

    // Sidebar
    public static function doob_sidebar_options()
    {
        $theme_prefix = DOOB_THEME_PREFIX;
        $doob_options = self::doob_get_options();
        $condition_prefix = self::layout_settings();
        $sidebar = get_post_meta(get_the_ID(), $theme_prefix . "_sidebar", true);
        $sidebar = (empty($sidebar) || $sidebar == 'default') ? $doob_options[$condition_prefix . '_sidebar'] : $sidebar;
        return $sidebar;
    }

    // Menu Option
    public static function doob_logos()
    {
        $doob_options = self::doob_get_options();
        // Logo
        $doob_dark_logo = empty($doob_options['logo']['url']) ? self::get_img('logo-black.svg') : $doob_options['logo']['url'];
        $doob_light_logo = empty($doob_options['logo_light']['url']) ? self::get_img('logo-white.svg') : $doob_options['logo_light']['url'];
        $doob_logo_symbol = empty($doob_options['logo_symbol']['url']) ? self::get_img('logo-symbol.svg') : $doob_options['logo_symbol']['url'];

        $menu_option = [
            'doob_dark_logo' => $doob_dark_logo,
            'doob_light_logo' => $doob_light_logo,
            'doob_logo_symbol' => $doob_logo_symbol
        ];
        return $menu_option;
    }

    // Page layout style
    public static function doob_layout_style()
    {
        $theme_prefix = DOOB_THEME_PREFIX;
        $doob_options = self::doob_get_options();
        $condition_prefix = self::layout_settings();

        if (is_single() || is_page()) {
            $layout = get_post_meta(get_the_ID(), $theme_prefix . "_layout", true);
            $layout = (empty($layout) || $layout == 'default') ? $doob_options[$condition_prefix . "_layout"] : $layout;

        } elseif (is_home() || is_archive() || is_search() || is_404()) {
            $layout = (empty($layout) || $layout == 'default') ? $doob_options[$condition_prefix . "_layout"] : $layout;
        }

        return $layout;
    }

    // layout style
    public static function doob_layout_style_all()
    {
        $theme_prefix = DOOB_THEME_PREFIX;
        $doob_options = self::doob_get_options();
        $condition_prefix = self::layout_settings();
        $sidebar 	= Doob_Helper::doob_sidebar_options();
        $has_sidebar_contnet = (is_active_sidebar( $sidebar ) || is_active_sidebar( 'sidebar' )) ? 'col-xl-8 doob-main' : 'col-xl-12 doob-main';

        if (is_single() || is_page()) {
            $layout = get_post_meta(get_the_ID(), $theme_prefix . "_layout", true);
            $layout = (empty($layout) || $layout == 'default') ? $doob_options[$condition_prefix . "_layout"] : $layout;

        } elseif (is_home() || is_archive() || is_search() || is_404()) {
            $layout = (empty($layout) || $layout == 'default') ? $doob_options[$condition_prefix . "_layout"] : $layout;
        }

        // Layout class
        if ($layout == 'full-width') {
            $layout_class = 'col-12';
            $post_class = 'col-lg-6 col-md-6 col-sm-6 col-xs-12 masonry-item';
        } else {
            $layout_class = $has_sidebar_contnet;
            $post_class = 'col-12';
        }

        $layout = [
            'layout' => $layout,
            'layout_class' => $layout_class,
            'post_class' => $post_class,
        ];
        return $layout;
    }

    // layout style
    public static function doob_layout_custom_taxonomy()
    {
        $theme_prefix = DOOB_THEME_PREFIX;
        $doob_options = self::doob_get_options();
        $condition_prefix = self::layout_settings();
        $layout = $doob_options[$condition_prefix . "_layout"];
        $sidebar 	= Doob_Helper::doob_sidebar_options();
        $has_sidebar_contnet = (is_active_sidebar( $sidebar ) || is_active_sidebar( 'sidebar' )) ? 'col-xl-8 doob-main' : 'col-xl-12 doob-main';

        // Layout class
        if ($layout == 'full-width') {
            $layout_class = 'col-12';
            $post_class = 'col-lg-4';
        } else {
            $layout_class = $has_sidebar_contnet;
            $post_class = 'col-lg-6';
        }
        $layout = [
            'layout' => $layout,
            'layout_class' => $layout_class,
            'post_class' => $post_class,
        ];
        return $layout;
    }

    /**  Footer Options */
    public static function doob_active_footer()
    {
        $doob_options = Doob_Helper::doob_get_options();
        if (!$doob_options['footer_area']) {
            return false;
        }
        $footer_column = $doob_options['footer_column'];
        for ($i = 1; $i <= $footer_column; $i++) {
            if (is_active_sidebar('footer-' . $i)) {
                return true;
            }
        }
        return false;
    }


    /**
     * Custom Sidebar
     */
    public static function get_custom_sidebar_fields()
    {
        $theme_prefix = DOOB_WIDGET_PREFIX;
        $sidebar_fields = array();
        $sidebar_fields['sidebar'] = esc_html__('Sidebar', 'doob');
        $sidebars = get_option("{$theme_prefix}_custom_sidebars", array());
        if ($sidebars) {
            foreach ($sidebars as $sidebar) {
                $sidebar_fields[$sidebar['id']] = $sidebar['name'];
            }
        }
        return $sidebar_fields;
    }

    /** layout settings */
    public static function layout_settings()
    {
        $theme_prefix = DOOB_THEME_PREFIX;
        $condition_prefix = DOOB_THEME_PREFIX;
        if (is_single() || is_page()) {
            $post_type = get_post_type();
            $post_id = get_the_id();

            switch ($post_type) {
                case 'page':
                    $theme_prefix = 'page';
                    break;
                case 'post':
                    $theme_prefix = 'single_post';
                    break;
                case "team":
                    $theme_prefix = 'team';
                    break;
                case 'product':
                    $theme_prefix = 'product';
                    break;
                default:
                    $theme_prefix = 'single_post';
                    break;
            }
        } elseif (is_home() || is_archive() || is_search() || is_404()) {
            if (is_author()) {
                $theme_prefix = 'author';
            } elseif (is_search()) {
                $theme_prefix = 'search';
            } elseif (is_post_type_archive("team") || is_tax("team_category")) {
                $theme_prefix = 'team_archive';
            } elseif (function_exists('is_woocommerce') && is_woocommerce()) {
                $theme_prefix = 'shop';
            } else {
                $theme_prefix = 'blog';
            }
        }
        return $theme_prefix;
    }

}
