<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */
if (!class_exists('Redux')) {
    return;
}

Redux::disable_demo();

$opt_name = DOOB_THEME_PREFIX . '_options';
$theme = wp_get_theme();
$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'disable_tracking' => true,
    'display_name' => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version' => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type' => 'submenu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => esc_html__('Doob Theme Options', 'doob'),
    'page_title' => esc_html__('Doob Theme Options', 'doob'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    //'google_api_key'       => 'AIzaSyC2GwbfJvi-WnYpScCPBGIUyFZF97LI0xs',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar' => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-menu',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    'forced_dev_mode_off' => false,
    // Show the time the page took to load, etc
    'update_notice' => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => false,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority' => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => '',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => DOOB_THEME_PREFIX . '_options',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => true,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    'footer_credit' => '&nbsp;',
    // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.
    'hide_expand' => true,
    // This variable determines if the ‘Expand Options’ buttons is visible on the options panel.
    'system_info' => true

);

Redux::setArgs($opt_name, $args);


/*
 * ---> END ARGUMENTS
 */

// -> START Basic Fields

/**
 * General
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('General', 'doob'),
    'id' => 'doob-general-setting-wrap',
    'icon' => 'el el-cog',
));

Redux::setSection($opt_name, array(
    'title' => esc_html__('General', 'doob'),
    'id' => 'doob-general-setting',
    'icon' => 'el el-adjust-alt',
    'subsection' => true,
    'fields' => array(

        array(
            'id' => 'active_dark_mode',
            'type' => 'switch',
            'title' => esc_html__('Switch to Dark Mode', 'doob'),
            'on' => esc_html__('Yes', 'doob'),
            'off' => esc_html__('No', 'doob'),
            'default' => true,
        ),
        array(
            'id' => 'show_ld_switcher_form_user_end',
            'type' => 'switch',
            'title' => esc_html__('Enabled Dark/Light Switcher Form User End', 'doob'),
            'on' => esc_html__('Enabled', 'doob'),
            'off' => esc_html__('Disabled', 'doob'),
            'default' => true,
        ),

        // Start logo
        array(
            'id' => 'doob_logo_type',
            'type' => 'button_set',
            'title' => esc_html__('Select Logo Type', 'doob'),
            'subtitle' => esc_html__('Select logo type, if the image is chosen the existing options of  image below will work, or text option will work. (Note: Used when Transparent Header is enabled.)', 'doob'),
            'options' => array(
                'image' => 'Image',
                'text' => 'Text',
            ),
            'default' => 'image',
        ),
        array(
            'id' => 'doob_head_logo',
            'title' => esc_html__('Default Logo', 'doob'),
            'subtitle' => esc_html__('Upload the main logo of your site. Note: Its work for header layout 1', 'doob'),
            'type' => 'media',
            'default' => array(
                'url' => DOOB_IMG_URL . 'logo.png'
            ),
            'required' => array('doob_logo_type', 'equals', 'image'),
        ),
        array(
            'id' => 'doob_head_logo_dark',
            'title' => esc_html__('Dark Logo', 'doob'),
            'subtitle' => esc_html__('Upload the dark logo of your site. Note: Its work when your header is sticky', 'doob'),
            'type' => 'media',
            'default' => array(
                'url' => DOOB_IMG_URL . 'logo-all-dark.png'
            ),
            'required' => array('doob_logo_type', 'equals', 'image'),
        ),
        array(
            'id' => 'doob_logo_max_height',
            'type' => 'dimensions',
            'units_extended' => true,
            'units' => array('rem', 'px', '%'),
            'title' => esc_html__('Logo Height', 'doob'),
            'subtitle' => esc_html__('Set custom logo height. Default value: 66px', 'doob'),
            'width' => false,
            'mode' => array(
                'width' => false,
                'height' => 'max-height',
            ),
            'output' => array(
                'max-height' => '.header-area .header-wrapper .logo img',
                'height' => '.header-area .header-wrapper .logo img',

            ),
            'required' => array('doob_logo_type', 'equals', 'image'),
        ),
        array(
            'id' => 'doob_logo_padding',
            'type' => 'spacing',
            'title' => esc_html__('Logo Padding', 'doob'),
            'subtitle' => esc_html__('Controls the top, right, bottom and left padding of the logo. (Note: Used when Transparent Header is enabled.)', 'doob'),
            'mode' => 'padding',
            'units' => array('em', 'px'),
            'default' => array(
                'padding-top' => 'px',
                'padding-right' => 'px',
                'padding-bottom' => 'px',
                'padding-left' => 'px',
                'units' => 'px',
            ),
            'output'         => array('.header-area .header-wrapper .logo a'),
            'required' => array('doob_logo_type', 'equals', 'image'),
        ),
        array(
            'id' => 'doob_logo_text',
            'type' => 'text',
            'required' => array('doob_logo_type', 'equals', 'text'),
            'title' => esc_html__('Site Title', 'doob'),
            'desc' => esc_html__('Enter your site title here. (Note: Used when Transparent Header is enabled.)', 'doob'),
            'default' => get_bloginfo('name')
        ),
        array(
            'id' => 'doob_logo_text_font',
            'type' => 'typography',
            'always_display' => true,
            'title' => esc_html__('Site Title Font Settings', 'doob'),
            'required' => array('doob_logo_type', 'equals', 'text'),
            'google' => false,
            'subsets' => false,
            'line-height' => false,
            'text-transform' => true,
            'transition' => false,
            'text-align' => false,
            'preview' => false,
            'all_styles' => true,
            'output' => array('.header-area .header-wrapper .logo a'),
            'units' => 'px',
            'subtitle' => esc_html__('Controls the font settings of the site title. (Note: Used when Transparent Header is enabled.)', 'doob'),
            'default' => array(
                'google' => false,
            )
        ),
        // End logo
        array(
            'id' => 'doob_scroll_to_top_enable',
            'type' => 'button_set',
            'title' => esc_html__('Enable Back To Top', 'doob'),
            'subtitle' => esc_html__('Enable the back to top button that appears in the bottom right corner of the screen.', 'doob'),
            'options' => array(
                'yes' => esc_html__('Yes', 'doob'),
                'no' => esc_html__('No', 'doob'),
            ),
            'default' => 'yes'
        ),
        array(
            'id' => 'doob_preloader',
            'type' => 'button_set',
            'title' => esc_html__('Enable Preloader', 'doob'),
            'options' => array(
                'yes' => esc_html__('Yes', 'doob'),
                'no' => esc_html__('No', 'doob'),
            ),
            'default' => 'no'
        ),
    )
));
//
//Redux::setSection($opt_name,
//    array(
//        'title' => esc_html__('Social Networks', 'doob'),
//        'id' => 'socials_section',
//        'heading' => esc_html__('Social Networks', 'doob'),
//        'icon' => 'el el-twitter',
//        'subsection' => true,
//        'fields' => array(
//            array(
//                'id' => 'doob_social_icons',
//                'type' => 'sortable',
//                'title' => esc_html__('Social Icons', 'doob'),
//                'subtitle' => esc_html__('Enter social links to show the icons. In case you want to hide any field, just keep that field empty', 'doob'),
//                'mode' => 'text',
//                'label' => true,
//                'options' => array(
//                    'facebook-f' => '',
//                    'twitter' => '',
//                    'pinterest-p' => '',
//                    'linkedin-in' => '',
//                    'instagram' => '',
//                    'vimeo-v' => '',
//                    'dribbble' => '',
//                    'behance' => '',
//                    'youtube' => '',
//                    'github' => '',
//                ),
//                'default' => array(
//                    'facebook-f' => 'https://www.facebook.com/',
//                    'twitter' => 'https://twitter.com/',
//                    'pinterest-p' => '',
//                    'linkedin-in' => 'https://linkedin.com/',
//                    'instagram' => 'https://instagram.com/',
//                    'vimeo-v' => '',
//                    'dribbble' => 'https://dribbble.com/',
//                    'behance' => '',
//                    'youtube' => '',
//                    'github' => '',
//                ),
//            )
//        )
//    )
//);
//


Redux::setSection($opt_name,
    array(
        'title' => esc_html__('Contact & Socials', 'doob'),
        'id' => 'socials_section',
        'heading' => esc_html__('Contact & Socials', 'doob'),
        'desc' => esc_html__('In case you want to hide any field, just keep that field empty', 'doob'),
        'icon' => 'el el-twitter',


        'fields' => array(


            array(
                'id' => 'social_title',
                'type' => 'text',
                'title' => esc_html__('Social Title', 'doob'),
                'default' => esc_html__('Follow us', 'doob'),
            ),
            array(
                'id' => 'doob_social_share_title',
                'type' => 'text',
                'title' => esc_html__('Social Title For Headers', 'doob'),
                'default' => esc_html__('find with me', 'doob'),
            ),
            array(
                'id' => 'social_facebook',
                'type' => 'text',
                'title' => esc_html__('Facebook', 'doob'),
                'default' => '#',
            ),
            array(
                'id' => 'social_twitter',
                'type' => 'text',
                'title' => esc_html__('Twitter', 'doob'),
                'default' => '#',
            ),

            array(
                'id' => 'social_linkedin',
                'type' => 'text',
                'title' => esc_html__('Linkedin', 'doob'),
                'default' => '#',
            ),
            array(
                'id' => 'social_youtube',
                'type' => 'text',
                'title' => esc_html__('Youtube', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_instagram',
                'type' => 'text',
                'title' => esc_html__('Instagram', 'doob'),
                'default' => '',
            ),

            array(
                'id' => 'social_tiktok',
                'type' => 'text',
                'title' => esc_html__('TikTok', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_telegram',
                'type' => 'text',
                'title' => esc_html__('Telegram', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_snapchat',
                'type' => 'text',
                'title' => esc_html__('Snapchat', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_whatsapp',
                'type' => 'text',
                'title' => esc_html__('WhatsApp', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_pinterest',
                'type' => 'text',
                'title' => esc_html__('Pinterest', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_reddit',
                'type' => 'text',
                'title' => esc_html__('Reddit', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_qq',
                'type' => 'text',
                'title' => esc_html__('QQ', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_vimeo',
                'type' => 'text',
                'title' => esc_html__('Vimeo', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_skype',
                'type' => 'text',
                'title' => esc_html__('Skype', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_viber',
                'type' => 'text',
                'title' => esc_html__('Viber', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_wordpress',
                'type' => 'text',
                'title' => esc_html__('WordPress', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_discord',
                'type' => 'text',
                'title' => esc_html__('discord', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_stack_overflow',
                'type' => 'text',
                'title' => esc_html__('Stack Overflow', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_stack_dribbble',
                'type' => 'text',
                'title' => esc_html__('Dribbble', 'doob'),
                'default' => '',
            ),
            array(
                'id' => 'social_stack_behance',
                'type' => 'text',
                'title' => esc_html__('Behance', 'doob'),
                'default' => '',
            ),



        )
    )
);

/**
 * TopBar
 */
Redux::setSection($opt_name, array(
        'title' => esc_html__('Top Bar', 'doob'),
        'id' => 'header_topbar',
        'icon' => 'el el-minus',
        'fields' => array(
            array(
                'id' => 'doob_enable_topbar',
                'type' => 'switch',
                'title' => esc_html__('Top Bar', 'doob'),
                'subtitle' => esc_html__('Enable or disable the top bar area.', 'doob'),
                'on' => esc_html__('Enabled', 'doob'),
                'off' => esc_html__('Disabled', 'doob'),
                'default' => true
            ),
            array(
                'id' => 'doob_enable_dismissible',
                'type' => 'switch',
                'title' => esc_html__('Dismissible', 'doob'),
                'subtitle' => esc_html__('Enable or disable close button.', 'doob'),
                'on' => esc_html__('Yes', 'doob'),
                'off' => esc_html__('No', 'doob'),
                'default' => true,
                'required' => array('doob_enable_topbar', 'equals', true),
            ),
            array(
                'id' => 'doob_header_topbar_badge_content',
                'type' => 'text',
                'title' => esc_html__('Badge Content', 'doob'),
                'desc' => esc_html__('In case you want to hide this field, just keep the field empty', 'doob'),
                'default' => esc_html__('Limited Time Offer', 'doob'),
                'required' => array('doob_enable_topbar', 'equals', true),
            ),
            array(
                'id' => 'doob_header_topbar_content',
                'type' => 'textarea',
                'title' => esc_html__('Content', 'doob'),
                'desc' => esc_html__('In case you want to hide this field, just keep the field empty', 'doob'),
                'default' => esc_html__('Intro price. Get Doob for Big Sale -95% off.', 'doob'),
                'required' => array('doob_enable_topbar', 'equals', true),
            ),
            array(
                'id' => 'doob_header_topbar_enable_button',
                'type' => 'switch',
                'title' => esc_html__('Button', 'doob'),
                'subtitle' => esc_html__('Enable or disable button.', 'doob'),
                'on' => esc_html__('Enabled', 'doob'),
                'off' => esc_html__('Disabled', 'doob'),
                'default' => true,
                'required' => array('doob_enable_topbar', 'equals', true),
            ),
            array(
                'id' => 'doob_header_topbar_button_txt',
                'type' => 'text',
                'title' => esc_html__('Button Text', 'doob'),
                'default' => esc_html__('Purchase Now', 'doob'),
                'required' => array('doob_header_topbar_enable_button', 'equals', true),
            ),

            array(
                'id' => 'doob_header_topbar_button_url',
                'type' => 'text',
                'title' => esc_html__('Button Url', 'doob'),
                'default' => '#',
                'required' => array('doob_header_topbar_enable_button', 'equals', true),
            ),
            array(
                'id' => 'doob_header_topbar_button_target',
                'type' => 'select',
                'title' => esc_html__('Button Target', 'doob'),
                'required' => array('doob_header_topbar_enable_button', 'equals', true),
                'options' => array(
                    '_blank' => esc_html__('Blank', 'doob'),
                    '_self' => esc_html__('Self', 'doob'),
                    '_parent' => esc_html__('Parent', 'doob'),
                    '_top' => esc_html__('Top', 'doob'),
                ),
                'default' => '_blank',
            ),
            array(
                'id' => 'doob_header_topbar_button_type',
                'type' => 'select',
                'title' => esc_html__('Button Type', 'doob'),
                'required' => array('doob_header_topbar_enable_button', 'equals', true),
                'options' => array(
                    'btn-default btn-border' => esc_html__('Secondary (Border)', 'doob'),
                    'btn-default' => esc_html__('Primary (Solid)', 'doob'),
                    'btn-read-more' => esc_html__('Link (Underline)', 'doob'),

                ),
                'default' => 'btn-read-more',
            ),
            array(
                'id' => 'doob_header_topbar_button_size',
                'type' => 'select',
                'title' => esc_html__('Button Type', 'doob'),
                'required' => array('doob_header_topbar_enable_button', 'equals', true),
                'options' => array(
                    'btn-extra-large' => esc_html__('Extra Large', 'doob'),
                    'btn-large' => esc_html__('Large', 'doob'),
                    'btn-medium' => esc_html__('Medium', 'doob'),
                    'btn-small' => esc_html__('Small', 'doob'),

                ),
                'default' => 'btn-small',
            ),

            array(
                'id' => 'doob_header_topbar_bg_image',
                'title' => esc_html__('Upload Background Image', 'doob'),
                'subtitle' => esc_html__('Upload the background image of your top bar area', 'doob'),
                'type' => 'media',
                'required' => array('doob_enable_topbar', 'equals', true),
            ),
            array(
                'id'       => 'doob_header_topbar_bg_color',
                'type'     => 'color_gradient',
                'title'    => esc_html__('Background Color', 'doob'),
                'validate' => 'color',
                'output'  =>  array('.header-top-news, .header-top-news-2'),
                'default'        => array(
                    'preview' => false,
                    'from'           => '',
                    'to'             => '',
                ),
                'required' => array('doob_enable_topbar', 'equals', true),
            ),

        )
    )
);

/**
 * Header area
 */
Redux::setSection($opt_name, array(
        'title' => esc_html__('Header', 'doob'),
        'id' => 'header_id',
        'icon' => 'el el-minus',
        'fields' => array(
            array(
                'id' => 'doob_enable_header',
                'type' => 'switch',
                'title' => esc_html__('Header', 'doob'),
                'subtitle' => esc_html__('Enable or disable the header area.', 'doob'),
                'on' => esc_html__('Enabled', 'doob'),
                'off' => esc_html__('Disabled', 'doob'),
                'default' => true
            ),
            // Header Custom Style
            array(
                'id' => 'doob_select_header_template',
                'type' => 'image_select',
                'title' => esc_html__('Select Header Layout', 'doob'),
                'options' => array(
                    '1' => array(
                        'alt' => esc_html__('Header Layout 1', 'doob'),
                        'title' => esc_html__('Header Layout 1', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/header/1.png',
                    ),
                    '2' => array(
                        'alt' => esc_html__('Header Layout 2', 'doob'),
                        'title' => esc_html__('Header Layout 2', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/header/2.png',
                    ),
                    '3' => array(
                        'alt' => esc_html__('Header Layout 3', 'doob'),
                        'title' => esc_html__('Header Layout 3', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/header/3.png',
                    ),
                    '4' => array(
                        'alt' => esc_html__('Header Layout 4', 'doob'),
                        'title' => esc_html__('Header Layout 4', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/header/4.png',
                    ),
                    '5' => array(
                        'alt' => esc_html__('Header Layout 5', 'doob'),
                        'title' => esc_html__('Header Layout 5 (One Page)', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/header/5.png',
                    ),
                ),
                'default' => '1',
                'required' => array('doob_enable_header', 'equals', true),
            ),

            array(
                'id' => 'doob_header_top_left_content',
                'type' => 'textarea',
                'title' => esc_html__('Header Top Left Content', 'doob'),
                'default' => esc_html__('Add your content or HTML code here.', 'doob'),
                'required' => array('doob_select_header_template', 'equals', '4'),
            ),
            array(
                'id' => 'doob_header_top_right_content',
                'type' => 'textarea',
                'title' => esc_html__('Header Top Right Content', 'doob'),
                'default' => esc_html__('Add your content or HTML code here.', 'doob'),
                'required' => array('doob_select_header_template', 'equals', '4'),
            ),

            array(
                'id' => 'doob_header_top_social_icons',
                'type' => 'switch',
                'title' => esc_html__('Header Top Social Icons', 'doob'),
                'desc' => esc_html__('Please go to "Contact & Socials" tab for customize icons', 'doob'),
                'on' => esc_html__('Enabled', 'doob'),
                'off' => esc_html__('Disabled', 'doob'),
                'default' => true,
                'required' => array('doob_select_header_template', 'equals', '4'),
            ),


            array(
                'id' => 'doob_header_btn',
                'type' => 'switch',
                'title' => esc_html__('Header Button', 'doob'),
                'on' => esc_html__('Enabled', 'doob'),
                'off' => esc_html__('Disabled', 'doob'),
                'default' => true,
                'required' => array('doob_enable_header', 'equals', true),
            ),
            array(
                'id' => 'doob_header_buttontext',
                'type' => 'text',
                'title' => esc_html__('Header button Text', 'doob'),
                'default' => esc_html__('BUY NOW', 'doob'),
                'required' => array('doob_header_btn', 'equals', true),
            ),
            array(
                'id' => 'doob_header_buttonUrl',
                'type' => 'text',
                'default' => '#',
                'title' => esc_html__('Button Url', 'doob'),
                'required' => array('doob_header_btn', 'equals', true),

            ),
            array(
                'id' => 'doob_header_sticky',
                'type' => 'switch',
                'title' => esc_html__('Header Sticky', 'doob'),
                'subtitle' => esc_html__('Enable to activate the sticky header.', 'doob'),
                'on' => esc_html__('Enabled', 'doob'),
                'off' => esc_html__('Disabled', 'doob'),
                'default' => false,
                'required' => array('doob_enable_header', 'equals', true),
            ),
            array(
                'id' => 'doob_header_transparent',
                'type' => 'switch',
                'title' => esc_html__('Header Transparent', 'doob'),
                'subtitle' => esc_html__('Enable to make the header area transparent.', 'doob'),
                'on' => esc_html__('Enabled', 'doob'),
                'off' => esc_html__('Disabled', 'doob'),
                'default' => false,
                'required' => array('doob_enable_header', 'equals', true),
            ), // output body class
            array(
                'id' => 'minicart_icon',
                'type' => 'switch',
                'title' => esc_html__('Cart Icon', 'doob'),
                'desc' => esc_html__('WooCommerce plugin must be activated', 'doob'),
                'on' => esc_html__('Enabled', 'doob'),
                'off' => esc_html__('Disabled', 'doob'),
                'default' => false,
                'required' => array('doob_enable_header', 'equals', true),
            ),

        )
    )
);

/**
 * Footer area
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Footer', 'doob'),
    'id' => 'doob_footer_section',
    'icon' => 'el el-photo',
    'fields' => array(
        array(
            'id' => 'doob_footer_enable',
            'type' => 'switch',
            'title' => esc_html__('Footer', 'doob'),
            'subtitle' => esc_html__('Enable or disable the footer area.', 'doob'),
            'on' => esc_html__('Enabled', 'doob'),
            'off' => esc_html__('Disabled', 'doob'),
            'default' => true,
        ),
        // Header Custom Style
        array(
            'id' => 'doob_select_footer_template',
            'type' => 'image_select',
            'title' => esc_html__('Select Footer Layout', 'doob'),
            'options' => array(
                '1' => array(
                    'alt' => esc_html__('Footer Layout 1', 'doob'),
                    'title' => esc_html__('Footer Layout 1', 'doob'),
                    'img' => get_template_directory_uri() . '/assets/images/optionframework/footer/1.png',
                ),
                '2' => array(
                    'alt' => esc_html__('Footer Layout 2', 'doob'),
                    'title' => esc_html__('Footer Layout 2', 'doob'),
                    'img' => get_template_directory_uri() . '/assets/images/optionframework/footer/2.png',
                ),
                '3' => array(
                    'alt' => esc_html__('Footer Layout 3', 'doob'),
                    'title' => esc_html__('Footer Layout 3', 'doob'),
                    'img' => get_template_directory_uri() . '/assets/images/optionframework/footer/3.png',
                ),
                '4' => array(
                    'alt' => esc_html__('Footer Layout 4', 'doob'),
                    'title' => esc_html__('Footer Layout 4', 'doob'),
                    'img' => get_template_directory_uri() . '/assets/images/optionframework/footer/4.png',
                ),
                '5' => array(
                    'alt' => esc_html__('Footer Layout 5', 'doob'),
                    'title' => esc_html__('Footer Layout 5', 'doob'),
                    'img' => get_template_directory_uri() . '/assets/images/optionframework/footer/5.png',
                ),
                '6' => array(
                    'alt' => esc_html__('Footer Layout 6', 'doob'),
                    'title' => esc_html__('Footer Layout 6', 'doob'),
                    'img' => get_template_directory_uri() . '/assets/images/optionframework/footer/6.png',
                ),
                '7' => array(
                    'alt' => esc_html__('Footer Layout 6', 'doob'),
                    'title' => esc_html__('Footer Layout 6', 'doob'),
                    'img' => get_template_directory_uri() . '/assets/images/optionframework/footer/6.png',
                ),
            ),
            'default' => '1',
            'required' => array('doob_footer_enable', 'equals', true),
        ),

        /**
         * CTA Section
         */
        array(
            'id' => 'cta_pre_title',
            'type' => 'text',
            'title' => esc_html__('CTA - Pre Title', 'doob'),
            'default' => esc_html__( 'Before Content', 'doob' ),
            'required' => array('doob_select_footer_template', 'equals', array('1', '3', '6')),
        ),
        array(
            'id' => 'cta_title',
            'type' => 'textarea',
            'title' => esc_html__('CTA - Content', 'doob'),
            'default' => esc_html__( "Ready to start creating a standard website?", "doob" ),
            'required' => array('doob_select_footer_template', 'equals', array('1', '3', '6')),
        ),
        array(
            'id' => 'cta_desc',
            'type' => 'textarea',
            'title' => esc_html__('CTA - Description', 'doob'),
            'default' => esc_html__( "Finest choice for your home & office", "doob" ),
            'required' => array('doob_select_footer_template', 'equals', array('1', '3', '6')),
        ),

        array(
            'id' => 'cta_newsletter',
            'type' => 'text',
            'title' => esc_html__('Newsletter Shortcode', 'doob'),
            'desc' => esc_html__('You can find shortcode here: MC4WP › Forms › Form ', 'doob'),
            'default' => esc_html__( "", "doob" ),
            'placeholder' => esc_html__( "Enter your form shortcode here", "doob" ),
            'required' => array('doob_select_footer_template', 'equals', array('6')),
        ),

        array(
            'id' => 'cta_btn_title',
            'type' => 'text',
            'title' => esc_html__('CTA Button Title', 'doob'),
            'default' => esc_html__( "CONTACT US", "doob" ),
            'required' => array('doob_select_footer_template', 'equals', array('1', '3')),
        ),
        array(
            'id' => 'cta_btn_url',
            'type' => 'text',
            'title' => esc_html__('CTA Button UTL', 'doob'),
            'default' => "#",
            'required' => array('doob_select_footer_template', 'equals', array('1', '3')),
        ),


        array(
            'id' => 'doob_footer_bottom_social_icons',
            'type' => 'switch',
            'title' => esc_html__('Footer Bottom Social Icons', 'doob'),
            'desc' => esc_html__('Please go to "Contact & Socials" tab for customize icons', 'doob'),
            'on' => esc_html__('Enabled', 'doob'),
            'off' => esc_html__('Disabled', 'doob'),
            'default' => true,
            // 'required' => array('doob_select_footer_template', 'equals', ['2', '3']),
        ),


        // Footer Bottom
        array(
            'id' => 'doob_copyright_contact',
            'type' => 'editor',
            'title' => esc_html__('Copyright Content', 'doob'),
            'args' => array(
                'teeny' => true,
                'textarea_rows' => 5,
            ),
            'default' => esc_html__('Copyright © 2022 Doob WordPress Theme.', 'doob'),
            'required' => array('doob_footer_enable', 'equals', true),
        ),

    )
));

/**
 * Page Banner/Title section
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('
    Page Banner', 'doob'),
    'id' => 'doob_banner_section',
    'icon' => 'el el-website',
    'fields' => array(
        array(
            'id' => 'doob_banner_enable',
            'type' => 'switch',
            'title' => esc_html__('Banner', 'doob'),
            'subtitle' => esc_html__('Enable or disable the banner area.', 'doob'),
            'on' => esc_html__('Enabled', 'doob'),
            'off' => esc_html__('Disabled', 'doob'),
            'default' => true,
        ),
        // Header Custom Style
        array(
            'id' => 'doob_select_banner_template',
            'type' => 'image_select',
            'title' => esc_html__('Select banner Layout', 'doob'),
            'options' => array(
                '1' => array(
                    'alt' => esc_html__('Banner Layout 1', 'doob'),
                    'title' => esc_html__('Banner Layout 1', 'doob'),
                    'img' => get_template_directory_uri() . '/assets/images/optionframework/banner/1.png',
                ),
                '2' => array(
                    'alt' => esc_html__('Banner Layout 2', 'doob'),
                    'title' => esc_html__('Banner Layout 2', 'doob'),
                    'img' => get_template_directory_uri() . '/assets/images/optionframework/banner/2.png',
                ),
            ),
            'default' => '1',
            'required' => array('doob_banner_enable', 'equals', true),
        ),
        array(
            'id' => 'doob_breadcrumb_enable',
            'type' => 'switch',
            'title' => esc_html__('Breadcrumb', 'doob'),
            'subtitle' => esc_html__('Enable or disable the breadcrumb area.', 'doob'),
            'default' => true,
            'required' => array('doob_select_banner_template', 'equals', '1'),
        ),
        array(
            'id' => 'doob_select_banner_image',
            'title' => esc_html__('Upload Banner Background Image', 'doob'),
            'subtitle' => esc_html__('Upload the banner background image of your banner layout one & two.', 'doob'),
            'type' => 'media',
            'required' => array('doob_banner_enable', 'equals', true),
        ),
        array(
            'id'       => 'doob_banner_image_overlay_gradient_color_opt',
            'type'     => 'color_gradient',
            'title'    => esc_html__('Banner Background Image Overlay', 'doob'),
            'validate' => 'color',
            'output'  =>  array('.breadcrumb-area:before, .rn-page-title-area:before'),
            'default'        => array(
                'preview' => false,
                'from'           => '',
                'to'             => '',
            ),
            'required' => array('doob_banner_enable', 'equals', true),
        ),

    )
));

/**
 * Blog Panel
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Blog', 'doob'),
    'id' => 'doob_blog',
    'icon' => 'el el-file-edit',
));

// Blog Options
Redux::setSection($opt_name, array(
        'title' => esc_html__('Archive', 'doob'),
        'id' => 'doob_blog_genaral',
        'icon' => 'el el-folder-open',
        'subsection' => true,
        'fields' => array(
            array(
                'id' => 'doob_blog_text',
                'type' => 'text',
                'title' => esc_html__('Default Title', 'doob'),
                'subtitle' => esc_html__('Controls the Default title of the page which is displayed on the page title are on the blog page.', 'doob'),
                'default' => esc_html__('Blog', 'doob'),
            ),
            array(
                'id' => 'doob_blog_sidebar',
                'type' => 'image_select',
                'title' => esc_html__('Select Blog Sidebar', 'doob'),
                'subtitle' => esc_html__('Choose your favorite blog layout', 'doob'),
                'options' => array(
                    'left' => array(
                        'alt' => esc_html__('Left Sidebar', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/left-sidebar.png',
                        'title' => esc_html__('Left Sidebar', 'doob'),
                    ),
                    'right' => array(
                        'alt' => esc_html__('Right Sidebar', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/right-sidebar.png',
                        'title' => esc_html__('Right Sidebar', 'doob'),
                    ),
                    'no' => array(
                        'alt' => esc_html__('No Sidebar', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/no-sidebar.png',
                        'title' => esc_html__('No Sidebar', 'doob'),
                    ),
                ),
                'default' => 'right',
            ),
            array(
                'id' => 'doob_show_post_author_meta',
                'type' => 'button_set',
                'title' => esc_html__('Author', 'doob'),
                'subtitle' => esc_html__('Show or hide the author of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_show_post_publish_date_meta',
                'type' => 'button_set',
                'title' => esc_html__('Publish Date', 'doob'),
                'subtitle' => esc_html__('Show or hide the publish date of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_show_post_updated_date_meta',
                'type' => 'button_set',
                'title' => esc_html__('Updated Date', 'doob'),
                'subtitle' => esc_html__('Show or hide the updated date of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'no',
            ),
            array(
                'id' => 'doob_show_post_reading_time_meta',
                'type' => 'button_set',
                'title' => esc_html__('Reading Time', 'doob'),
                'subtitle' => esc_html__('Show or hide the publish content reading time.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_show_post_comments_meta',
                'type' => 'button_set',
                'title' => esc_html__('Comments', 'doob'),
                'subtitle' => esc_html__('Show or hide the comments of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'no',
            ),
            array(
                'id' => 'doob_show_post_categories_meta',
                'type' => 'button_set',
                'title' => esc_html__('Categories', 'doob'),
                'subtitle' => esc_html__('Show or hide the categories of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'no',
            ),
            array(
                'id' => 'doob_show_post_tags_meta',
                'type' => 'button_set',
                'title' => esc_html__('Tags', 'doob'),
                'subtitle' => esc_html__('Show or hide the tags of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'no',
            ),
            array(
                'id' => 'doob_enable_readmore_btn',
                'type' => 'button_set',
                'title' => esc_html__('Read More Button', 'doob'),
                'subtitle' => esc_html__('Show or hide the read more button of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_readmore_text',
                'type' => 'text',
                'title' => esc_html__('Read More Text', 'doob'),
                'subtitle' => esc_html__('Set the Default title of read more button.', 'doob'),
                'default' => esc_html__('Read More', 'doob'),
                'required' => array('doob_enable_readmore_btn', 'equals', 'yes'),
            ),
        )
    )
);

/**
 * Single Post
 */
Redux::setSection($opt_name, array(
        'title' => esc_html__('Single', 'doob'),
        'id' => 'doob_blog_details_id',
        'icon' => 'el el-website',
        'subsection' => true,
        'fields' => array(
//            array(
//                'id' => 'doob_single_pos',
//                'type' => 'image_select',
//                'title' => esc_html__('Blog Details Layout', 'doob'),
//                'subtitle' => esc_html__('Choose your favorite layout', 'doob'),
//                'options' => array(
//                    'left' => array(
//                        'alt' => esc_html__('Left Sidebar', 'doob'),
//                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/left-sidebar.png',
//                        'title' => esc_html__('Left Sidebar', 'doob'),
//                    ),
//                    'right' => array(
//                        'alt' => esc_html__('Right Sidebar', 'doob'),
//                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/right-sidebar.png',
//                        'title' => esc_html__('Right Sidebar', 'doob'),
//                    ),
//                    'full' => array(
//                        'alt' => esc_html__('Full Width', 'doob'),
//                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/no-sidebar.png',
//                        'title' => esc_html__('Full Width', 'doob'),
//                    ),
//                ),
//                'default' => 'full',
//            ),
            array(
                'id' => 'doob_show_blog_details_author_meta',
                'type' => 'button_set',
                'title' => esc_html__('Author', 'doob'),
                'subtitle' => esc_html__('Show or hide the author of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_show_blog_details_publish_date_meta',
                'type' => 'button_set',
                'title' => esc_html__('Publish Date', 'doob'),
                'subtitle' => esc_html__('Show or hide the publish date of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_show_blog_details_updated_date_meta',
                'type' => 'button_set',
                'title' => esc_html__('Updated Date', 'doob'),
                'subtitle' => esc_html__('Show or hide the updated date of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'no',
            ),
            array(
                'id' => 'doob_show_blog_details_reading_time_meta',
                'type' => 'button_set',
                'title' => esc_html__('Reading Time', 'doob'),
                'subtitle' => esc_html__('Show or hide the publish content reading time.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_show_blog_details_comments_meta',
                'type' => 'button_set',
                'title' => esc_html__('Comments', 'doob'),
                'subtitle' => esc_html__('Show or hide the comments of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'no',
            ),
            array(
                'id' => 'doob_show_blog_details_categories_meta',
                'type' => 'button_set',
                'title' => esc_html__('Categories', 'doob'),
                'subtitle' => esc_html__('Show or hide the categories of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'no',
            ),
            array(
                'id' => 'doob_show_blog_details_tags_meta',
                'type' => 'button_set',
                'title' => esc_html__('Tags', 'doob'),
                'subtitle' => esc_html__('Show or hide the tags of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'no',
            ),

        )
    )
);
/**
 * Portfolio Panel
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Portfolio', 'doob'),
    'id' => 'doob_portfolio',
    'icon' => 'el el-th',
));
/**
 * Single Archive
 */
Redux::setSection($opt_name, array(
        'title' => esc_html__('Archive', 'doob'),
        'id' => 'doob_portfolio_archive_id',
        'icon' => 'el el-folder-open',
        'subsection' => true,
        'fields' => array(
            // Client Name

            array(
                'id' => 'doob_show_project_category',
                'type' => 'button_set',
                'title' => esc_html__('Category', 'doob'),
                'subtitle' => esc_html__('Show or hide the category of blog post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_enable_case_study_button',
                'type' => 'button_set',
                'title' => esc_html__('Portfolio Button (View Details)', 'doob'),
                'subtitle' => esc_html__('Show or hide the portfolio case study (View Details) button of portfolio archive and addons', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'no',
            ),
            array(
                'id' => 'doob_enable_case_study_button_text',
                'type' => 'text',
                'title' => esc_html__('Portfolio Button Text', 'doob'),
                'default' => esc_html__('Case Study', 'doob'),
                'required' => array('doob_enable_case_study_button', 'equals', 'yes'),
            ),
            array(
                'id' => 'doob_project_image_size',
                'type' => 'select',
                'title' => esc_html__('Select Thumbnail Size', 'doob'),
                'options' => doob_get_thumbnail_sizes(),
                'default' => 'doob-thumbnail-sm',
            ),
            array(
                'id' => 'doob_project_archive_sidebar',
                'type' => 'image_select',
                'title' => esc_html__('Select Project Archive Sidebar', 'doob'),
                'subtitle' => esc_html__('Choose your favorite layout', 'doob'),
                'options' => array(
                    'left' => array(
                        'alt' => esc_html__('Left Sidebar', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/left-sidebar.png',
                        'title' => esc_html__('Left Sidebar', 'doob'),
                    ),
                    'right' => array(
                        'alt' => esc_html__('Right Sidebar', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/right-sidebar.png',
                        'title' => esc_html__('Right Sidebar', 'doob'),
                    ),
                    'no' => array(
                        'alt' => esc_html__('No Sidebar', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/no-sidebar.png',
                        'title' => esc_html__('No Sidebar', 'doob'),
                    ),
                ),
                'default' => 'no',
            ),
            array(
                'id'       => 'doob_project_archive_col_lg',
                'type'     => 'select',
                'title'    => esc_html__('Select Column for Desktops', 'doob'),
                'subtitle' => esc_html__('Desktops: ≥ 1200px', 'doob'),
                'options'  => array(
                    '12' => esc_html__('1 Col', 'doob'),
                    '6' => esc_html__('2 Col', 'doob'),
                    '4' => esc_html__('3 Col', 'doob'),
                    '3' => esc_html__('4 Col', 'doob'),
                ),
                'default'  => '4',
            ),
            array(
                'id'       => 'doob_project_archive_col_md',
                'type'     => 'select',
                'title'    => esc_html__('Select Column for Tabs', 'doob'),
                'subtitle'    => esc_html__('Tabs: ≥ 992px', 'doob'),
                'options'  => array(
                    '12' => esc_html__('1 Col', 'doob'),
                    '6' => esc_html__('2 Col', 'doob'),
                    '4' => esc_html__('3 Col', 'doob'),
                    '3' => esc_html__('4 Col', 'doob'),
                ),
                'default'  => '6',
            ),
            array(
                'id'       => 'doob_project_archive_col_sm',
                'type'     => 'select',
                'title'    => esc_html__('Select Column for Large Mobiles', 'doob'),
                'subtitle'    => esc_html__('Large Mobiles: ≥ 576px', 'doob'),
                'options'  => array(
                    '12' => esc_html__('1 Col', 'doob'),
                    '6' => esc_html__('2 Col', 'doob'),
                    '4' => esc_html__('3 Col', 'doob'),
                    '3' => esc_html__('4 Col', 'doob'),
                ),
                'default'  => '12',
            ),
            array(
                'id'       => 'doob_project_archive_col',
                'type'     => 'select',
                'title'    => esc_html__('Select Column for Small Mobiles', 'doob'),
                'subtitle'    => esc_html__('Small Mobiles: < 576px', 'doob'),
                'options'  => array(
                    '12' => esc_html__('1 Col', 'doob'),
                    '6' => esc_html__('2 Col', 'doob'),
                    '4' => esc_html__('3 Col', 'doob'),
                    '3' => esc_html__('4 Col', 'doob'),
                ),
                'default'  => '12',
            ),
            array(
                'id' => 'projects_slug',
                'type' => 'text',
                'title' => esc_html__('Project Slug', 'doob'),
                'subtitle' => esc_html__('Change the project url slug', 'doob'),
                'description' => esc_html__('After saving your custom portfolio slug, flush the permalinks from "Wordpress Settings > Permalinks" for the changes to take effect.', 'doob'),
                'default' => 'portfolio',
            ),
            array(
                'id' => 'projects_cat_slug',
                'type' => 'text',
                'title' => esc_html__('Projects Categories Slug', 'doob'),
                'subtitle' => esc_html__('Change the projects Categories url slug', 'doob'),
                'description' => esc_html__('After saving your custom portfolio slug, flush the permalinks from "Wordpress Settings > Permalinks" for the changes to take effect.', 'doob'),
                'default' => 'portfolio-cat',
            ),

        )
    )
);
/**
 * Single Portfolio
 */
Redux::setSection($opt_name, array(
        'title' => esc_html__('Single', 'doob'),
        'id' => 'doob_portfolio_details_id',
        'icon' => 'el el-website',
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'select_title_bellow_content',
                'type'     => 'select',
                'title'    => esc_html__('Select Title Bellow Content', 'doob'),
                'desc'     => esc_html__('Select Excerpt or Breadcrumbs. If you want to empty this please select none.', 'doob'),
                // Must provide key => value pairs for select options
                'options'  => array(
                    'excerpt' => 'Excerpt',
                    'breadcrumbs' => 'Breadcrumbs',
                    'both' => 'Excerpt and Breadcrumbs',
                    'none' => 'None'
                ),
                'default'  => 'excerpt',
            ),

            array(
                'id' => 'doob_project_single_image_size',
                'type' => 'select',
                'title' => esc_html__('Select Thumbnail Size', 'doob'),
                'options' => doob_get_thumbnail_sizes(),
                'default' => 'doob-thumbnail-single',
            ),


            // Client Name
            array(
                'id' => 'doob_enable_client_name_meta',
                'type' => 'button_set',
                'title' => esc_html__('Client Name', 'doob'),
                'subtitle' => esc_html__('Show or hide the portfolio client name of portfolio single post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_client_name_text',
                'type' => 'text',
                'title' => esc_html__('Client Name Text', 'doob'),
                'default' => esc_html__('Client Name', 'doob'),
                'required' => array('doob_enable_client_name_meta', 'equals', 'yes'),
            ),

            // Release Date
            array(
                'id' => 'doob_enable_release_date_meta',
                'type' => 'button_set',
                'title' => esc_html__('Release Date', 'doob'),
                'subtitle' => esc_html__('Show or hide the portfolio release date of portfolio single post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_release_date_text',
                'type' => 'text',
                'title' => esc_html__('Release Date Text', 'doob'),
                'default' => esc_html__('Release Date', 'doob'),
                'required' => array('doob_enable_release_date_meta', 'equals', 'yes'),
            ),

            // Project Types
            array(
                'id' => 'doob_enable_project_types_meta',
                'type' => 'button_set',
                'title' => esc_html__('Project Types', 'doob'),
                'subtitle' => esc_html__('Show or hide the portfolio project types of portfolio single post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_project_types_text',
                'type' => 'text',
                'title' => esc_html__('Project Types Text', 'doob'),
                'default' => esc_html__('Project Types', 'doob'),
                'required' => array('doob_enable_project_types_meta', 'equals', 'yes'),
            ),

            // Live Preview
            array(
                'id' => 'doob_enable_live_preview_meta',
                'type' => 'button_set',
                'title' => esc_html__('Live Preview', 'doob'),
                'subtitle' => esc_html__('Show or hide the portfolio live preview of portfolio single post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_live_preview_text',
                'type' => 'text',
                'title' => esc_html__('Live Preview Text', 'doob'),
                'default' => esc_html__('Live Preview', 'doob'),
                'required' => array('doob_enable_live_preview_meta', 'equals', 'yes'),
            ),
            array(
                'id' => 'doob_live_preview_button_text',
                'type' => 'text',
                'title' => esc_html__('Live Preview Button Text', 'doob'),
                'default' => esc_html__('Visit Live Site', 'doob'),
                'required' => array('doob_enable_live_preview_meta', 'equals', 'yes'),
            ),


            /**
             * Portfolio Share option
             */
            array(
                'id' => 'doob_enable_portfolio_share',
                'type' => 'button_set',
                'title' => esc_html__('Share options', 'doob'),
                'subtitle' => esc_html__('Show or hide the social share button of portfolio single post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            // Facebook
            array(
                'id' => 'doob_enable_portfolio_share_facebook',
                'type' => 'button_set',
                'title' => esc_html__('Facebook', 'doob'),
                'subtitle' => esc_html__('Show or hide the facebook share button of portfolio single post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
                'required' => array('doob_enable_portfolio_share', 'equals', 'yes'),
            ),
            // Twitter
            array(
                'id' => 'doob_enable_portfolio_share_twitter',
                'type' => 'button_set',
                'title' => esc_html__('Twitter', 'doob'),
                'subtitle' => esc_html__('Show or hide the twitter share button of portfolio single post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
                'required' => array('doob_enable_portfolio_share', 'equals', 'yes'),
            ),
            // Linkedin
            array(
                'id' => 'doob_enable_portfolio_share_linkedin',
                'type' => 'button_set',
                'title' => esc_html__('Linkedin', 'doob'),
                'subtitle' => esc_html__('Show or hide the linkedin share button of portfolio single post.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
                'required' => array('doob_enable_portfolio_share', 'equals', 'yes'),
            ),

            /**
             * Related portfolio
             */
            array(
                'id' => 'doob_enable_related_portfolio',
                'type' => 'button_set',
                'title' => esc_html__('Related Portfolio', 'doob'),
                'subtitle' => esc_html__('Show or hide the related portfolio area of portfolio single post bellow section.', 'doob'),
                'options' => array(
                    'yes' => esc_html__('Show', 'doob'),
                    'no' => esc_html__('Hide', 'doob'),
                ),
                'default' => 'yes',
            ),
            array(
                'id' => 'doob_related_portfolio_section_title_before_text',
                'type' => 'text',
                'title' => esc_html__('Section Title Before Text', 'doob'),
                'default' => esc_html__('Related Work', 'doob'),
                'required' => array('doob_enable_related_portfolio', 'equals', 'yes'),
            ),
            array(
                'id' => 'doob_related_portfolio_section_title_text',
                'type' => 'text',
                'title' => esc_html__('Section Title Text', 'doob'),
                'default' => esc_html__('Our More Projects', 'doob'),
                'required' => array('doob_enable_related_portfolio', 'equals', 'yes'),
            ),

        )
    )
);
/**
 * Typography
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Typography', 'doob'),
    'id' => 'doob_fonts',
    'icon' => 'el el-fontsize',
    'fields' => array(
        array(
            'id' => 'doob_b_typography',
            'type' => 'typography',
            'title' => esc_html__('Body Typography (Paragraph)', 'doob'),
            'subtitle' => esc_html__('Controls the typography settings of the body.', 'doob'),
            'google' => true,
            'color' => false,
            'subsets' => false,
            'word-spacing' => false,
            'letter-spacing' => false,
            'text-align' => false,
            'all_styles' => false,
            'output' => array('body, p'),
            'units' => 'px',
        ),
        array(
            'id' => 'doob_h1_typography',
            'type' => 'typography',
            'always_display' => false,
            'color' => false,
            'title' => esc_html__('H1 Heading Typography', 'doob'),
            'subtitle' => esc_html__('Controls the typography settings of the H1 heading.', 'doob'),
            'google' => true,
            'text-transform' => false,
            'word-spacing' => false,
            'letter-spacing' => false,
            'subsets' => false,
            'text-align' => false,
            'all_styles' => false,
            'units' => 'px',
            'output' => array('h1, .h1'),
        ),
        array(
            'id' => 'doob_h2_typography',
            'type' => 'typography',
            'always_display' => false,
            'color' => false,
            'title' => esc_html__('H2 Heading Typography', 'doob'),
            'subtitle' => esc_html__('Controls the typography settings of the H2 heading.', 'doob'),
            'google' => true,
            'text-transform' => false,
            'letter-spacing' => false,
            'word-spacing' => false,
            'subsets' => false,
            'text-align' => false,
            'all_styles' => false,
            'units' => 'px',
            'output' => array('h2, .h2'),
        ),
        array(
            'id' => 'doob_h3_typography',
            'type' => 'typography',
            'always_display' => false,
            'color' => false,
            'title' => esc_html__('H3 Heading Typography', 'doob'),
            'subtitle' => esc_html__('Controls the typography settings of the H3 heading.', 'doob'),
            'google' => true,
            'text-transform' => false,
            'letter-spacing' => false,
            'word-spacing' => false,
            'subsets' => false,
            'text-align' => false,
            'all_styles' => false,
            'units' => 'px',
            'output' => array('h3, .h3'),
        ),
        array(
            'id' => 'doob_h4_typography',
            'type' => 'typography',
            'always_display' => false,
            'color' => false,
            'title' => esc_html__('H4 Heading Typography', 'doob'),
            'subtitle' => esc_html__('Controls the typography settings of the H4 heading.', 'doob'),
            'google' => true,
            'text-transform' => false,
            'word-spacing' => false,
            'letter-spacing' => false,
            'subsets' => false,
            'text-align' => false,
            'all_styles' => false,
            'units' => 'px',
            'output' => array('h4, .h4'),
        ),
        array(
            'id' => 'doob_h5_typography',
            'type' => 'typography',
            'always_display' => false,
            'color' => false,
            'title' => esc_html__('H5 Heading Typography', 'doob'),
            'subtitle' => esc_html__('Controls the typography settings of the H5 heading.', 'doob'),
            'google' => true,
            'text-transform' => false,
            'word-spacing' => false,
            'letter-spacing' => false,
            'subsets' => false,
            'text-align' => false,
            'all_styles' => false,
            'units' => 'px',
            'output' => array('h5, .h5'),
        ),
        array(
            'id' => 'doob_h6_typography',
            'type' => 'typography',
            'always_display' => false,
            'color' => false,
            'title' => esc_html__('H6 Heading Typography', 'doob'),
            'subtitle' => esc_html__('Controls the typography settings of the H6 heading.', 'doob'),
            'google' => true,
            'text-transform' => false,
            'word-spacing' => false,
            'letter-spacing' => false,
            'subsets' => false,
            'text-align' => false,
            'all_styles' => false,
            'units' => 'px',
            'output' => array('h6, .h6'),
        ),

    )
));

/**
 * 404 error page
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('404 Page', 'doob'),
    'id' => 'doob_error_page',
    'icon' => 'el el-eye-close',
    'fields' => array(
        array(
            'id' => 'doob_404_title',
            'type' => 'text',
            'title' => esc_html__('Title', 'doob'),
            'subtitle' => esc_html__('Add your Default title.', 'doob'),
            'default' => esc_html__('404!', 'doob'),
        ),
        array(
            'id' => 'doob_404_subtitle',
            'type' => 'text',
            'title' => esc_html__('Sub Title', 'doob'),
            'subtitle' => esc_html__('Add your custom subtitle.', 'doob'),
            'default' => esc_html__('Page not found', 'doob'),
        ),
        array(
            'id' => 'doob_404_desc',
            'type' => 'text',
            'title' => esc_html__('Description', 'doob'),
            'subtitle' => esc_html__('Add your custom description.', 'doob'),
            'default' => esc_html__('The page you were looking for could not be found.', 'doob'),
        ),
        array(
            'id' => 'doob_enable_go_back_btn',
            'type' => 'button_set',
            'title' => esc_html__('Button', 'doob'),
            'subtitle' => esc_html__('Enable or disable the go to home page button.', 'doob'),
            'options' => array(
                'yes' => 'Enable',
                'no' => 'Disable'
            ),
            'default' => 'yes'
        ),
        array(
            'id' => 'doob_404_enable_search',
            'type' => 'button_set',
            'title' => esc_html__('Search Form', 'doob'),
            'subtitle' => esc_html__('Enable or disable the blog search form', 'doob'),
            'options' => array(
                'yes' => 'Enable',
                'no' => 'Disable'
            ),
            'default' => 'yes'
        ),
        array(
            'id' => 'doob_404_search_form_placeholder',
            'type' => 'text',
            'title' => esc_html__('Search placeholder', 'doob'),
            'default' => esc_html__('Search Here...', 'doob'),
            'required' => array('doob_404_enable_search', 'equals', 'yes'),
        ),
        array(
            'id' => 'doob_404_button_text',
            'type' => 'text',
            'title' => esc_html__('Button Text', 'doob'),
            'subtitle' => esc_html__('Set the custom text of go to home page button.', 'doob'),
            'default' => esc_html__('Back To Homepage', 'doob'),
            'required' => array('doob_enable_go_back_btn', 'equals', 'yes'),
        ),
    )
));


/**
 * WooCommerce
 */
if ( class_exists( 'WooCommerce' ) ) {

    Redux::setSection($opt_name, array(
        'title' => esc_html__('WooCommerce', 'doob'),
        'id' => 'woo_Settings_section',
        'icon' => 'el el-shopping-cart',
    ));
    /**
     * WooCommerce Archive
     */
    Redux::setSection($opt_name, array(
        'title' => esc_html__('General', 'doob'),
        'id' => 'wc_sec_general',
        'icon' => 'el el-folder-open',
        'subsection' => true,
        'fields' => array(
            array(
                'id' => 'wc_general_sidebar',
                'type' => 'image_select',
                'title' => esc_html__('Select Shop Sidebar', 'doob'),
                'subtitle' => esc_html__('Choose your favorite shop layout', 'doob'),
                'options' => array(
                    'left' => array(
                        'alt' => esc_html__('Left Sidebar', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/left-sidebar.png',
                        'title' => esc_html__('Left Sidebar', 'doob'),
                    ),
                    'right' => array(
                        'alt' => esc_html__('Right Sidebar', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/right-sidebar.png',
                        'title' => esc_html__('Right Sidebar', 'doob'),
                    ),
                    'no' => array(
                        'alt' => esc_html__('No Sidebar', 'doob'),
                        'img' => get_template_directory_uri() . '/assets/images/optionframework/layout/no-sidebar.png',
                        'title' => esc_html__('No Sidebar', 'doob'),
                    ),
                ),
                'default' => 'no',
            ),
            array(
                'id'       => 'wc_num_product_per_row',
                'type'     => 'text',
                'title'    => esc_html__( 'Number of Products Per Row', 'doob' ),
                'default'  => '3',
            ),
            array(
                'id'       => 'wc_num_product',
                'type'     => 'text',
                'title'    => esc_html__( 'Number of Products Per Page', 'doob' ),
                'default'  => '12',
            ),
        )
    ));
    /**
     * WooCommerce Single Page
     */
    Redux::setSection($opt_name, array(
        'title' => esc_html__('Product Single Page', 'doob'),
        'id' => 'wc_sec_product',
        'icon' => 'el el-folder-open',
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'wc_cats',
                'type'     => 'switch',
                'title'    => esc_html__( 'Categories', 'doob' ),
                'on'       => esc_html__( 'Show', 'doob' ),
                'off'      => esc_html__( 'Hide', 'doob' ),
                'default'  => true,
            ),
            array(
                'id'       => 'wc_tags',
                'type'     => 'switch',
                'title'    => esc_html__( 'Tags', 'doob' ),
                'on'       => esc_html__( 'Show', 'doob' ),
                'off'      => esc_html__( 'Hide', 'doob' ),
                'default'  => true,
            ),
            array(
                'id'       => 'wc_related',
                'type'     => 'switch',
                'title'    => esc_html__( 'Related Products', 'doob' ),
                'on'       => esc_html__( 'Show', 'doob' ),
                'off'      => esc_html__( 'Hide', 'doob' ),
                'default'  => true,
            ),
            array(
                'id'       => 'wc_description',
                'type'     => 'switch',
                'title'    => esc_html__( 'Description Tab', 'doob' ),
                'on'       => esc_html__( 'Show', 'doob' ),
                'off'      => esc_html__( 'Hide', 'doob' ),
                'default'  => true,
            ),
            array(
                'id'       => 'wc_reviews',
                'type'     => 'switch',
                'title'    => esc_html__( 'Reviews Tab', 'doob' ),
                'on'       => esc_html__( 'Show', 'doob' ),
                'off'      => esc_html__( 'Hide', 'doob' ),
                'default'  => true,
            ),
            array(
                'id'       => 'wc_additional_info',
                'type'     => 'switch',
                'title'    => esc_html__( 'Additional Information Tab', 'doob' ),
                'on'       => esc_html__( 'Show', 'doob' ),
                'off'      => esc_html__( 'Hide', 'doob' ),
                'default'  => true,
            ),
        )
    ));
    /**
     * WooCommerce Cart Page
     */
    Redux::setSection($opt_name, array(
        'title' => esc_html__('Cart page', 'doob'),
        'id' => 'wc_sec_cart',
        'icon' => 'el el-folder-open',
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'wc_cross_sell',
                'type'     => 'switch',
                'title'    => esc_html__( 'Cross Sell Products', 'doob' ),
                'on'       => esc_html__( 'Show', 'doob' ),
                'off'      => esc_html__( 'Hide', 'doob' ),
                'default'  => true,
            ),
        )
    ));
} // End WooCommerce
