<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package doob
 */


if (!function_exists('doob_scripts')){
    /**
     * Enqueue scripts and styles.
     */
    function doob_scripts() {

        wp_deregister_style('font-awesome');

        // Fonts
        wp_enqueue_style('doob-fonts', doob_fonts_url());

        // Style
        if ( is_rtl() ) {
            wp_enqueue_style('bootstrap', DOOB_RTL_CSS_URL . 'vendor/bootstrap.min.css', array(), DOOB_VERSION);
        } else {
            wp_enqueue_style('bootstrap', DOOB_CSS_URL . 'vendor/bootstrap.min.css', array(), DOOB_VERSION);
        }

        wp_enqueue_style('lightbox', DOOB_CSS_URL . 'vendor/lightbox.css', array(), DOOB_VERSION);
        wp_enqueue_style('magnific-popup', DOOB_CSS_URL . 'vendor/magnify.min.css', array(), DOOB_VERSION);
        wp_enqueue_style('font-awesome', DOOB_CSS_URL . 'vendor/fontawesome.css', array(), DOOB_VERSION);

        wp_enqueue_style('slick-slider', DOOB_CSS_URL . 'vendor/slick.css', array(), DOOB_VERSION);
        wp_enqueue_style('slick-slider-theme', DOOB_CSS_URL . 'vendor/slick-theme.css', array(), DOOB_VERSION);

        wp_enqueue_style('animation', DOOB_CSS_URL . 'vendor/animation.css', array(), DOOB_VERSION);
        wp_enqueue_style('feather', DOOB_CSS_URL . 'vendor/feather.css', array(), DOOB_VERSION);
        wp_enqueue_style('doob-main-style', DOOB_CSS_URL . 'style.css', array(), DOOB_VERSION);
        wp_enqueue_style('doob-woocommerce', DOOB_CSS_URL . 'woocommerce.css', array(), DOOB_VERSION);
        wp_enqueue_style('doob-dev-style', DOOB_CSS_URL . 'dev-style.css', array(), DOOB_VERSION);
        wp_enqueue_style('doob-style', get_stylesheet_uri() );
        wp_style_add_data( 'doob-style', 'rtl', 'replace' );

        // Scripts
        wp_enqueue_script('bootstrap', DOOB_JS_URL . 'vendor/bootstrap.min.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('popper', DOOB_JS_URL . 'vendor/popper.min.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('stellar', DOOB_JS_URL . 'vendor/stellar.js', array('jquery'), DOOB_VERSION, false);
        wp_enqueue_script('particles', DOOB_JS_URL . 'vendor/particles.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('jquery-one-page-nav', DOOB_JS_URL . 'vendor/jquery-one-page-nav.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('imagesloaded');
        wp_enqueue_script('isotope', DOOB_JS_URL . 'vendor/isotope.js', array('imagesloaded'), DOOB_VERSION, true);
        wp_enqueue_script('masonry', DOOB_JS_URL . 'vendor/masonry.js', array('masonry'), DOOB_VERSION, true);
        wp_enqueue_script('counterup', DOOB_JS_URL . 'vendor/counterup.min.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('feather-icons', DOOB_JS_URL . 'vendor/feather.min.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('lightbox', DOOB_JS_URL . 'vendor/lightbox.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('magnify', DOOB_JS_URL . 'vendor/magnify.min.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('parallax', DOOB_JS_URL . 'vendor/parallax.js', array('jquery'), DOOB_VERSION, false);
        wp_enqueue_script('slick', DOOB_JS_URL . 'vendor/slick.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('easypie', DOOB_JS_URL . 'vendor/easypie.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('waypoints', DOOB_JS_URL . 'vendor/waypoints.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('wow', DOOB_JS_URL . 'vendor/wow.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('sal', DOOB_JS_URL . 'vendor/sal.min.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('text-type', DOOB_JS_URL . 'vendor/text-type.js', array('jquery'), DOOB_VERSION, true);
        wp_enqueue_script('doob-cookie', DOOB_JS_URL . 'vendor/js.cookie.js', array('jquery'), DOOB_VERSION, true);


        // Style
        if ( is_rtl() ) {
            wp_enqueue_script('doob-main', DOOB_RTL_JS_URL . 'main.js', array('jquery'), DOOB_VERSION, true);
        } else {
            wp_enqueue_script('doob-main', DOOB_JS_URL . 'main.js', array('jquery'), DOOB_VERSION, true);
        }

        wp_enqueue_script('jquery-style-switcher', DOOB_JS_URL . 'vendor/jquery.style.switcher.js', array('jquery'), DOOB_VERSION, true);

        wp_enqueue_script('doob-navigation', DOOB_ADMIN_JS_URL . 'navigation.js', array(), DOOB_VERSION, true );
        wp_enqueue_script('doob-skip-link-focus-fix', DOOB_ADMIN_JS_URL . 'skip-link-focus-fix.js', array(), DOOB_VERSION, true );

        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply' );
        }
    }
}
add_action( 'wp_enqueue_scripts', 'doob_scripts' );


if( !function_exists('doob_media_scripts') ) {
    /**
     * Doob admin script
     */
    function doob_media_scripts() {

         wp_enqueue_style( 'doob-wp-admin', get_template_directory_uri() . '/assets/admin/css/admin-style.css', false, '1.0.0' );

        // JS
        wp_enqueue_media();
        wp_enqueue_script( 'jquery-ui-tabs' );
        wp_enqueue_script( 'doob-logo-uploader', DOOB_ADMIN_JS_URL .'logo-uploader.js', false, '', true );
    }
}
add_action('admin_enqueue_scripts', 'doob_media_scripts', 1000);

